#!/bin/sh
#$Header$ 
#
# File:  lsigetlunix.sh 
#
# 
# See Readme.txt (Embedded further down)
#
#  How to run it:
#    1) Copy the included files to a file system with available space. 
#       In general, the size of the data collected is at least as big as the total size of
#       all log files.
#    3) Run it:   ./lsigetlunix.sh -H <enter> for help screen
#
# 
#  What to do when the script ends:
#    1) Send the .tgz file to Technical Support or to the FAE that you are in contact with.
# 
#  What to do when receiving the .tgz file:
#    1) Extract
#    3) Verify files are not empty & Controller_Cx.txt and/or Adapter_Ax.txt files are present.
#    4) Analyze the collected data 
#
#
#
# 02/20/10 - To many major changes have occurred to document them all. Revamped capture script that supports 3ware, MegaRAID
#	     & HBA's. All changes from here on out to be documented. 
# 02/21/10 - Grep'ed disk specific parameters together for easier troubleshooting for 3ware, already on MegaRAID. Added modpgctl.
# 02/22/10 - Fixed HBA version reporting.
# 02/24/10 - Changing export to x=y for FreeBSD, may break MacOS or Solaris, need to verify. Changed -? to -H for Help, 
#            reserved on FreeBSD. Grep MegaRAID specific info in FreeBSD messages file. 
# 02/25/10 - Fixed grepped disk specific parameters for multiple controllers on 3ware. Added FreeBSD Support for MegaRAID & HBA.
# 	     Cleaned up CLI naming/arch. Excluded all MegaRAID/HBA sections if MacOS. Changed to gunzip instead of tar -zxvf for 
#            Solaris. Added MegaRAID specific logging for Solaris. Added additional files to cleanup. 
# 04/10/10 - Added check for "OS_LSI"="" (Ubuntu others?), added check for iuCRC on MegaRAID. 
# 06/19/10 - Rearranged data for easier troubleshooting, less use of MegaCli, more grepping of master file for better performance.
#	     Created separate files for pdlist/adpalilog/adpallinfo/fwtermlog & added master file name to all as well as 
#	     adapter_ax.txt file (fwtermlog and all relevant data still in adapter_ax.txt file. Created separate files for grepped
#            fwtermlog errors to make it easier to read fwtermlog (instead of appending to end).
# 06/20/10 - Updated MegaCli to 10M05, updated help, fwtermlog errors in separate subdir.
#
#set -x
# grep as variable, for Solaris - grep=/usr/xpg4/bin/grep
grep=grep
# Init variable
OS_LSI=
date '+%H:%M:%S.%N'
TWGETLUNIXSTARTutc=`date -u`
TWGETLUNIXSTART=`date`
Capture_Script_Version=062010
echo Capture_Script_Version_$Capture_Script_Version
###########################################################################################################################
# Set OS type - Need first, initially for correct grep version.
###########################################################################################################################

if [ `echo $OSTYPE | $grep linux` ] ; then
OS_LSI=linux
fi

if [ -d /proc/vmware ] ; then
OS_LSI=vmware
fi
#if [ "$OS_LSI" = "vmware" ] ; then
#check vmware version
#OS_LSIm=vmware_esx35
#OS_LSIm=vmware_esx40
#OS_LSIm=vmware_esxi40
#fi

if [ `echo $OSTYPE | $grep FreeBSD` ] ; then
OS_LSI=freebsd
fi

if [ `echo $OSTYPE | $grep darwin` ] ; then
OS_LSI=macos
fi


if [ `uname | $grep SunOS` ] ; then
OS_LSI=solaris
if [ -e /usr/xpg4/bin/grep ] ; then 
grep=/usr/xpg4/bin/grep
else
echo ""
echo ""
echo ""
echo ""
echo ""
echo "This script requires /usr/xpg4/bin/grep that supports grep -xe to work correctly!"
echo ""
echo ""
echo ""
echo ""
echo ""
exit
fi
fi

if [ "$OS_LSI" = "" ] ; then
echo "OS_LSI is not set, either not a valid OS for this script or try running;"
echo "sudo bash ./lsigetlunix.sh -D -Q"
exit
fi
 
###########################################################################################################################
# Verify all capture script files exist or exit.
###########################################################################################################################

for i in Readme.txt all_cli ; do
if [ ! -f $i ] ; then echo "$i missing"

#cho ".................................................||................................................."
#echo "" 
echo '"./lsigetlunix.sh -H" provides a help screen.'
echo "" 
echo "This is not a valid lsigetlunix.sh installation. This script is available at;"
echo "" 
echo "http://www.3ware.com/KB/article.aspx?id=12278"
echo "" 
echo "All files included in the original lsigetlunix_xxx_xxxxxx.tgz file MUST be kept"
echo "in the same subdir as lsigetlunix.sh."
echo "" 
echo "" 
date '+%H:%M:%S.%N'
exit
fi
done	     
###########################################################################################################################
# Initialize Variables
###########################################################################################################################
#3ware
TWPRINTFILENAME=
TWGETDIRECTORYKEEP=
TWGETBATCHMODE=
TWGETPARTIALMODE=STANDARD
TWGETMONITORMODE=
TW_Help_Screen=
TWPROMPTFORCOMMENT=
CLI_NAME=tw_cli
CLI_LOCATION=./
TWcomment=
tw_hostname=
tw_host=
OLD_EVT_CAP_EXIST=NO
NEW_EVT_CAP_EXIST=NO
TW_ECHO_AEC=
TW_ECHO_PMSTAT=
ex_enclosurenums=
TWPARTIALCAP=

#MegaRAID
MCLI_NAME=
MCLI_LOCATION=./
num_mraid_adapters=
LimitMegaCliCMDs=

###########################################################################################################################
# Command Line Options
# Looking for comments that are not command line options.
# Only 1 comment allowed, lowest variable # wins.
###########################################################################################################################

if [ "$6" != "" ] ; then 
echo $6 | $grep -xe -M -xe -P -xe -D -xe -B -xe -Q -xe -E_AEC -xe -E_DPMSTAT -xe -E_AEC_DPMSTAT -xe -G_AEC -xe -G_DPMSTAT -xe -G_AEC_DPMSTAT -xe -MRWA -xe -H > /dev/null 2>&1
	if [ $? -ne 0 ] ; then TWcomment="$6"
	fi
fi
if [ "$5" != "" ] ; then 
echo $5 | $grep -xe -M -xe -P -xe -D -xe -B -xe -Q -xe -E_AEC -xe -E_DPMSTAT -xe -E_AEC_DPMSTAT -xe -G_AEC -xe -G_DPMSTAT -xe -G_AEC_DPMSTAT -xe -MRWA -xe -H > /dev/null 2>&1
	if [ $? -ne 0 ] ; then TWcomment="$5"
	fi
fi
if [ "$4" != "" ] ; then 
echo $4 | $grep -xe -M -xe -P -xe -D -xe -B -xe -Q -xe -E_AEC -xe -E_DPMSTAT -xe -E_AEC_DPMSTAT -xe -G_AEC -xe -G_DPMSTAT -xe -G_AEC_DPMSTAT -xe -MRWA -xe -H > /dev/null 2>&1
	if [ $? -ne 0 ] ; then TWcomment="$4"
	fi
fi
if [ "$3" != "" ] ; then 
echo $3 | $grep -xe -M -xe -P -xe -D -xe -B -xe -Q -xe -E_AEC -xe -E_DPMSTAT -xe -E_AEC_DPMSTAT -xe -G_AEC -xe -G_DPMSTAT -xe -G_AEC_DPMSTAT -xe -MRWA -xe -H > /dev/null 2>&1
	if [ $? -ne 0 ] ; then TWcomment="$3"
	fi
fi
if [ "$2" != "" ] ; then 
echo $2 | $grep -xe -M -xe -P -xe -D -xe -B -xe -Q -xe -E_AEC -xe -E_DPMSTAT -xe -E_AEC_DPMSTAT -xe -G_AEC -xe -G_DPMSTAT -xe -G_AEC_DPMSTAT -xe -MRWA -xe -H > /dev/null 2>&1
	if [ $? -ne 0 ] ; then TWcomment="$2"
	fi
fi
if [ "$1" != "" ] ; then 
echo $1 | $grep -xe -M -xe -P -xe -D -xe -B -xe -Q -xe -E_AEC -xe -E_DPMSTAT -xe -E_AEC_DPMSTAT -xe -G_AEC -xe -G_DPMSTAT -xe -G_AEC_DPMSTAT -xe -MRWA -xe -H > /dev/null 2>&1
	if [ $? -ne 0 ] ; then TWcomment="$1"
	fi
fi


# Checking command line variables 1-6 for options.
# Competing options are not allowed.

if [ "$1" = "-P" ] ; then TWPRINTFILENAME=YES ; fi
if [ "$2" = "-P" ] ; then TWPRINTFILENAME=YES ; fi
if [ "$3" = "-P" ] ; then TWPRINTFILENAME=YES ; fi
if [ "$4" = "-P" ] ; then TWPRINTFILENAME=YES ; fi
if [ "$5" = "-P" ] ; then TWPRINTFILENAME=YES ; fi
if [ "$6" = "-P" ] ; then TWPRINTFILENAME=YES ; fi
if [ "$1" = "-D" ] ; then TWGETDIRECTORYKEEP=YES ; fi
if [ "$2" = "-D" ] ; then TWGETDIRECTORYKEEP=YES ; fi
if [ "$3" = "-D" ] ; then TWGETDIRECTORYKEEP=YES ; fi
if [ "$4" = "-D" ] ; then TWGETDIRECTORYKEEP=YES ; fi
if [ "$5" = "-D" ] ; then TWGETDIRECTORYKEEP=YES ; fi
if [ "$6" = "-D" ] ; then TWGETDIRECTORYKEEP=YES ; fi
if [ "$1" = "-Q" ] ; then TWGETBATCHMODE=QUIET ; fi
if [ "$2" = "-Q" ] ; then TWGETBATCHMODE=QUIET ; fi
if [ "$3" = "-Q" ] ; then TWGETBATCHMODE=QUIET ; fi
if [ "$4" = "-Q" ] ; then TWGETBATCHMODE=QUIET ; fi
if [ "$5" = "-Q" ] ; then TWGETBATCHMODE=QUIET ; fi
if [ "$6" = "-Q" ] ; then TWGETBATCHMODE=QUIET ; fi
if [ "$1" = "-B" ] ; then TWGETBATCHMODE=BATCH ; fi
if [ "$2" = "-B" ] ; then TWGETBATCHMODE=BATCH ; fi
if [ "$3" = "-B" ] ; then TWGETBATCHMODE=BATCH ; fi
if [ "$4" = "-B" ] ; then TWGETBATCHMODE=BATCH ; fi
if [ "$5" = "-B" ] ; then TWGETBATCHMODE=BATCH ; fi
if [ "$6" = "-B" ] ; then TWGETBATCHMODE=BATCH ; fi
if [ "$1" = "-E_AEC" ] ; then TWGETPARTIALMODE=E_AEC ; fi
if [ "$2" = "-E_AEC" ] ; then TWGETPARTIALMODE=E_AEC ; fi
if [ "$3" = "-E_AEC" ] ; then TWGETPARTIALMODE=E_AEC ; fi
if [ "$4" = "-E_AEC" ] ; then TWGETPARTIALMODE=E_AEC ; fi
if [ "$5" = "-E_AEC" ] ; then TWGETPARTIALMODE=E_AEC ; fi
if [ "$6" = "-E_AEC" ] ; then TWGETPARTIALMODE=E_AEC ; fi
if [ "$1" = "-E_DPMSTAT" ] ; then TWGETPARTIALMODE=E_DPMSTAT ; fi
if [ "$2" = "-E_DPMSTAT" ] ; then TWGETPARTIALMODE=E_DPMSTAT ; fi
if [ "$3" = "-E_DPMSTAT" ] ; then TWGETPARTIALMODE=E_DPMSTAT ; fi
if [ "$4" = "-E_DPMSTAT" ] ; then TWGETPARTIALMODE=E_DPMSTAT ; fi
if [ "$5" = "-E_DPMSTAT" ] ; then TWGETPARTIALMODE=E_DPMSTAT ; fi
if [ "$6" = "-E_DPMSTAT" ] ; then TWGETPARTIALMODE=E_DPMSTAT ; fi
if [ "$1" = "-E_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=E_AEC_DPMSTAT ; fi
if [ "$2" = "-E_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=E_AEC_DPMSTAT ; fi
if [ "$3" = "-E_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=E_AEC_DPMSTAT ; fi
if [ "$4" = "-E_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=E_AEC_DPMSTAT ; fi
if [ "$5" = "-E_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=E_AEC_DPMSTAT ; fi
if [ "$6" = "-E_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=E_AEC_DPMSTAT ; fi
if [ "$1" = "-G_AEC" ] ; then TWGETPARTIALMODE=G_AEC ; fi
if [ "$2" = "-G_AEC" ] ; then TWGETPARTIALMODE=G_AEC ; fi
if [ "$3" = "-G_AEC" ] ; then TWGETPARTIALMODE=G_AEC ; fi
if [ "$4" = "-G_AEC" ] ; then TWGETPARTIALMODE=G_AEC ; fi
if [ "$5" = "-G_AEC" ] ; then TWGETPARTIALMODE=G_AEC ; fi
if [ "$6" = "-G_AEC" ] ; then TWGETPARTIALMODE=G_AEC ; fi
if [ "$1" = "-G_DPMSTAT" ] ; then TWGETPARTIALMODE=G_DPMSTAT ; fi
if [ "$2" = "-G_DPMSTAT" ] ; then TWGETPARTIALMODE=G_DPMSTAT ; fi
if [ "$3" = "-G_DPMSTAT" ] ; then TWGETPARTIALMODE=G_DPMSTAT ; fi
if [ "$4" = "-G_DPMSTAT" ] ; then TWGETPARTIALMODE=G_DPMSTAT ; fi
if [ "$5" = "-G_DPMSTAT" ] ; then TWGETPARTIALMODE=G_DPMSTAT ; fi
if [ "$6" = "-G_DPMSTAT" ] ; then TWGETPARTIALMODE=G_DPMSTAT ; fi
if [ "$1" = "-G_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=G_AEC_DPMSTAT ; fi
if [ "$2" = "-G_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=G_AEC_DPMSTAT ; fi
if [ "$3" = "-G_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=G_AEC_DPMSTAT ; fi
if [ "$4" = "-G_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=G_AEC_DPMSTAT ; fi
if [ "$5" = "-G_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=G_AEC_DPMSTAT ; fi
if [ "$6" = "-G_AEC_DPMSTAT" ] ; then TWGETPARTIALMODE=G_AEC_DPMSTAT ; fi
if [ "$1" = "-M" ] ; then TWGETMONITORMODE=MONITOR ; fi
if [ "$2" = "-M" ] ; then TWGETMONITORMODE=MONITOR ; fi
if [ "$3" = "-M" ] ; then TWGETMONITORMODE=MONITOR ; fi
if [ "$4" = "-M" ] ; then TWGETMONITORMODE=MONITOR ; fi
if [ "$5" = "-M" ] ; then TWGETMONITORMODE=MONITOR ; fi
if [ "$6" = "-M" ] ; then TWGETMONITORMODE=MONITOR ; fi
if [ "$1" = "-MRWA" ] ; then LimitMegaCliCMDs=YES ; fi
if [ "$2" = "-MRWA" ] ; then LimitMegaCliCMDs=YES ; fi
if [ "$3" = "-MRWA" ] ; then LimitMegaCliCMDs=YES ; fi
if [ "$4" = "-MRWA" ] ; then LimitMegaCliCMDs=YES ; fi
if [ "$5" = "-MRWA" ] ; then LimitMegaCliCMDs=YES ; fi
if [ "$6" = "-MRWA" ] ; then LimitMegaCliCMDs=YES ; fi
if [ "$1" = "-H" ] ; then TW_Help_Screen=YES ; fi
if [ "$2" = "-H" ] ; then TW_Help_Screen=YES ; fi
if [ "$3" = "-H" ] ; then TW_Help_Screen=YES ; fi
if [ "$4" = "-H" ] ; then TW_Help_Screen=YES ; fi
if [ "$5" = "-H" ] ; then TW_Help_Screen=YES ; fi
if [ "$6" = "-H" ] ; then TW_Help_Screen=YES ; fi

###########################################################################################################################
# Option Override
###########################################################################################################################

if [ "$TWGETMONITORMODE" = "MONITOR" ] ; then TWGETPARTIALMODE=STANDARD ; fi

###########################################################################################################################
# Bypass Comment prompt
###########################################################################################################################

if [ "$TWGETPARTIALMODE" = "E_AEC" ] ; then TWPROMPTFORCOMMENT=NO ; fi
if [ "$TWGETPARTIALMODE" = "E_DPMSTAT" ] ; then TWPROMPTFORCOMMENT=NO ; fi
if [ "$TWGETPARTIALMODE" = "E_AEC_DPMSTAT" ] ; then TWPROMPTFORCOMMENT=NO ; fi
if [ "$TWGETBATCHMODE" = "BATCH" ] ; then TWPROMPTFORCOMMENT=NO ; fi
if [ "$TWGETBATCHMODE" = "QUIET" ] ; then TWPROMPTFORCOMMENT=NO ; fi
if [ "$TWcomment" != "" ] ; then TWPROMPTFORCOMMENT=NO ; fi
if [ "$TWGETPARTIALMODE" = "G_AEC_DPMSTAT" ] ; then TWPARTIALCAP=YES ; fi
if [ "$TWGETPARTIALMODE" = "G_AEC" ] ; then TWPARTIALCAP=YES ; fi
if [ "$TWGETPARTIALMODE" = "G_DPMSTAT" ] ; then TWPARTIALCAP=YES ; fi
###########################################################################################################################
# Help Screen
###########################################################################################################################

if [ "$TW_Help_Screen" = "YES" ] ; then

#cho ".................................................||................................................."
echo "" 
echo "LSI HBA/MegaRAID/3ware Data collection script for Linux, FreeBSD, MacOS, & Solaris X86 (sh shell)." 
echo "This script will collect system logs and info as well as controller, disk and"
echo "enclosure info for debugging purposes. All files included in the original" 
echo "lsigetlunix_xxxxxx.tgz file MUST be kept in the same subdir as lsigetlunix.sh."
echo "You MUST have root access rights to run this script, su/sudo/root/etc. The latest version of this"
echo "script as well as information on what data can be collected manually can be found at;"
echo ""
echo "http://www.3ware.com/KB/article.aspx?id=12278"
echo ""
echo "OR"
echo ""
echo "ftp0.lsil.com"
echo "User:tsupport"
echo "Password:tsupport"
echo "/outgoing_perm/CaptureScripts  (Usually newer scripts than KB article)"
echo ""
echo "To automatically get the latest script you can download the following file & grep for the current"
echo "latest file. This ensures support will always have access to the latest data to speed up the support"
echo "process." 
echo "/outgoing_perm/CaptureScripts/Latest_Script_Versions.txt"
echo "#Used for automated remote script updates"
echo "LatestFreebsd#lsigetfreebsd_041010.tgz"
echo "LatestLinux#lsigetlinux_041010.tgz"
echo "LatestLunix#lsigetlunix_041010.tgz"
echo "LatestMacOS#lsigetmacos_041010.tgz"
echo "LatestSolaris#lsigetsolaris_041010.tgz"
echo "LatestWin#lsigetwin_031310.tgz"
echo ""
echo "This script is being packaged for all supported linux/Unix based OS's"
echo "together as well as individually for each OS with different bundled" 
echo "utilities. The exact same script is used in all cases, this is being done" 
echo "to cut down on the size of the full .tgz file, currently 18MB's for the full lunix build."
echo ""
echo "	lsigetlunix_xxxxxx.tgz 	 - (Linux/Unix) FreeBSD/Linux/MacOS/Sco/Solaris/VMWare"
echo "	lsigetfreebsd_xxxxxx.tgz - FreeBSD"
echo "	lsigetlinux_xxxxxx.tgz 	 - Linux"   
echo "	lsigetmacos_xxxxxx.tgz 	 - MacOS"
echo "	lsigetsco_xxxxxx.tgz 	 - Sco     (currently - Not Supported - Needs to be added)"
echo "	lsigetsolaris_xxxxxx.tgz - Solaris"
echo "	lsigetvmware_xxxxxx.tgz  - VMWare  (currently - Not Supported - Needs testing)"
echo ""
echo "Optional Command Line Options:"
echo "lsigetlunix [Comment] [Option(s)]"		
echo 'Comment: Enclose noncontiguous strings in double quotes "My Comments"' 
echo "Option:" 
echo "-P             = PRINT filename in ./LSICAPTUREFILES.TXT for batch automation."
echo "-D             = Working DIRECTORY is not deleted."
echo "-Q             = QUIET Mode - No keystrokes required unless error."
echo "-B             = BATCH Mode - No keystrokes required."
echo "-E_AEC         = Clear and ENABLE AEC. !Under Direction Only! (3ware Only)" 
echo "-E_DPMSTAT     = Clear and ENABLE DPMSTAT. (3ware Only)"
echo "-E_AEC_DPMSTAT = Clear and ENABLE AEC and DPMSTAT. !Under Direction Only! (3ware Only)" 
echo "-G_AEC         = Disable and GET AEC Logs, IF enabled. !Under Direction Only! (3ware Only)" 
echo "-G_DPMSTAT     = Disable and GET DPMSTAT Logs, IF enabled. (3ware Only)"
echo "-G_AEC_DPMSTAT = Disable and GET AEC/DPMSTAT Logs, IF enabled. !Under Direction Only! (3ware Only)" 
echo "-M             = MONITOR Mode - Standard and daily/targeted logging. (3ware Only)"  
echo "-MRWA          = MegaRAID Work Around - Limit commands for compatibility issues with old code" 		
echo "-H             = This Help Screen."
echo ""
echo 'Example ./lsigetlunix.sh -D -Q "This is my comment"'
echo "Runs the standard script leaving the working directory, without prompts" 
echo "and leaves a comment."
echo ""
echo 'Example ./lsigetlunix.sh -Q "This is my comment" -D -M' 
echo "Runs the standard script leaving the working directory, without prompts" 
echo "and leaves a comment, once done the script stays resident in Monitor Mode."
echo ""
echo "Notes:" 
echo "Send just the created .tar.gz file as is to your support rep."
echo ""
echo "AEC = Advanced Event Capture - This is an unreleased INTERNAL option!" 
echo "Do NOT use AEC without being directed to by Technical Support or an FAE! (3ware Only)"
echo ""
echo "DPMSTAT = Disk Performance Monitoring Statistics - Captures performance"
echo "related information on a controller/disk basis. Detailed information can" 
echo "found in the 9.5.1 or later Users Guide available at; (3ware Only)"
echo ""
echo "http://www.3ware.com/support/userdocs.asp"
echo ""
echo "All of the -G_* "GET" Options are done automatically if AEC or DPMSTAT was"
echo 'enabled previously with the -E_* "ENABLE" options by default. The -G_*' 
echo "options are meant for quick repetitive results without getting other system"
echo "information. Normally you should run the standard lsigetlunix.sh file without"
echo "a -G_* option to provide as much info as possible. (3ware Only)"
echo ""
echo "If there are competing comments the lowest variable number wins."
echo "If there are contradictory options the lowest variable number with the"
echo "option order listed in the help wins. Valid combinations would be;"
echo "-D or -D with -B or -Q any -E_* or -G_* option by itself or in conjunction"
echo "with a -D and -B/-Q option. -E_* is allowed with -D but has no effect as" 
echo "there is no working directory created."
echo ""
echo "Monitor Mode = Runs the standard capture script and then remains resident"
echo 'logging "show diag" approx. every 24 hours and also monitors for three' 
echo "specific AEN's (Controller Reset/Degraded Array/Rebuild Started). If any"
echo 'of these are encountered a final "show diag" will be done and the script' 
echo "will finish normally. Use to capture the internal printlog/buf prior to"
echo "the buffer being overwritten. Run a standard capture after Monitor Mode completes. (3ware Only)"
echo ""
echo "MRWA = MegaRAID Work Around - Limits the MegaCli(64) commands that are run."
echo "MegaCli has been seen to hang in some cases when running the 92xx controllers with"
echo "pre 4.1.1 FW and/or driver versions. Currently this switch bypasses the encinfo & adplilog"
echo "parameters. Instead of using this switch it is recommended to upgrade your code as this"
echo "work around is not always 100% effective. See the troubleshooting section for more information."
echo ""
echo "Trouble Shooting Script Issues -"
echo ""
echo "I. Ubuntu 9.04"
echo "sudo ./lsigetlunix.sh -D -Q"
echo "Tue Sep 22 17:06:32 PDT 2009"
echo "export: 3: 22: bad variable name"
echo ""
echo "Run;"
echo "sudo bash ./lsigetlunix.sh -D -Q"
echo ""
echo "II. Script hangs with MegaRAID Controller"
echo ""
echo "If you are positive the script is hung, CTRL-C the process, wait 3 minutes."
echo "If the prompt doesn't come back kill the term window, do a ps -ea, note the"
echo "# of any lsigetlunix.sh or MegaCli(64) processes. Do a kill -9 process-number"
echo "for each process. If any can't be killed, wait 3 minutes, there is a 180 second"
echo "timeout on MegaCli. Upgrade your driver/fw/capture script to the latest version and"
echo "try again. If you cant upgrade or if you still have problems try the -MRWA switch."
echo "If you still have problems manually zip the subdirectory structure and "
echo "email it to your support rep."
echo ""
echo "III. You get an error when running the MegaCli(64)left in the working directory."
#cho ".................................................||................................................."
echo "OSSpecificInitialize: Failed to load libsysfs.so.2.0.1 Please ensure that libsfs is present in the"
echo "system. The dependent library libsysfs.so.2.0.1 not available. Please contact LSI for distribution"
echo "of the package." 
echo "User specified controller is not present."
echo "Failed to get CpController object."
echo ""
echo "Install the private library found in the working directory; rpm -ihv Lib_Utils-1.00-05.noarch.rpm"
echo ""
echo "Recommended Code Set/Release Versions"
echo ""
echo "3ware-"
echo ""
echo "This script should run with any release between 7.6.0 & 10.0 on the 7k, 8k & 9k family of"
echo "controllers. If you are running an earlier Code Set you can still run this script as it also"
echo "captures system information. If you are using a latter Code Set you should obtain"
echo "the latest script file set at the following link; http://www.3ware.com/KB/article.aspx?id=12278"	 
echo ""
echo "HOWEVER - It is recommended to update to the latest code base in general."
echo "10.0 utilities are backwards compatible to 7xxx, 8xxx, 95xx and 96xx controllers."
echo "10.0 drivers are for 6Gb controllers ONLY."
echo "10.0 firmware is for 6Gb controllers ONLY."
echo "9.5.3 drivers are backwards compatible to 95xx and 96xx controllers."
echo "9.5.3 firmware is only compatible with 96xx controllers."
echo ""
echo "97xx - 5.08.00.008FW(10.0) for 9750 & 10.0 utilities & drivers"
echo "96xx - Highly Recommend 4.10.00.007FW(9.5.3) for 9690SA/9650SE & 9.5.3 utilities & drivers"
echo "9550/9590 - Highly Recommend 3.08.00.029FW(9.4.3) & 9.5.3 utilities & drivers"
echo "9500S - Highly Recommend 2.08.00.009FW(9.3.0.8), use 9.5.3 utilities & drivers"
echo "7/8xxx - Require 1.05.00.068FW(7.7.1), use 7.7.1 or latest OS included drivers & 9.5.3 utilities"
echo ""
echo "3ware Drivers/FW/Utilities/Docs"
echo "http://www.3ware.com/support/support.asp"
echo ""
echo "MegaRAID -"
echo ""
echo "This script should run with any release between 3.1 & 4.3 on the 82xx, 83xx, 84xx, 87xx,"
echo "88xx & 92xx family of controllers. If you are running an earlier Code Set you can still run"
echo "this script as it also captures system information. If you are using a latter Code Set you" 
echo "should obtain the latest script file set at the following link;" 
echo "http://www.3ware.com/KB/article.aspx?id=12278"	 
echo ""
echo "HOWEVER - It is recommended to update to the latest code base in general."
echo "4.3 utilities are backwards compatible to 82xx, 83xx, 84xx, 87xx, 88xx, and 92xx controllers."
echo "4.3 drivers are backwards compatible to 83xx, 84xx, 87xx, 88xx, and 92xx controllers."
echo "4.3 firmware is only compatible with 92xx controllers."
echo ""
echo "HBA/MegaRAID Drivers/FW/Utilities/Docs"
echo "http://www.lsichannelgateway.com/ChannelDownloads/Default.aspx"
echo ""
echo "Check the ftp site for code updates as well, the MegaRAID Web site updates lag sometimes."
echo "FTP Site - 3ware/HBA/MegaRAID"
echo "ftp0.lsil.com"
echo "User:tsupport"
echo "Password:tsupport"
echo "/outgoing_perm/Official_MegaRAID_Releases/"
echo ""
echo "HBA -"
echo ""
echo "This script should run with any LSI HBA using an mpt based driver."
echo ""
echo "Capture Script Version: $Capture_Script_Version"
echo ""
date '+%H:%M:%S.%N'
exit
fi
	

###########################################################################################################################
# Comment check
###########################################################################################################################

if [ "$TWPROMPTFORCOMMENT" != "NO" ] ; then


#Update on Code Set Change
#cho ".................................................||................................................."
echo ""
echo '"./lsigetlunix.sh -H" provides a help screen.'
echo ""
echo "To associate a user comment with this data capture session pass the comment as a variable."
#echo "comment as a variable." 
echo ""						  
echo "Example;"
echo './lsigetlunix.sh "Before upgrade from 9.3.0.3 to 9.5.3 code set."'   
echo ""
echo 'NOTE: Noncontiguous strings must be in double quotes "My Comments".' 	  
echo ""
echo ""
# no read -r in sh
GetKeystroke () { 
trap "" 2 3 
oldSttySettings=`stty -g` 
stty -echo raw 
echo "`dd count=1 2> /dev/null`" 
stty $oldSttySettings 
trap 2 3 
} 
 
keyStroke="" 
while [ "$keyStroke" != "C" ] 
do 

if [ "$keyStroke" = "Q" ] ; then
date '+%H:%M:%S.%N'
exit
fi

echo "Type C to continue or Q to Quit." 
echo "...................................................................................................."
keyStroke=`GetKeystroke` 
done
# no read -r in sh

fi


###########################################################################################################################
# Set architecture, i.e. check to see if 64-bit or 32 bit
###########################################################################################################################

if [ `uname -m | $grep 64` ] ; then
Arch32or64=64
else
Arch32or64=32
fi

###########################################################################################################################
# Clean up
###########################################################################################################################

if [ -d ./3rdpartylibs ] ; then
rm -rf ./3rdpartylibs
fi

for i in LGPLLicenseV2.txt libsysfs.so.2.0.1 ApacheLicenseV2.txt cliVmWare.conf libcrypto.so.0.9.7 libpegclient.so.1 libpegcommon.so.1 libpegconfig.so.1 libpegexportserver.so.1 libpeglistener.so.1 libpegprovider.so.1 libpegslp_client.so.1 libssl.so.0.9.7 libxerces-c.so.28.0 NOTICE OpenPegasusLicense.txt OpenPegasusNOTICE.txt OpenSSLLicense.txt server.cert server.key ssl.rnd CtDbg.log MegaSAS.log CmdTool.log lsut Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt cversions_3w.txt cversions_MR.txt cversions_HBA.txt create freebsd_MegaCli freebsd_tw_cli.32 freebsd_tw_cli.64 linux_lsut.32 linux_lsut.64 linux_MegaCli linux_MegaCli64 linux_tw_cli.32 linux_tw_cli.64 macos_tw_cli.32 sco_MegaCli solaris_lsut.i386 solaris_lsut.sparc solaris_MegaCli solaris_tw_cli.32 vmware_MegaCli vmware_tw_cli.esx35 vmware_tw_cli.esx40 vmware_tw_cli.esxi40 ; do
if [ -e ./$i ] ; then
rm -f ./$i
fi
done

if [ "$OS_LSI" != "linux" ] ; then
rm -f ./Lib_Utils-1.00-07.noarch.rpm
rm -f ./Lib_Utils2-1.00-01.noarch.rpm
fi

###########################################################################################################################
# Unpack files
###########################################################################################################################

if [ -e ./all_cli ] ; then
gunzip < all_cli | tar xvf - > /dev/null 2>&1
fi

###########################################################################################################################
# Rename appropriate 3ware cli based on OS type
###########################################################################################################################

if [ "$OS_LSI" = "linux" ] ; then
if [ "$Arch32or64" = "64" ] ; then
mv -f linux_tw_cli.64 tw_cli
fi
if [ "$Arch32or64" = "32" ] ; then
mv -f linux_tw_cli.32 tw_cli
fi
fi

if [ "$OS_LSIm" = "vmware_esx35" ] ; then
mv -f vmware_tw_cli.esx35 tw_cli
fi

if [ "$OS_LSIm" = "vmware_esx40" ] ; then
mv -f vmware_tw_cli.esx40 tw_cli
fi

if [ "$OS_LSIm" = "vmware_esxi40" ] ; then
mv -f vmware_tw_cli.esxi40 tw_cli
fi

if [ "$OS_LSI" = "freebsd" ] ; then
if [ "$Arch32or64" = "64" ] ; then
mv -f freebsd_tw_cli.64 tw_cli
fi
if [ "$Arch32or64" = "32" ] ; then
mv -f freebsd_tw_cli.32 tw_cli
fi
fi

# Only 32bit CLI as of 10.1
if [ "$OS_LSI" = "macos" ] ; then
mv -f macos_tw_cli.32 tw_cli
fi

if [ "$OS_LSI" = "solaris" ] ; then
mv -f solaris_tw_cli.32 tw_cli
fi

###########################################################################################################################
# MegaRAID MegaCLI  - Load appropriate LINUX libraries
###########################################################################################################################

if [ "$OS_LSI" = "linux" ] ; then
cp 3rdpartylibs/x86_64/libsysfs.so.2.0.1 .
cp 3rdpartylibs/LGPLLicenseV2.txt .
if [ "$Arch32or64" = "64" ] ; then
LD_PRELOAD=libsysfs.so.2.0.1
LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH
fi
if [ "$Arch32or64" = "32" ] ; then
cp 3rdpartylibs/libsysfs.so.2.0.1 .
cp 3rdpartylibs/LGPLLicenseV2.txt .
LD_PRELOAD=libsysfs.so.2.0.1
LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH
fi
fi

###########################################################################################################################
# Rename appropriate MegaRAID cli based on OS type
###########################################################################################################################

if [ "$OS_LSI" = "linux" ] ; then
if [ "$Arch32or64" = "64" ] ; then
mv -f linux_MegaCli64 MegaCli64
MCLI_NAME=MegaCli64
fi
if [ "$Arch32or64" = "32" ] ; then
mv -f linux_MegaCli MegaCli
MCLI_NAME=MegaCli
fi
fi

if [ "$OS_LSIm" = "vmware_esx35" ] ; then
mv -f vmware_MegaCli MegaCli
MCLI_NAME=MegaCli
fi

if [ "$OS_LSIm" = "vmware_esx40" ] ; then
mv -f vmware_MegaCli MegaCli
MCLI_NAME=MegaCli
fi

if [ "$OS_LSIm" = "vmware_esxi40" ] ; then
mv -f vmware_MegaCli MegaCli
MCLI_NAME=MegaCli
fi

if [ "$OS_LSI" = "freebsd" ] ; then
mv -f freebsd_MegaCli MegaCli
MCLI_NAME=MegaCli
fi

# Not supported as of 4.3
#if [ "$OS_LSI" = "macos" ] ; then
#if [ "$Arch32or64" = "64" ] ; then
#mv -f macos_MegaCli MegaCli
#MCLI_NAME=MegaCli
#fi
#if [ "$Arch32or64" = "32" ] ; then
#mv -f macos_MegaCli MegaCli
#MCLI_NAME=MegaCli
#fi
#fi

if [ "$OS_LSI" = "solaris" ] ; then
mv -f solaris_MegaCli MegaCli
MCLI_NAME=MegaCli
fi



###########################################################################################################################
# Extract appropriate lsiutil based on OS type
###########################################################################################################################

if [ "$OS_LSI" = "linux" ] ; then
if [ "$Arch32or64" = "64" ] ; then
mv linux_lsut.64 lsut
fi
if [ "$Arch32or64" = "32" ] ; then
mv linux_lsut.32 lsut
fi
fi

if [ "$OS_LSI" = "solaris" ] ; then
if [ "$Arch32or64" = "32" ] ; then
mv solaris_lsut.i386 lsut
fi
fi


###########################################################################################################################
# Use the bundled tw_cli, if it doesn't work try the existing tw_cli.
###########################################################################################################################


./tw_cli help > /dev/null 2>&1
if [ "$?" -ne "0" ]; then
#Bundled tw_cli didn't execute or driver not loaded
tw_cli_Bundled_work=NO
else
#Bundled tw_cli executed
tw_cli_Bundled_work=YES

fi

if [ "$tw_cli_Bundled_work" = "YES" ]; then
./tw_cli show | $grep "No controller found" > /dev/null 2>&1
if [ "$?" -eq "0" ]; then
#Bundled tw_cli didn't work or driver not loaded
tw_cli_Bundled_work=NO
else
#Bundled tw_cli worked
tw_cli_Bundled_work=YES

fi
fi

###########################################################################################################################
# Check existing version 
###########################################################################################################################

{ tw_cli help > /dev/null 2>&1; } 2>/dev/null
if [ "$?" -eq "0" ]; then
#Existing tw_cli present
tw_cli_Existing=YES
else
#Existing tw_cli not present
tw_cli_Existing=NO
fi

if [ "$tw_cli_Existing" = "YES" ]; then
	tw_cli show 2>&1 | $grep "No controller found" > /dev/null 2>&1
	if [ "$?" -eq "0" ]; then
	#Existing tw_cli didn't work or driver not loaded
	tw_cli_Existing_work=NO
	else
	#Existing tw_cli worked
	tw_cli_Existing_work=YES
	fi
fi

if [ "$tw_cli_Bundled_work" = "YES" ]; then 
CLI_LOCATION=./
tw_cli_Functional=YES
	else
	if [ "$tw_cli_Existing_work" = "YES" ]; then 
	CLI_LOCATION=
	tw_cli_Functional=YES
		else
	        export	tw_cli_Functional=NO
		
	fi
fi







###########################################################################################################################
# Use the bundled MegaCli, if it doesn't work try the existing MegaCli
###########################################################################################################################
if [ "$OS_LSI" != "macos" ] ; then

./$MCLI_NAME adpcount nolog | $grep "Controller Count:" > /dev/null 2>&1
if [ "$?" -eq "0" ]; then
#Bundled cli executed
mcli_Bundled_work=YES
else
#Bundled cli did not execute
mcli_Bundled_work=NO
fi


if [ "$mcli_Bundled_work" = "YES" ]; then
./$MCLI_NAME adpcount nolog | $grep "Controller Count: 0." > /dev/null 2>&1
if [ "$?" -eq "0" ]; then
#Bundled cli didn't work, driver not loaded or no MegaRAID SAS Adapters
mcli_Bundled_work=NO
else
#Bundled cli worked
mcli_Bundled_work=YES
fi
fi

###########################################################################################################################
# Check existing version - Only checks for MegaCli in path, doesn't look in /opt/MegaRAID/MegaCli
###########################################################################################################################

{ $MCLI_NAME adpcount nolog | $grep "Controller Count:" > /dev/null 2>&1; } 2>/dev/null
if [ "$?" -eq "0" ]; then
#Existing cli present
mcli_Existing=YES
else
#Existing cli not present
mcli_Existing=NO
fi

if [ "$mcli_Existing" = "YES" ]; then
	$MCLI_NAME adpcount nolog | $grep "Controller Count: 0." > /dev/null 2>&1
	if [ "$?" -eq "0" ]; then
	#Existing cli didn't work or driver not loaded
	mcli_Existing_work=NO
	else
	#Existing cli worked
	mcli_Existing_work=YES
	fi
fi

if [ "$mcli_Bundled_work" = "YES" ]; then 
MCLI_LOCATION=./
mcli_Functional=YES
	else
	if [ "$mcli_Existing_work" = "YES" ]; then 
	MCLI_LOCATION=
	mcli_Functional=YES
		else
	        export	mcli_Functional=NO
		
	fi
fi

# Return if MacOS
fi
###########################################################################################################################
# Use the bundled lsutil
###########################################################################################################################
NO_LSI_HBAs=YES
if [ "$OS_LSI" != "freebsd" ] ; then
if [ "$OS_LSI" != "vmware_esx35" ] ; then
if [ "$OS_LSI" != "vmware_esx40" ] ; then
if [ "$OS_LSI" != "vmware_esxi40" ] ; then
if [ "$OS_LSI" != "macos" ] ; then
if [ "$OS_LSI" != "sco" ] ; then

./lsut 0 | $grep "Chip Vendor" > /dev/null 2>&1
if [ "$?" -eq "0" ]; then
#HBAs present
NO_LSI_HBAs=NO
else
#HBAs NOT present
NO_LSI_HBAs=YES
fi

fi
fi
fi
fi
fi
fi

###########################################################################################################################
# IF tw_cli and MegaCli not functional
###########################################################################################################################
	
if [ "$tw_cli_Functional" = "NO" ]; then
	if [ "$mcli_Functional" = "NO" ]; then
		if [ "$NO_LSI_HBAs" = "YES" ]; then
### 
#cho ".................................................||................................................."
echo "...................................................................................................."
echo "################## No CLI installed, or CLI incompatible -- CLI will not be used. ##################"
echo "################################################ OR ################################################"
echo "################# You do not have root privileges which are required to run tw_cli. ################"
echo ""
echo '"./lsigetlunix.sh -H" provides a help screen.'
echo ""
###########################################################################################################################
# Done with MegaCli!
###########################################################################################################################
LD_PRELOAD=
LD_LIBRARY_PATH=
###########################################################################################################################
# Clean up
###########################################################################################################################

if [ -d ./3rdpartylibs ] ; then
rm -rf ./3rdpartylibs
fi

for i in LGPLLicenseV2.txt libsysfs.so.2.0.1 ApacheLicenseV2.txt cliVmWare.conf libcrypto.so.0.9.7 libpegclient.so.1 libpegcommon.so.1 libpegconfig.so.1 libpegexportserver.so.1 libpeglistener.so.1 libpegprovider.so.1 libpegslp_client.so.1 libssl.so.0.9.7 libxerces-c.so.28.0 NOTICE OpenPegasusLicense.txt OpenPegasusNOTICE.txt OpenSSLLicense.txt server.cert server.key ssl.rnd CtDbg.log MegaSAS.log CmdTool.log lsut Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt cversions_3w.txt cversions_MR.txt cversions_HBA.txt create freebsd_MegaCli freebsd_tw_cli.32 freebsd_tw_cli.64 linux_lsut.32 linux_lsut.64 linux_MegaCli linux_MegaCli64 linux_tw_cli.32 linux_tw_cli.64 macos_tw_cli.32 sco_MegaCli solaris_lsut.i386 solaris_lsut.sparc solaris_MegaCli solaris_tw_cli.32 vmware_MegaCli vmware_tw_cli.esx35 vmware_tw_cli.esx40 vmware_tw_cli.esxi40 ; do
if [ -e ./$i ] ; then
rm -f ./$i
fi
done

if [ "$OS_LSI" != "linux" ] ; then
rm -f ./Lib_Utils-1.00-07.noarch.rpm
rm -f ./Lib_Utils2-1.00-01.noarch.rpm
fi


	if [ "$TWGETBATCHMODE" != "BATCH" ] ; then 
	
# no read -r in sh
GetKeystroke () { 
trap "" 2 3 
oldSttySettings=`stty -g` 
stty -echo raw 
echo "`dd count=1 2> /dev/null`" 
stty $oldSttySettings 
trap 2 3 
} 
 
keyStroke="" 
while [ "$keyStroke" != "C" ] 
do 

if [ "$keyStroke" = "Q" ] ; then
date '+%H:%M:%S.%N'
exit
fi

echo "Type C to continue or Q to Quit." 
echo "...................................................................................................."
keyStroke=`GetKeystroke` 
done
# no read -r in sh

	fi
	fi
		fi
fi




###########################################################################################################################
# Create unique file/subdirectory name
###########################################################################################################################

if [ "$OS_LSI" = "linux" ]; then tw_host=$HOSTNAME; fi
if [ "$OS_LSI" = "vmware" ]; then tw_host=$HOSTNAME; fi
if [ "$OS_LSI" = "freebsd" ]; then tw_host=$HOST; fi
if [ "$OS_LSI" = "macos" ]; then tw_host=$HOSTNAME; fi
if [ "$OS_LSI" = "solaris" ]; then tw_host=$hostName; fi

tw_hostname=`echo $tw_host | cut -d. -f1`

todayDate=`date '+DATE:%m%d%y' | cut -d: -f2`
currentTime=`date '+TIME:%H%M%S' | cut -d: -f2`

if [ "$TWGETPARTIALMODE" = "STANDARD" ]; then TWdescriptor=lsi; fi
if [ "$TWGETPARTIALMODE" = "G_AEC" ]; then TWdescriptor=AEC; fi
if [ "$TWGETPARTIALMODE" = "G_DPMSTAT" ]; then TWdescriptor=DPMSTAT; fi
if [ "$TWGETPARTIALMODE" = "G_AEC_DPMSTAT" ]; then TWdescriptor=AEC_DPMSTAT; fi
if [ "$TWGETMONITORMODE" = "MONITOR" ]; then TWdescriptor=MONITOR; fi

fileName=$TWdescriptor.$OS_LSI.$tw_hostname.$todayDate.$currentTime

###########################################
# 3W - Not required for Enable Feature switches
###########################################
if [ "$TWGETPARTIALMODE" != "E_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "E_AEC" ]; then
if [ "$TWGETPARTIALMODE" != "E_AEC_DPMSTAT" ]; then
#

mkdir $fileName
mkdir $fileName/script_workspace
mkdir $fileName/3ware
mkdir $fileName/MegaRAID
mkdir $fileName/MegaRAID/FWTermLog
mkdir $fileName/HBA

if [ "$TWPRINTFILENAME" = "YES" ]; then echo $fileName.tar.gz >> LSICAPTUREFILES.TXT; fi



###########################################################################################################################
# 3W - Rename any old AEC files
###########################################################################################################################
for i in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 ; do #Support for Controller IDs 0-15
	if [ -e evtcapture_c$i.dat ]; then OLD_EVT_CAP_EXIST=YES > /dev/null 2>&1
	fi	

	if [ "$OLD_EVT_CAP_EXIST" = "YES" ]; then 
	if [ ! -d PreExisting_AEC_$fileName ]; then mkdir PreExisting_AEC_$fileName ; fi	
	fi

	if [ -e evtcapture_c$i.dat ]; then mv evtcapture_c$i.dat PreExisting_AEC_$fileName > /dev/null 2>&1
	fi

done

###########################################################################################################################
# 3W - For G_*
# Disabling and Getting Advanced Event Capture (AEC) IF Enabled
# Advanced Event Capture must be first or the log gets filled with IOCTLs
###########################################################################################################################
if [ "$TWGETPARTIALMODE" != "STANDARD" ]; then
if [ "$TWGETPARTIALMODE" != "G_DPMSTAT" ]; then

for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
if $CLI_LOCATION$CLI_NAME /c$i show capture 2>/dev/null | $grep "  State =" > /dev/null 2>&1 ; then
	$CLI_LOCATION$CLI_NAME /c$i set capture=stop > /dev/null 2>&1	 
	$CLI_LOCATION$CLI_NAME /c$i get capture > /dev/null 2>&1
	$CLI_LOCATION$CLI_NAME /c$i set capture=disable > /dev/null 2>&1
	
	if [ ! -d ./$fileName/3ware/AEC ];then mkdir ./$fileName/3ware/AEC
	fi
	
	if [ -e evtcapture_c$i.dat ]; then mv evtcapture_c$i.dat ./$fileName/3ware/AEC > /dev/null 2>&1
	fi
	TW_ECHO_AEC=YES
fi
done

if [ "$TW_ECHO_AEC" = "YES" ]; then
echo "Disabling and Getting Advanced Event Capture (AEC) ....."
fi

###########################################
# Return for skipping G_* AEC Get
###########################################
fi
fi 
#

###########################################################################################################################
# 3W - Standard
# Disabling and Getting Advanced Event Capture (AEC) IF Enabled
# Advanced Event Capture must be first or the log gets filled with IOCTLs
###########################################################################################################################
if [ "$TWGETPARTIALMODE" != "G_AEC" ]; then
if [ "$TWGETPARTIALMODE" != "G_AEC_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "G_DPMSTAT" ]; then

for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
if $CLI_LOCATION$CLI_NAME /c$i show capture 2>/dev/null | $grep "  State = Enabled" > /dev/null 2>&1 ; then
	$CLI_LOCATION$CLI_NAME /c$i set capture=stop > /dev/null 2>&1	 
	$CLI_LOCATION$CLI_NAME /c$i get capture > /dev/null 2>&1
	$CLI_LOCATION$CLI_NAME /c$i set capture=disable > /dev/null 2>&1
	
	if [ ! -d ./$fileName/3ware/AEC ];then mkdir ./$fileName/3ware/AEC
	fi
	
	if [ -e evtcapture_c$i.dat ]; then mv evtcapture_c$i.dat ./$fileName/3ware/AEC > /dev/null 2>&1
	fi
	TW_ECHO_AEC=YES
fi
done

if [ "$TW_ECHO_AEC" = "YES" ]; then
echo "Disabling and Getting Advanced Event Capture (AEC) ....."
fi

###########################################
# 3W - Return for skipping Standard AEC Get
###########################################
fi  
fi 
fi
#


###########################################
# 3W - Return for skipping mkdir & Disable/Get AEC
###########################################
fi # E_AEC
fi # E_AEC_DPMSTAT
#

###########################################
# Not required for 
###########################################
if [ "$TWGETPARTIALMODE" != "G_AEC" ]; then
if [ "$TWGETPARTIALMODE" != "G_AEC_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "G_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "E_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "STANDARD" ]; then
#

###########################################################################################################################
# 3W - Clearing and Enabling Advanced Event Capture (AEC)
###########################################################################################################################

if [ "$tw_cli_Functional" != "NO" ]; then

echo "Clearing and Enabling Advanced Event Capture (AEC)..."
for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
if $CLI_LOCATION$CLI_NAME /c$i set capture=disable > /dev/null 2>&1; then	 
	$CLI_LOCATION$CLI_NAME /c$i set capture=enable numevents=150000 > /dev/null 2>&1 
	$CLI_LOCATION$CLI_NAME /c$i set capturemode=stopped > /dev/null 2>&1 
	$CLI_LOCATION$CLI_NAME /c$i set capture=start > /dev/null 2>&1
fi
done

fi

if [ "$tw_cli_Functional" = "NO" ]; then
#cho ".................................................||................................................."
echo "...................................................................................................."
echo "################## No CLI installed, or CLI incompatible -- CLI will not be used. ##################"
echo "################################################ OR ################################################"
echo "################# You do not have root privileges which are required to run tw_cli. ################"
echo ""
echo '"./lsigetlunix.sh -H" provides a help screen.'
echo ""
fi
###########################################
# Return for skipping Clear & Enable AEC
###########################################
fi # STANDARD
fi # E_DPMSTAT
fi # G_DPMSTAT
fi # G_AEC_DPMSTAT
fi # G_AEC
#

###########################################
# If E_AEC exit
###########################################
if [ "$TWGETPARTIALMODE" = "E_AEC" ]; then 
date '+%H:%M:%S.%N'

if [ -d ./3rdpartylibs ] ; then
rm -rf ./3rdpartylibs
fi

for i in libsysfs.so.2.0.1 CtDbg.log MegaSAS.log CmdTool.log lsut Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt cversions_3w.txt cversions_MR.txt cversions_HBA.txt cliVmWare.conf libpegclient.so.1 libpegcommon.so.1 libpegslp_client.so.1 OpenPegasusLicense.txt OpenPegasusNOTICE.txt OpenSSLLicense.txt server.cert server.key ssl.rnd create freebsd_MegaCli freebsd_tw_cli.32 freebsd_tw_cli.64 Lib_Utils-1.00-05.noarch.rpm linux_lsut.32 linux_lsut.64 linux_MegaCli linux_MegaCli64 linux_tw_cli.32 linux_tw_cli.64 macos_tw_cli.32 sco_MegaCli solaris_lsut.i386 solaris_lsut.sparc solaris_MegaCli solaris_tw_cli.32 vmware_MegaCli vmware_tw_cli.esx35 vmware_tw_cli.esx40 vmware_tw_cli.esxi40 ; do
if [ -e ./$i ] ; then
rm -f ./$i
fi
done

exit 
fi
#

###########################################
# Return for E_DPMSTAT
###########################################
fi # E_DPMSTAT
#

###########################################
# Not required for 
###########################################
if [ "$TWGETPARTIALMODE" != "G_AEC" ]; then
if [ "$TWGETPARTIALMODE" != "G_AEC_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "G_DPMSTAT" ]; then
if [ "$TWGETPARTIALMODE" != "STANDARD" ]; then
#

###########################################################################################################################
# Clearing and Enabling Disk Performance Monitoring Statistics (DPMSTAT)
###########################################################################################################################

if [ "$tw_cli_Functional" != "NO" ]; then

echo "Clearing and Enabling Disk Performance Monitoring Statistics (DPMSTAT)..."
for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
	if $CLI_LOCATION$CLI_NAME /c$i show pmstat 2>/dev/null | $grep "Instantaneous" > /dev/null 2>&1; then	 

		for l in $($CLI_LOCATION$CLI_NAME /c$i show | $grep ^p | $grep -v NOT-PRESENT | cut -b 2-4); do #Supports up to 999 Ports per Controller.
				$CLI_LOCATION$CLI_NAME /c$i/p$l set pmstat=clear type=ra > /dev/null 2>&1 
				$CLI_LOCATION$CLI_NAME /c$i/p$l set pmstat=clear type=lct > /dev/null 2>&1 
				$CLI_LOCATION$CLI_NAME /c$i/p$l set pmstat=clear type=ext > /dev/null 2>&1 
		done
	$CLI_LOCATION$CLI_NAME /c$i set pmstat=on > /dev/null 2>&1 
	fi
done

fi

if [ "$tw_cli_Functional" = "NO" ]; then
#cho ".................................................||................................................."
echo "...................................................................................................."
echo "################## No CLI installed, or CLI incompatible -- CLI will not be used. ##################"
echo "################################################ OR ################################################"
echo "################# You do not have root privileges which are required to run tw_cli. ################"
echo ""
echo '"./lsigetlunix.sh -H" provides a help screen.'
echo ""
fi

###########################################
# If E_DPMSTAT or E_AEC_DPMSTAT exit
###########################################
if [ "$TWGETPARTIALMODE" = "E_DPMSTAT" ]; then 
date '+%H:%M:%S.%N'

if [ -d ./3rdpartylibs ] ; then
rm -rf ./3rdpartylibs
fi

for i in libsysfs.so.2.0.1 CtDbg.log MegaSAS.log CmdTool.log lsut Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt cversions_3w.txt cversions_MR.txt cversions_HBA.txt cliVmWare.conf libpegclient.so.1 libpegcommon.so.1 libpegslp_client.so.1 OpenPegasusLicense.txt OpenPegasusNOTICE.txt OpenSSLLicense.txt server.cert server.key ssl.rnd create freebsd_MegaCli freebsd_tw_cli.32 freebsd_tw_cli.64 Lib_Utils-1.00-05.noarch.rpm linux_lsut.32 linux_lsut.64 linux_MegaCli linux_MegaCli64 linux_tw_cli.32 linux_tw_cli.64 macos_tw_cli.32 sco_MegaCli solaris_lsut.i386 solaris_lsut.sparc solaris_MegaCli solaris_tw_cli.32 vmware_MegaCli vmware_tw_cli.esx35 vmware_tw_cli.esx40 vmware_tw_cli.esxi40 ; do
if [ -e ./$i ] ; then
rm -f ./$i
fi
done

exit
fi
if [ "$TWGETPARTIALMODE" = "E_AEC_DPMSTAT" ]; then 
date '+%H:%M:%S.%N'

if [ -d ./3rdpartylibs ] ; then
rm -rf ./3rdpartylibs
fi

for i in libsysfs.so.2.0.1 CtDbg.log MegaSAS.log CmdTool.log lsut Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt cversions_3w.txt cversions_MR.txt cversions_HBA.txt cliVmWare.conf libpegclient.so.1 libpegcommon.so.1 libpegslp_client.so.1 OpenPegasusLicense.txt OpenPegasusNOTICE.txt OpenSSLLicense.txt server.cert server.key ssl.rnd create freebsd_MegaCli freebsd_tw_cli.32 freebsd_tw_cli.64 Lib_Utils-1.00-05.noarch.rpm linux_lsut.32 linux_lsut.64 linux_MegaCli linux_MegaCli64 linux_tw_cli.32 linux_tw_cli.64 macos_tw_cli.32 sco_MegaCli solaris_lsut.i386 solaris_lsut.sparc solaris_MegaCli solaris_tw_cli.32 vmware_MegaCli vmware_tw_cli.esx35 vmware_tw_cli.esx40 vmware_tw_cli.esxi40 ; do
if [ -e ./$i ] ; then
rm -f ./$i
fi
done

exit
fi
#

###########################################
# Return for skipping Clear & Enable DPMSTAT
###########################################
fi # STANDARD
fi # G_DPMSTAT
fi # G_AEC_DPMSTAT
fi # G_AEC
#


###########################################################################################################################
# PMSTAT Data Collection for G_*
###########################################################################################################################
if [ "$TWGETPARTIALMODE" != "E_AEC_DPMSTAT" ]; then 
if [ "$TWGETPARTIALMODE" != "E_AEC" ]; then 
if [ "$TWGETPARTIALMODE" != "E_DPMSTAT" ]; then 
if [ "$TWGETPARTIALMODE" != "STANDARD" ]; then 
if [ "$TWGETPARTIALMODE" != "G_AEC" ]; then


	for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
		if $CLI_LOCATION$CLI_NAME /c$i show pmstat 2>/dev/null | $grep "Performance Monitor:" > /dev/null 2>&1 ; then

		TW_ECHO_PMSTAT=YES

		if [ ! -d ./$fileName/3ware/PMSTAT ]; then mkdir ./$fileName/3ware/PMSTAT 
		fi

		$CLI_LOCATION$CLI_NAME /c$i set pmstat=off > /dev/null 2>&1 
		
		

		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i show pmstat type=inst................................" >> ./$fileName/3ware/PMSTAT/PMSTAT_INST_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show pmstat type=inst >> ./$fileName/3ware/PMSTAT/PMSTAT_INST_C$i.txt 2>&1

		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i show pmstat type=ra.................................." >> ./$fileName/3ware/PMSTAT/PMSTAT_RA_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show pmstat type=ra >> ./$fileName/3ware/PMSTAT/PMSTAT_RA_C$i.txt 2>&1


		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i show pmstat type=ext................................." >> ./$fileName/3ware/PMSTAT/PMSTAT_EXT_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show pmstat type=ext >> ./$fileName/3ware/PMSTAT/PMSTAT_EXT_C$i.txt 2>&1

		for l in $($CLI_LOCATION$CLI_NAME /c$i show | $grep ^p | $grep -v NOT-PRESENT | cut -b 2-4); do #Supports up to 999 Ports per Controller.
			#cho ".................................................||................................................."
			echo "............................../tw_cli /c$i/p$l show pmstat type=histdata.............................." >> ./$fileName/3ware/PMSTAT/PMSTAT_HISTDATA_C$i.txt
			$CLI_LOCATION$CLI_NAME /c$i/p$l show pmstat type=histdata >> ./$fileName/3ware/PMSTAT/PMSTAT_HISTDATA_C$i.txt 2>&1
					
			#cho ".................................................||................................................."
			echo "............................../tw_cli /c$i/p$l show pmstat type=lct..................................." >> ./$fileName/3ware/PMSTAT/PMSTAT_LCT_C$i.txt
			$CLI_LOCATION$CLI_NAME /c$i/p$l show pmstat type=lct >> ./$fileName/3ware/PMSTAT/PMSTAT_LCT_C$i.txt 2>&1

			#fi
		done
		fi
	done


if [ "$TW_ECHO_PMSTAT" = "YES" ]; then
echo "Disabling and Getting Disk Performance Monitoring Statistics (DPMSTAT) ....."
fi
###########################################
# Return for skipping DPMSTAT collection for G_*
###########################################
fi
fi
fi
fi
fi 
#

###########################################################################################################################
# PMSTAT Data Collection Standard
###########################################################################################################################
if [ "$TWGETPARTIALMODE" != "G_AEC_DPMSTAT" ]; then 
if [ "$TWGETPARTIALMODE" != "G_DPMSTAT" ]; then 
if [ "$TWGETPARTIALMODE" != "G_AEC" ]; then 



	for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
		if $CLI_LOCATION$CLI_NAME /c$i show pmstat 2>/dev/null | $grep "Performance Monitor: ON" > /dev/null 2>&1 ; then

		TW_ECHO_PMSTAT=YES

		if [ ! -d ./$fileName/3ware/PMSTAT ]; then mkdir ./$fileName/3ware/PMSTAT 
		fi

		$CLI_LOCATION$CLI_NAME /c$i set pmstat=off > /dev/null 2>&1 
		
		

		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i show pmstat type=inst................................" >> ./$fileName/3ware/PMSTAT/PMSTAT_INST_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show pmstat type=inst >> ./$fileName/3ware/PMSTAT/PMSTAT_INST_C$i.txt 2>&1

		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i show pmstat type=ra.................................." >> ./$fileName/3ware/PMSTAT/PMSTAT_RA_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show pmstat type=ra >> ./$fileName/3ware/PMSTAT/PMSTAT_RA_C$i.txt 2>&1


		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i show pmstat type=ext................................." >> ./$fileName/3ware/PMSTAT/PMSTAT_EXT_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show pmstat type=ext >> ./$fileName/3ware/PMSTAT/PMSTAT_EXT_C$i.txt 2>&1

		for l in $($CLI_LOCATION$CLI_NAME /c$i show | $grep ^p | $grep -v NOT-PRESENT | cut -b 2-4); do #Supports up to 999 Ports per Controller.
			#cho ".................................................||................................................."
			echo "............................../tw_cli /c$i/p$l show pmstat type=histdata.............................." >> ./$fileName/3ware/PMSTAT/PMSTAT_HISTDATA_C$i.txt
			$CLI_LOCATION$CLI_NAME /c$i/p$l show pmstat type=histdata >> ./$fileName/3ware/PMSTAT/PMSTAT_HISTDATA_C$i.txt 2>&1
					
			#cho ".................................................||................................................."
			echo "............................../tw_cli /c$i/p$l show pmstat type=lct..................................." >> ./$fileName/3ware/PMSTAT/PMSTAT_LCT_C$i.txt
			$CLI_LOCATION$CLI_NAME /c$i/p$l show pmstat type=lct >> ./$fileName/3ware/PMSTAT/PMSTAT_LCT_C$i.txt 2>&1

			#fi
		done
		fi
	done


if [ "$TW_ECHO_PMSTAT" = "YES" ]; then
echo "Disabling and Getting Disk Performance Monitoring Statistics (DPMSTAT) ....."
fi
###########################################
# Return for skipping DPMSTAT collection for standard
###########################################
fi
fi
fi
#




###########################################################################################################################
# Starting 3ware Controller Data Collection
###########################################################################################################################

# List of 3ware controller numbers
$CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3 > ./$fileName/script_workspace/controller_numbers.txt
if [ -s ./$fileName/script_workspace/controller_numbers.txt ] ; then
echo "Starting 3ware Controller Data Collection..."
fi
	for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
	#cho ".................................................||................................................."
	echo $fileName >> ./$fileName/3ware/Controller_C$i.txt
	echo "............................................/tw_cli show............................................" >> ./$fileName/3ware/Controller_C$i.txt
	$CLI_LOCATION$CLI_NAME show >> ./$fileName/3ware/Controller_C$i.txt 2>&1
	echo "......................................../tw_cli /c$i show all........................................" >> ./$fileName/3ware/Controller_C$i.txt
	$CLI_LOCATION$CLI_NAME /c$i show all >> ./$fileName/3ware/Controller_C$i.txt 2>&1
	echo "Collecting Controller Information for Controller C$i..."
	done

###########################################
# If G_* skip to the end
###########################################
if [ "$TWPARTIALCAP" != "YES" ]; then
#

	for i in $($CLI_LOCATION$CLI_NAME show | $grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
	echo "Collecting Unit Information for Controller C$i..."
	for k in $($CLI_LOCATION$CLI_NAME /c$i show | $grep ^u | cut -b 2-4); do #Supports up to 999 Units per Controller.
		#cho ".................................................||................................................."
		echo "....................................../tw_cli /c$i/u$k show all......................................." >> ./$fileName/3ware/Controller_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i/u$k show all >> ./$fileName/3ware/Controller_C$i.txt 2>&1

		#cho ".................................................||................................................."
		echo ".................................../tw_cli /c$i/u$k show writedpo....................................." >> ./$fileName/3ware/Controller_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i/u$k show writedpo >> ./$fileName/3ware/Controller_C$i.txt 2>&1
	done	


	echo "Collecting Port Information for Controller C$i..."
	echo "This may take a few minutes..."
	for l in $($CLI_LOCATION$CLI_NAME /c$i show | $grep ^p | $grep -v NOT-PRESENT | cut -b 2-4); do #Supports up to 999 Ports per Controller.
		#cho ".................................................||................................................."
		echo "....................................../tw_cli /c$i/p$l show all......................................." >> ./$fileName/script_workspace/px_show_all_c$i.txt
		$CLI_LOCATION$CLI_NAME /c$i/p$l show all >> ./$fileName/script_workspace/px_show_all_c$i.txt
	done

	if [ -e ./$fileName/script_workspace/px_show_all_c$i.txt ]; then 
		#cho ".................................................||................................................."
		echo ".............................................Disk Model............................................." >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Model =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo ".......................................SAS Only - Drive Type........................................" >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Drive Type =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo "...........................................Disk Firmware............................................" >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Firmware Version =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo "...........................................Disk Serial #............................................" >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Serial =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo "...........................................Disk Capacity............................................" >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Capacity =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		#cho ".................................................||................................................."
		echo ".......................................Disk Reallocated Sectors....................................." >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Reallocated Sectors =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo "..........................................Disk Temperature.........................................." >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Temperature =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo "..........................................Disk Link Speed..........................................." >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Link Speed =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		#cho ".................................................||................................................."
		echo "......................................SATA Only - NCQ Enabled......................................." >> ./$fileName/3ware/Controller_C$i.txt
		$grep "NCQ Enabled" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
		echo ".....................................SAS Only - Queuing Enabled....................................." >> ./$fileName/3ware/Controller_C$i.txt
		$grep "Queuing Enabled =" ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
	fi	
	


	#cho ".................................................||................................................."
	echo "................................../tw_cli /c$i show alarms reverse..................................." >> ./$fileName/3ware/Controller_C$i.txt
	$CLI_LOCATION$CLI_NAME /c$i show alarms reverse >> ./$fileName/3ware/Controller_C$i.txt 2>&1
		
	for CLI_ARG in rebuild rebuildrate rebuildmode verify verifyrate verifymode selftest forcedrivecacheon avmode lbareorder modepgctl phy iostat pmstat capture ; do
		#cho ".................................................||................................................."
		echo "....................................../tw_cli /c$i show $CLI_ARG......................................." >> ./$fileName/3ware/Controller_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i show $CLI_ARG >> ./$fileName/3ware/Controller_C$i.txt 2>&1
	done
	


	#cho ".................................................||................................................."
	echo "....................................../tw_cli /c$i/bbu show all......................................" >> ./$fileName/3ware/Controller_C$i.txt
	$CLI_LOCATION$CLI_NAME /c$i/bbu show all >> ./$fileName/3ware/Controller_C$i.txt 2>&1


	echo "Collecting /Cx/Ex Enclosure Information for Controller C$i..."	
	for j in $($CLI_LOCATION$CLI_NAME show | $grep ^/c$i/e | cut -d/ -f3 | cut -b 2-4); do #Supports up to 999 Enclosure IDs
		#cho ".................................................||................................................."
		echo "......................................./tw_cli /c$i/e$j show all......................................" >> ./$fileName/3ware/Controller_C$i.txt
		$CLI_LOCATION$CLI_NAME /c$i/e$j show all >> ./$fileName/3ware/Controller_C$i.txt 2>&1
	done



	echo "Collecting /Ex Enclosure Information for Controller C$i..."
	for j in $($CLI_LOCATION$CLI_NAME show | $grep ^e | cut -b 2-4); do  #Supports up to 999 Enclosure IDs 
	for k in $($CLI_LOCATION$CLI_NAME /e$j show | $grep ^e | cut -d/ -f2 | cut -b2-3); do #Supports up to 999 Controller IDs
	if [ "$k" = "$i" ]; then # To keep the output in sync with the script flow, otherwise /ex prints at the top of output file.
		#cho ".................................................||................................................."
		echo "...................................../tw_cli /e$j show protocol......................................" >> ./$fileName/3ware/Controller_C$i.txt
		$CLI_LOCATION$CLI_NAME /e$j show protocol >> ./$fileName/3ware/Controller_C$i.txt 2>&1
		echo "......................................./tw_cli /e$j show all......................................" >> ./$fileName/3ware/Controller_C$i.txt
		$CLI_LOCATION$CLI_NAME /e$j show all >> ./$fileName/3ware/Controller_C$i.txt 2>&1
	fi
	done
	done

	if [ -e ./$fileName/script_workspace/px_show_all_c$i.txt ]; then 
		cat ./$fileName/script_workspace/px_show_all_c$i.txt >> ./$fileName/3ware/Controller_C$i.txt
	fi	


	#cho ".................................................||................................................."
	echo "......................................../tw_cli /c$i show diag......................................." >> ./$fileName/3ware/Controller_C$i.txt
	echo ".........The diag output has been processed by strings in order to be viewable by GEDIT............." >> ./$fileName/3ware/Controller_C$i.txt
	echo "......................The degree symbol was deleted to maintain formatting.........................." >> ./$fileName/3ware/Controller_C$i.txt
	echo "..............................The unmodified output is available in ................................" >> ./$fileName/3ware/Controller_C$i.txt
	echo "............../$fileName/script_workspace/raw_diag_C$i.txt................." >> ./$fileName/3ware/Controller_C$i.txt
	echo "...................................................................................................." >> ./$fileName/3ware/Controller_C$i.txt
	#cho ".................................................||................................................."
	$CLI_LOCATION$CLI_NAME /c$i show diag > ./$fileName/script_workspace/raw_diag_C$i.txt 2>&1
	#strings was deleting the degree symbol and changing the format, tr deletes the symbol but maintains format
	cat ./$fileName/script_workspace/raw_diag_C$i.txt | tr -d ° | strings > ./$fileName/script_workspace/strings_diag_C$i.txt
	cat ./$fileName/script_workspace/strings_diag_C$i.txt >> ./$fileName/3ware/Controller_C$i.txt 2>&1

###########################################################################################################################
# 3ware Diag Output Error Checking
###########################################################################################################################


		if [ -e ./$fileName/script_workspace/strings_diag_C$i.txt ]; then 
		$grep "Check power cycles" ./$fileName/script_workspace/strings_diag_C$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo ".....................tw_cli /c$i show diag - contains Drive Power Cycle Checks......................." >> ./$fileName/3ware/Controller_C$i.txt
			echo ".If the power cycle number is increasing this usually signifies a power supply or backplane problem." >> ./$fileName/3ware/Controller_C$i.txt
			$grep "Check power cycles" ./$fileName/script_workspace/strings_diag_C$i.txt >> ./$fileName/3ware/Controller_C$i.txt
			echo "......................tw_cli /c$i show diag - contains Drive Power Cycle Checks......................" >> ./$fileName/3ware/diag_CPC_C$i.txt
			echo ".If the power cycle number is increasing this usually signifies a power supply or backplane problem." >> ./$fileName/3ware/diag_CPC_C$i.txt
			$grep "Check power cycles" ./$fileName/script_workspace/strings_diag_C$i.txt >> ./$fileName/3ware/diag_CPC_C$i.txt
					
			fi
		fi

		if [ -e ./$fileName/script_workspace/strings_diag_C$i.txt ]; then 
		egrep "Assert|.cpp" ./$fileName/script_workspace/strings_diag_C$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo ".............................tw_cli /c$i show diag - contains Asserts................................" >> ./$fileName/3ware/Controller_C$i.txt
			echo "..................This is evidence of a possible FW bug, contact your support rep!.................." >> ./$fileName/3ware/Controller_C$i.txt
			egrep "Assert|.cpp" ./$fileName/script_workspace/strings_diag_C$i.txt >> ./$fileName/3ware/Controller_C$i.txt
			echo ".............................tw_cli /c$i show diag - contains Asserts................................" >> ./$fileName/3ware/diag_Assert_C$i.txt
			echo "..................This is evidence of a possible FW bug, contact your support rep!.................." >> ./$fileName/3ware/diag_Assert_C$i.txt
			egrep "Assert|.cpp" ./$fileName/script_workspace/strings_diag_C$i.txt >> ./$fileName/3ware/diag_Assert_C$i.txt
					
			fi
		fi


#done for controller #ing i.e. $i
done

###########################################################################################################################
# 3ware Smartctl Data Collection if Smartctl is installed
# Start Linux Only Section for now
# Must test on other OS's
###########################################################################################################################

if [ -s ./$fileName/script_workspace/controller_numbers.txt ] ; then
if [ "$OS_LSI" = "linux" ] ; then 


smartctl -h > /dev/null 2>&1
if [ "$?" -eq "0" ] ; then
echo "Starting 3ware Smartctl Data Collection..."
if [ ! -d ./$fileName/3ware/SMARTCTL ] ; then mkdir ./$fileName/3ware/SMARTCTL ; fi

for i in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 ; do #Supports up to 16 character device node entries
	for j in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 ; do #Supports up to 24 Disks per controller, smartctl limitation still 16 as of 5.39??
#		#cho ".................................................||................................................."
		smartctl -i -d 3ware,$j /dev/twa$i | egrep "START OF INFORMATION SECTION|Serial number:" 1>/dev/null # Test for instances that exist
		if [ "$?" -eq "0" ] ; then
		#cho ".................................................||................................................."
		echo "..........Port $j, TWA # is in order of Controller number, not equal too, lowest to highest.........." >> ./$fileName/3ware/SMARTCTL/TWA$i.txt 2>&1
		echo "..................................smartctl -a -d 3ware,$j /dev/twa$i.................................." >> ./$fileName/3ware/SMARTCTL/TWA$i.txt 2>&1
		smartctl -a -d 3ware,$j /dev/twa$i >> ./$fileName/3ware/SMARTCTL/TWA$i.txt 2>&1
		fi
	done
done

for i in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 ; do #Supports up to 16 character device node entries
	for j in 0 1 2 3 4 5 6 7 8 9 10 11 ; do #Supports up to 12 Disks per controller, max port count for 7/8xxx controllers
#		#cho ".................................................||................................................."
		smartctl -i -d 3ware,$j /dev/twe$i | egrep "START OF INFORMATION SECTION|Serial number:" 1>/dev/null # Test for instances that exist
		if [ "$?" -eq "0" ]; then
		#cho ".................................................||................................................."
		echo "..........Port $j, TWE # is in order of Controller number, not equal too, lowest to highest.........." >> ./$fileName/3ware/SMARTCTL/TWE$i.txt 2>&1
		echo "..................................smartctl -a -d 3ware,$j /dev/twe$i.................................." >> ./$fileName/3ware/SMARTCTL/TWE$i.txt 2>&1
		smartctl -a -d 3ware,$j /dev/twe$i >> ./$fileName/3ware/SMARTCTL/TWE$i.txt 2>&1
		fi
	done
done

# return for smartctl -h
fi
# return for OS_LSI=linux
fi
# return for if controller_numbers.txt greater than 0 bytes
fi
#
# End Linux Only Section
#

###########################################################################################################################
# LSI HBA 
###########################################################################################################################
if [ "$NO_LSI_HBAs" != "YES" ] ; then 
echo "Starting the LSI HBA Data Collection..."

for i in $(./lsut 0 | $grep -A1 "Chip Vendor/Type/Rev" | $grep LSI | cut -d. -f1); do # Support for unlimited HBAs

#cho ".................................................||................................................."
echo $fileName >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo "..............................................LSIUtil..............................................." >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
./lsut 0 >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo "" >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo ".............................................LSIUtil 1.............................................." >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
./lsut -p $i 1 >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo ".............................................LSIUtil 8.............................................." >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
./lsut -p $i 8 >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo ".............................................LSIUtil 16............................................." >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
./lsut -p $i 16 >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo ".............................................LSIUtil 42............................................." >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
./lsut -p $i 42 >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
echo ".............................................LSIUtil 47............................................." >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
./lsut -p $i 47 >> ./$fileName/HBA/1_8_16_42_47_hba$i.txt
#echo "............................................LSIUtil 100............................................." >> ./$fileName/HBA/100_hba$i.txt
./lsut -p $i 100 >> ./$fileName/HBA/100_hba$i.txt >> ./$fileName/HBA/100_hba$i.txt

echo "REM lsipage is an LSI internal utility" > ./$fileName/HBA/100_hba$i.bat
echo "copy 100_hba$i.txt 100_hba$i" >> ./$fileName/HBA/100_hba$i.bat
echo "lsipage -h -i 100_hba$i" >> ./$fileName/HBA/100_hba$i.bat
echo "del 100_hba$i" >> ./$fileName/HBA/100_hba$i.bat
done

#Only show all with more than 1 adapter
./lsut 0 | $grep "1 MPT Ports found" > /dev/null
if [ "$?" -ne "0" ] ; then

#cho ".................................................||................................................."
echo $fileName >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo "..............................................LSIUtil..............................................." >> ./$fileName/HBA/1_8_16_42_47_all.txt
./lsut 0 >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo "" >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo ".............................................LSIUtil 1.............................................." >> ./$fileName/HBA/1_8_16_42_47_all.txt
./lsut 1 >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo ".............................................LSIUtil 8.............................................." >> ./$fileName/HBA/1_8_16_42_47_all.txt
./lsut 8 >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo ".............................................LSIUtil 16............................................." >> ./$fileName/HBA/1_8_16_42_47_all.txt
./lsut 16 >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo ".............................................LSIUtil 42............................................." >> ./$fileName/HBA/1_8_16_42_47_all.txt
./lsut 42 >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo ".............................................LSIUtil 47............................................." >> ./$fileName/HBA/1_8_16_42_47_all.txt
./lsut 47 >> ./$fileName/HBA/1_8_16_42_47_all.txt
echo "............................................LSIUtil 100............................................." >> ./$fileName/HBA/100_all.txt
./lsut 100 >> ./$fileName/HBA/100_all.txt

echo "REM lsipage is an LSI internal utility" > ./$fileName/HBA/100_all.bat
echo "copy 100_all.txt 100_all" >> ./$fileName/HBA/100_all.bat
echo "lsipage -h -i 100_all" >> ./$fileName/HBA/100_all.bat
echo "del 100_all" >> ./$fileName/HBA/100_all.bat

fi


fi

###########################################################################################################################
# Starting MegaRAID Controller Data Collection
###########################################################################################################################
if [ "$OS_LSI" != "macos" ] ; then

#MegaRAID Adapter #'s
$MCLI_LOCATION$MCLI_NAME adpcount nolog | $grep ^Controller | cut -d: -f2 | cut -d. -f1 | tr -d [:blank:] > ./$fileName/script_workspace/num_mraid_adapters.txt
if [ -n `cat ./$fileName/script_workspace/num_mraid_adapters.txt` ] ; then
for i in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 ; do
if [ "$i" -lt "`cat ./$fileName/script_workspace/num_mraid_adapters.txt`" ] ; then echo $i >> ./$fileName/script_workspace/adapter_numbers.txt ; fi
done
fi

# Make sure at least 1 MegaRAID Adapter is identified
if [ -f ./$fileName/script_workspace/adapter_numbers.txt ] ; then

for i in `cat ./$fileName/script_workspace/adapter_numbers.txt` ; do #Support for all adapter IDs 

#MegaRAID Logical Disk #'s
$MCLI_LOCATION$MCLI_NAME ldgetnum a$i nolog | $grep Number | cut -d: -f2 | tr -d [:blank:] > ./$fileName/script_workspace/num_lds_A$i.txt
if [ -n `cat ./$fileName/script_workspace/num_lds_A$i.txt` ] ; then
for j in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255; do #Supports up to 256 LDs
if [ "$j" -lt "`cat ./$fileName/script_workspace/num_lds_A$i.txt`" ] ; then echo $j >> ./$fileName/script_workspace/ld_numbers_A$i.txt ; fi
done
fi

if [ "$LimitMegaCliCMDs" != "YES" ] ; then 
#MegaRAID Enclosure #'s
$MCLI_LOCATION$MCLI_NAME encinfo a$i nolog | $grep "Device ID" | cut -d: -f2 | tr -d [:blank:] >> ./$fileName/script_workspace/enclosure_numbers_A$i.txt
fi

#MegaRAID phy #'s
$MCLI_LOCATION$MCLI_NAME phyerrorcounters a$i nolog | $grep "Phy No:" | cut -d: -f2 | tr -d [:blank:] >> ./$fileName/script_workspace/phy_numbers_A$i.txt

#MegaRAID PDList data, used for grepping.
echo $fileName >> ./$fileName/MegaRAID/PDList_A$i.txt 2>&1
$MCLI_LOCATION$MCLI_NAME pdlist a$i nolog >> ./$fileName/MegaRAID/PDList_A$i.txt 2>&1

#MegaRAID Disk Device ID #'s
$grep -e "Device Id:" ./$fileName/MegaRAID/PDList_A$i.txt | cut -d" " -f3 >> ./$fileName/script_workspace/disk_dev_id_numbers_A$i.txt

#MegaRAID adpallinfo data, used for grepping.
echo $fileName >> ./$fileName/MegaRAID/AdpAllInfo_A$i.txt 2>&1
$MCLI_LOCATION$MCLI_NAME adpallinfo a$i nolog >> ./$fileName/MegaRAID/AdpAllInfo_A$i.txt 2>&1

#MegaRAID adpalilog data, used for grepping.
if [ "$LimitMegaCliCMDs" != "YES" ] ; then
echo $fileName >> ./$fileName/MegaRAID/AdpAliLog_A$i.txt 2>&1
$MCLI_LOCATION$MCLI_NAME adpalilog a$i nolog >> ./$fileName/MegaRAID/AdpAliLog_A$i.txt 2>&1
fi


echo "Starting MegaRAID Adapter Data Collection..."

	#cho ".................................................||................................................."
	echo $fileName >> ./$fileName/MegaRAID/Adapter_A$i.txt
	echo "......................................./$MCLI_NAME adpcount.........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpcount nolog | $grep Count: >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "............................................Adapter a$i.............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
if [ -f ./$fileName/MegaRAID/AdpAllInfo_A$i.txt ] ; then
	$grep -e "Product Name    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Memory Size     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Host Interface  :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Serial No       :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "SAS Address     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "FW Package Build:" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "FW Version         :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Mfg. Date       :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "BBU             :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Battery FRU     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Serial Debugger :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "On board Expander:" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "On board Expander FW version :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

if [ "$OS_LSI" = "linux" ]; then 

if [ ! -f ./$fileName/script_workspace/megaraid_sas_ver.txt ] ; then
#Need adpalilog fixed for driver version
lsmod | $grep megaraid_sas >/dev/null
	if [ "$?" -eq "0" ] ; then
	modinfo megaraid_sas | $grep "version:        00." | cut -d: -f2 | tr [:blank:] @ | tr -d @ >> ./$fileName/script_workspace/megaraid_sas_ver.txt
	fi
fi

if [ ! -f ./$fileName/script_workspace/megasr_ver.txt ] ; then
lsmod | $grep megasr >/dev/null
	if [ "$?" -eq "0" ] ; then
	modinfo megasr | $grep "version:        00." | cut -d: -f2 | tr [:blank:] @ | tr -d @ >> ./$fileName/script_workspace/megasr_ver.txt
	fi
fi

$MCLI_LOCATION$MCLI_NAME adpallinfo a$i nolog | $grep -e "Product Name" | $grep " 82" >/dev/null
	if [ "$?" -eq "0" ] ; then
	echo Driver megasr per modinfo: >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	cat ./$fileName/script_workspace/megasr_ver.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	else
	echo Driver megaraid_sas per modinfo: >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	cat ./$fileName/script_workspace/megaraid_sas_ver.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	fi
#OS Linux
fi


	#cho ".................................................||................................................."
	echo "...............................................Errors..............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Memory Correctable Errors   :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Memory Uncorrectable Errors :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Any Offline VD Cache Preserved   :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "ECC Bucket Count                 :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "...........................................Rate Settings............................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Ecc Bucket Size                  :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Ecc Bucket Leak Rate             :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Predictive Fail Poll Interval    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Interrupt Throttle Active Count  :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Interrupt Throttle Completion    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Rebuild Rate                     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "PR Rate                          :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	echo "Note: Resynch Rate is BgiRate" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Resynch Rate                     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Check Consistency Rate           :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Reconstruction Rate              :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Cache Flush Interval             :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Max Drives to Spinup at One Time :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Delay Among Spinup Groups        :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Physical Drive Coercion Mode     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".............................................Performance............................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Host Request Reordering          :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Load Balance Mode                :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop NCQDsply a$i nolog | $grep "NCQ" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop WBSupport a$i nolog | $grep "Adapter" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "................................Enclosures/Backplanes and Connectors................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Auto Detect BackPlane Enabled    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop ExposeEnclDevicesEnbl a$i nolog | $grep "Expose" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetconnectormode connectorall a$i nolog | $grep "Adapter" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "........................................Alarms and Warnings........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Alarm                            :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Battery Warning                  :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "........................................Rebuild and Hotspare........................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Auto Rebuild                     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Restore HotSpare on Insertion    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop AutoEnhancedImportDsply a$i nolog | $grep "Auto" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop MaintainPdFailHistoryEnbl a$i nolog | $grep "Maintain" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".............................................Copy Back.............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpgetprop CopyBackDsbl a$i nolog | $grep "Copyback" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop SMARTCpyBkEnbl a$i nolog | $grep "Copyback" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop SSDSMARTCpyBkEnbl a$i nolog | $grep "Copyback" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".............................................PR and CC.............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpgetprop EnblSSDPatrolRead a$i nolog | $grep "Patrol" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop PrCorrectUncfgdAreas a$i nolog | $grep "Unconfigured" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop AbortCCOnError a$i nolog | $grep "Abort" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".............................................Encryption............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Security Key Assigned            :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Security Key Failed              :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Security Key Not Backedup        :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop UseFDEOnlyEncrypt a$i nolog | $grep "FDE Only Encryption:" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "..........................................Power Management.........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpgetprop EnblSpinDownUnConfigDrvs a$i nolog | $grep "Spin" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpgetprop DsblSpinDownHSP a$i nolog | $grep "spin" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "............................................Miscellaneous..........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpbios dsply a$i nolog | $grep "BIOS" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpbootdrive get a$i nolog | $grep "boot" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Cluster Mode                     :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "...............................................Drives..............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Virtual Drives    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Degraded        :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Offline         :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Physical Devices  :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Disks           :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Critical Disks  :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$grep -e "Failed Disks    :" ./$fileName/MegaRAID/AdpAllInfo_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
#AdpAllInfo_A$i.txt exist
fi

#cho ".................................................||................................................."
echo "....................................Adapter/System Time Sync A$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
echo "Adapter Date/Time:" >> ./$fileName/MegaRAID/Adapter_A$i.txt
$MCLI_LOCATION$MCLI_NAME adpgettime a$i nolog | $grep -e "Date:" -e "Time:" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
echo "System Date/Time:" >> ./$fileName/MegaRAID/Adapter_A$i.txt
date >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
echo "System Date/Time UTC:" >> ./$fileName/MegaRAID/Adapter_A$i.txt
date -u >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo ".............................../$MCLI_NAME getpreservedcachelist a$i.................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME getpreservedcachelist a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

if [ -f ./$fileName/script_workspace/ld_numbers_A$i.txt ] ; then
for j in `cat ./$fileName/script_workspace/ld_numbers_A$i.txt` ; do #Support for up to 256 LDs
	#cho ".................................................||................................................."
	echo "...................................../$MCLI_NAME ldinfo l$j a$i........................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME ldinfo l$j a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".....................................Init/CC/Recon Status l$j a$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME ldinit showprog l$j a$i nolog | $grep "Initialization" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME ldbi showprog l$j a$i nolog | $grep "Background" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME ldcc showprog l$j a$i nolog | $grep "Check" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME ldrecon showprog l$j a$i nolog | $grep "Reconstruction" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
done
fi

	echo ".................................../$MCLI_NAME pdgetmissing a$i......................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME pdgetmissing a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "...................................Logical Disks & Physical Disks..................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME ldpdinfo a$i | $grep -e "Virtual Disk:" -e "RAID Level:" -e "Number Of Drives:" -e "PD:" -e "Enclosure Device ID:" -e "Slot Number:" -e "Device Id:" >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo ".....................................Physical Disk - Slot Number...................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Slot Number:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "......................................Physical Disk - Device Id....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Device Id:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo ".....................................Physical Disk - Inquiry Data..................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Inquiry Data:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo ".....................................Physical Disk - SAS Address...................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "SAS Address" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "....................................Physical Disk - Firmware state.................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Firmware state:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "....................................Physical Disk - Foreign State..................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e  "Foreign State:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "...............................Physical Disk - Predictive Failure Count............................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Predictive Failure Count:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo ".....................................Physical Disk - Link Speed....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Link Speed:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo ".......................................Physical Disk - Type........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "PD Type:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "......................................Physical Disk - Common........................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$grep -e "Slot Number:" -e "Enclosure Device ID:" -e "Device Id:" -e "Inquiry Data:" -e "Firmware state:" -e "Predictive Failure Count:" -e "Link Speed:" -e "PD Type:" ./$fileName/MegaRAID/PDList_A$i.txt >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1



if [ "$LimitMegaCliCMDs" != "YES" ] ; then 
echo "Collecting Enclosure Information for Adapter A$i..."
	#cho ".................................................||................................................."
	echo "....................................../$MCLI_NAME encinfo a$i........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME encinfo a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
fi

	#cho ".................................................||................................................."
	echo "...................................../$MCLI_NAME adpbbucmd a$i........................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpbbucmd a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

echo "Collecting Information for Adapter A$i..."

	#cho ".................................................||................................................."
	echo "................................../$MCLI_NAME cfgforeign scan a$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME cfgforeign scan a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "................................./$MCLI_NAME cfgforeign dsply a$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME cfgforeign dsply a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "................................/$MCLI_NAME cfgforeign preview a$i...................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME cfgforeign preview a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "..................................../$MCLI_NAME adppr info a$i........................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adppr info a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "................................../$MCLI_NAME adpccsched info a$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpccsched info a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "................................./$MCLI_NAME cfgfreespaceinfo a$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME cfgfreespaceinfo a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "............................/$MCLI_NAME cfgsave -f cfgsave_A$i.cfg a$i................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME cfgsave -f ./$fileName/MegaRAID/cfgsave_A$i.cfg a$i nolog > /dev/null 2>&1

	#cho ".................................................||................................................."
	echo "............................/$MCLI_NAME adpeventlog geteventloginfo a$i..............................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog geteventloginfo a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".............../$MCLI_NAME adpeventlog getevents -f eventlog_getevents_A$i.txt a$i....................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getevents -f ./$fileName/MegaRAID/eventlog_getevents_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "........./$MCLI_NAME adpeventlog getsinceshutdown -f eventlog_getsinceshutdown_A$i.txt a$i............" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getsinceshutdown -f ./$fileName/MegaRAID/eventlog_getsinceshutdown_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "........./$MCLI_NAME adpeventlog getsincereboot -f eventlog_getsincereboot_A$i.txt a$i................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getsincereboot -f ./$fileName/MegaRAID/eventlog_getsincereboot_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

	#cho ".................................................||................................................."
	echo "........./$MCLI_NAME adpeventlog includedeleted -f eventlog_includedeleted_A$i.txt a$i................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog includedeleted -f ./$fileName/MegaRAID/eventlog_includedeleted_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo ".........../$MCLI_NAME adpeventlog getlatest 1 -f Return_getlatest_1_A$i.txt a$i................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getlatest 1 -f ./$fileName/MegaRAID/Return_getlatest_1_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
if [ "$?" -eq "35" ] ; then
	#cho ".................................................||................................................."
	echo "....../$MCLI_NAME adpeventlog getlatest 10000 -f Return_0x23_getlatest_10000_A$i.txt a$i.............." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getlatest 10000 -f ./$fileName/MegaRAID/Return_0x23_getlatest_10000_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
if [ "$?" -eq "35" ] ; then
	#cho ".................................................||................................................."
	echo "......../$MCLI_NAME adpeventlog getlatest 1000 -f Return_0x23_getlatest_1000_A$i.txt a$i.............." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getlatest 1000 -f ./$fileName/MegaRAID/Return_0x23_getlatest_1000_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
if [ "$?" -eq "35" ] ; then
	#cho ".................................................||................................................."
	echo "......../$MCLI_NAME adpeventlog getlatest 100 -f Return_0x23_getlatest_100_A$i.txt a$i................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getlatest 100 -f ./$fileName/MegaRAID/Return_0x23_getlatest_100_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
if [ "$?" -eq "35" ] ; then
	#cho ".................................................||................................................."
	echo "........../$MCLI_NAME adpeventlog getlatest 10 -f Return_0x23_getlatest_10_A$i.txt a$i................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getlatest 10 -f ./$fileName/MegaRAID/Return_0x23_getlatest_10_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
if [ "$?" -eq "35" ] ; then
	#cho ".................................................||................................................."
	echo ".........../$MCLI_NAME adpeventlog getlatest 1 -f Return_0x23_getlatest_1_A$i.txt a$i................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME adpeventlog getlatest 1 -f ./$fileName/MegaRAID/Return_0x23_getlatest_1_A$i.txt a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
fi
fi
fi
fi
fi

	#cho ".................................................||................................................."
	echo "...................................../$MCLI_NAME cfgdsply a$i.........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME cfgdsply a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

echo "Collecting Logical Disk Information for Adapter A$i..."
	#cho ".................................................||................................................."
	echo "...................................../$MCLI_NAME ldpdinfo a$i........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME ldpdinfo a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
	echo "................................/$MCLI_NAME phyerrorcounters a$i......................................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME phyerrorcounters a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1

for j in `cat ./$fileName/script_workspace/phy_numbers_A$i.txt` ; do
	#cho ".................................................||................................................."
	echo ".................................../$MCLI_NAME phyinfo phy$j a$i......................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME phyinfo phy$j a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
done
	#cho ".................................................||................................................."
	echo "............................../$MCLI_NAME directpdmapping dsply a$i..................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME directpdmapping dsply a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."
echo "Collecting Physical Disk Information for Adapter A$i..."
	echo "....................................../$MCLI_NAME pdlist a$i.........................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME pdlist a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	#cho ".................................................||................................................."

###########################################################################################################################
# MegaOEM INI dump if installed
###########################################################################################################################

		if [ -e /opt/MegaRAID/MegaOEM/MegaOEM ]; then 
			#cho ".................................................||................................................."
			echo "................................./opt/MegaRAID/MegaOEM/MegaOEM -v..................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
			/opt/MegaRAID/MegaOEM/MegaOEM -v >> ./$fileName/MegaRAID/Adapter_A$i.txt
			echo "...........................MegaOEM adpsettings write -f MFC_Settings_opt_A$i.ini a$i......................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
			date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
			/opt/MegaRAID/MegaOEM/MegaOEM adpsettings write -f ./$fileName/MegaRAID/MFC_Settings_opt_A$i.ini a$i >> ./$fileName/MegaRAID/Adapter_A$i.txt
		fi


		if [ -e ./MegaOEM ]; then 
			#cho ".................................................||................................................."
			echo ".............................................MegaOEM -v............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
			./MegaOEM -v >> ./$fileName/MegaRAID/Adapter_A$i.txt

			echo "...........................MegaOEM adpsettings write -f MFC_Settings_A$i.ini a$i......................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
			date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
			./MegaOEM adpsettings write -f ./$fileName/MegaRAID/MFC_Settings_A$i.ini a$i >> ./$fileName/MegaRAID/Adapter_A$i.txt
		fi

		MegaOEM -v > /dev/null 2>&1
		if [ "$?" -eq "0" ]; then 
			#cho ".................................................||................................................."
			echo ".............................................MegaOEM -v............................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
			MegaOEM -v >> ./$fileName/MegaRAID/Adapter_A$i.txt

			echo "...........................MegaOEM adpsettings write -f MFC_Settings_path_A$i.ini a$i......................" >> ./$fileName/MegaRAID/Adapter_A$i.txt
			date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
			MegaOEM adpsettings write -f ./$fileName/MegaRAID/MFC_Settings_path_A$i.ini a$i >> ./$fileName/MegaRAID/Adapter_A$i.txt
		fi


echo "Collecting Internal Logs for Adapter A$i..."
	#cho ".................................................||................................................."
	echo "................................../$MCLI_NAME fwtermlog dsply a$i....................................." >> ./$fileName/MegaRAID/Adapter_A$i.txt
	date '+%H:%M:%S.%N' >> ./$fileName/MegaRAID/Adapter_A$i.txt
	$MCLI_LOCATION$MCLI_NAME fwtermlog dsply a$i nolog >> ./$fileName/MegaRAID/Adapter_A$i.txt 2>&1
	echo $fileName >> ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME fwtermlog dsply a$i nolog >> ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt 2>&1



###########################################################################################################################
# MegaCli fwtermlog dsply Ax - fwtermlog error screening
# 
# Words to look out for... "Fatal firmware error: Line" Fault Panic BAIL_OUT Paused REC CRC Unrecoverable Sense "Battery Put to Sleep" 
###########################################################################################################################


		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "Fatal firmware error: Line" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...............$MCLI_NAME fwtermlog dsply a$i - contains Fatal firmware error: Line...................." >> ./$fileName/MegaRAID/FWTermLog/Fatal_FW_Error_FWTermLog_A$i.txt
			echo "........This indicates that a SERIOUS FW Issue has occurred, contact Tech. Support or your FAE......." >> ./$fileName/MegaRAID/FWTermLog/Fatal_FW_Error_FWTermLog_A$i.txt
			$grep "Fatal firmware error: Line" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Fatal_FW_Error_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep " Fault " ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains Fault............................." >> ./$fileName/MegaRAID/FWTermLog/Fault_FWTermLog_A$i.txt
			echo "........This indicates that a SERIOUS FW Issue has occurred, contact Tech. Support or your FAE......." >> ./$fileName/MegaRAID/FWTermLog/Fault_FWTermLog_A$i.txt
			$grep " Fault " ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Fault_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "Panic" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains Panic............................." >> ./$fileName/MegaRAID/FWTermLog/Panic_FWTermLog_A$i.txt
			echo "........This indicates that a SERIOUS FW Issue has occurred, contact Tech. Support or your FAE......." >> ./$fileName/MegaRAID/FWTermLog/Panic_FWTermLog_A$i.txt
			$grep "Panic" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Panic_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "BAIL_OUT" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains BAIL_OUT.........................." >> ./$fileName/MegaRAID/FWTermLog/BAIL_OUT_FWTermLog_A$i.txt
			echo "........This indicates that a SERIOUS FW Issue has occurred, contact Tech. Support or your FAE......." >> ./$fileName/MegaRAID/FWTermLog/BAIL_OUT_FWTermLog_A$i.txt
			$grep "BAIL_OUT" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/BAIL_OUT_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "Paused" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains Paused............................" >> ./$fileName/MegaRAID/FWTermLog/Paused_FWTermLog_A$i.txt
			echo "....................................This should be investigated....................................." >> ./$fileName/MegaRAID/FWTermLog/Paused_FWTermLog_A$i.txt
			$grep "Paused" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Paused_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep -e "MPI2_EVENT_SAS_QUIESCE_RC_STARTED" -e "MPI2_EVENT_SAS_QUIESCE_RC_COMPLETED" -e "Test event: An unexpected data IO error occurred on PD" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "..........................$MCLI_NAME fwtermlog dsply a$i - contains Test_Event............................" >> ./$fileName/MegaRAID/FWTermLog/Test_Event_FWTermLog_A$i.txt
			echo "....................................This should be investigated....................................." >> ./$fileName/MegaRAID/FWTermLog/Test_Event_FWTermLog_A$i.txt
			$grep -e "MPI2_EVENT_SAS_QUIESCE_RC_STARTED" -e "MPI2_EVENT_SAS_QUIESCE_RC_COMPLETED" -e "Test event: An unexpected data IO error occurred on PD" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Test_Event_FWTermLog_A$i.txt
					
			fi
		fi


		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "REC" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains REC..............................." >> ./$fileName/MegaRAID/FWTermLog/REC_FWTermLog_A$i.txt
			echo "....................................This should be investigated....................................." >> ./$fileName/MegaRAID/FWTermLog/REC_FWTermLog_A$i.txt
			$grep "REC" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/REC_FWTermLog_A$i.txt
					
			fi
		fi

		
		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "Unrecoverable" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...................$MCLI_NAME fwtermlog dsply a$i - contains Unrecoverable............................." >> ./$fileName/MegaRAID/FWTermLog/Unrecoverable_FWTermLog_A$i.txt
			echo "....................................This should be investigated....................................." >> ./$fileName/MegaRAID/FWTermLog/Unrecoverable_FWTermLog_A$i.txt
			$grep "Unrecoverable" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Unrecoverable_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep "CRC" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains CRC..............................." >> ./$fileName/MegaRAID/FWTermLog/CRC_FWTermLog_A$i.txt
			echo "....................................This should be investigated....................................." >> ./$fileName/MegaRAID/FWTermLog/CRC_FWTermLog_A$i.txt
			$grep "CRC" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/CRC_FWTermLog_A$i.txt
					
			fi
		fi
		
		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep -i "Sense" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "...........................$MCLI_NAME fwtermlog dsply a$i - contains Sense............................." >> ./$fileName/MegaRAID/FWTermLog/Sense_FWTermLog_A$i.txt
			echo "...........................................Informational............................................" >> ./$fileName/MegaRAID/FWTermLog/Sense_FWTermLog_A$i.txt
			$grep -i "Sense" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/Sense_FWTermLog_A$i.txt
					
			fi
		fi

		if [ -e ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt ]; then 
		$grep -i "Battery Put to Sleep" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt > /dev/null
			if [ "$?" -eq "0" ]; then
			#cho ".................................................||................................................."
			echo "..................$MCLI_NAME fwtermlog dsply a$i - contains Battery Put to Sleep......................." >> ./$fileName/MegaRAID/FWTermLog/BatterySleep_FWTermLog_A$i.txt
			echo "...........................................Informational............................................" >> ./$fileName/MegaRAID/FWTermLog/BatterySleep_FWTermLog_A$i.txt
			$grep -i "Battery Put to Sleep" ./$fileName/MegaRAID/FWTermLog/fwtermlog_A$i.txt >> ./$fileName/MegaRAID/FWTermLog/BatterySleep_FWTermLog_A$i.txt
					
			fi
		fi



###########################################################################################################################
# MegaRAID Smartctl Data Collection if Smartctl is installed
# Start Linux Only Section for now
# Must test on other OS's
###########################################################################################################################

if [ "$OS_LSI" = "linux" ]; then 

smartctl -h > /dev/null 2>&1
if [ "$?" -eq "0" ] ; then
# Smartctl added support for MegaRAID in 5.39
if [ `smartctl -V | $grep release | cut -d" " -f3 | cut -d. -f1` -ge 5 ] ; then
if [ `smartctl -V | $grep release | cut -d" " -f3 | cut -d. -f2` -ge 39 ] ; then

for j in a b c d e f g h i j k l m n o p q r s t u v w x y z ; do
if [ -e /sys/block/sd$j ] ; then echo $j >> ./$fileName/script_workspace/sd_letters.txt ; fi
done

echo "Starting MegaRAID Smartctl Data Collection..."
if [ ! -d ./$fileName/MegaRAID/SMARTCTL ]; then mkdir ./$fileName/MegaRAID/SMARTCTL ; fi

if [ -e ./$fileName/script_workspace/sd_letters.txt ] ; then
for j in `cat ./$fileName/script_workspace/sd_letters.txt` ; do #Supports up to 26 character device node entries
	for k in `cat ./$fileName/script_workspace/disk_dev_id_numbers_A$i.txt` ; do #Limit?
#		#cho ".................................................||................................................."
		smartctl -T permissive -i -d megaraid,$k /dev/sd$j | egrep "START OF INFORMATION SECTION|Serial number:" 1>/dev/null # Test for instances that exist
		if [ "$?" -eq "0" ]; then
		#cho ".................................................||................................................."
		echo ".................................megaraid,$k is the Disk Device ID #................................." >> ./$fileName/MegaRAID/SMARTCTL/megaraid_A$i.txt 2>&1
		echo ".......................smartctl -T permissive -a -d megaraid,$k /dev/sd$j............................." >> ./$fileName/MegaRAID/SMARTCTL/megaraid_A$i.txt 2>&1
		smartctl -T permissive -a -d megaraid,$k /dev/sd$j >> ./$fileName/MegaRAID/SMARTCTL/megaraid_A$i.txt 2>&1
		fi
	done
done
fi


# returns for smartctl -V
fi
fi
# return for smartctl -h
fi
# return for OS_LSI=linux
fi

# Adapter number
done

# Returns from - Make sure at least 1 MegaRAID Adapter is identified
fi
#

###########################################################################################################################
# Component version number collection
###########################################################################################################################
#Get the MegaCli version that came bundled with the script
if [ "$mcli_Bundled_work" = "YES" ]; then
./$MCLI_NAME -v | $grep Ver | cut -dr -f2 | tr [:blank:] @ | cut -d@ -f2 > ./$fileName/script_workspace/mcli_Bundled_version.txt
fi

# Get the MegaCli version that was pre-existing
if [ "$tw_cli_Existing_work" = "YES" ]; then
$MCLI_NAME -v | $grep Ver | cut -dr -f2 | tr [:blank:] @ | cut -d@ -f2 > ./$fileName/script_workspace/mcli_Existing_version.txt
fi

###########################################################################################################################
# Done with MegaCli!
###########################################################################################################################
LD_PRELOAD=
LD_LIBRARY_PATH=



# Return if MacOS for MegaRAID
fi
###########################################################################################################################
# Script Version
###########################################################################################################################
###Update on Code Set Change
echo "$Capture_Script_Version" > ./$fileName/script_workspace/lsigetlunix_version.txt

###########################################################################################################################
# Data to help troubleshoot script issues.
###########################################################################################################################


#cho ".................................................||................................................."
echo "............................whoami - user executing lsigetlunix.sh script..........................." >> ./$fileName/script_workspace/script_diag.txt
whoami >> ./$fileName/script_workspace/script_diag.txt
#cho ".................................................||................................................."
echo "..................groups - groups user executing lsigetlunix.sh script belongs to..................." >> ./$fileName/script_workspace/script_diag.txt
groups >> ./$fileName/script_workspace/script_diag.txt
#cho ".................................................||................................................."
echo "..........................ls -latr - files in subdir script was executed from......................." >> ./$fileName/script_workspace/script_diag.txt
ls -latr >> ./$fileName/script_workspace/script_diag.txt
#cho ".................................................||................................................."
echo "....................................set - environment for script...................................." >> ./$fileName/script_workspace/script_diag.txt
set >> ./$fileName/script_workspace/script_diag.txt 2>&1
#cho ".................................................||................................................."
echo "....................................env - environment for script...................................." >> ./$fileName/script_workspace/script_diag.txt
env >> ./$fileName/script_workspace/script_diag.txt 2>&1
echo "......................................Command Line and Options......................................" >> ./$fileName/script_workspace/script_diag.txt
echo "$0 $@" > ./$fileName/script_workspace/cmd_line.txt
TWCMDLINE=`cat ./$fileName/script_workspace/cmd_line.txt`
export TWCMDLINE
echo "$0 $@" >> ./$fileName/script_workspace/script_diag.txt

###########################################################################################################################
# System capture comment
###########################################################################################################################
if [ "$TWcomment" != "" ] ; then  echo "$TWcomment" > ./$fileName/Comment.txt ; fi


###########################################################################################################################
# Component version number collection
###########################################################################################################################
#Get the tw_cli version that came bundled with the script
if [ "$tw_cli_Bundled_work" = "YES" ]; then
./$CLI_NAME help 2>/dev/null | $grep version | awk  '{ print $4 }' | sed -e 's/)//' > ./$fileName/script_workspace/tw_cli_Bundled_version.txt
fi

# Get the tw_cli version that was pre-existing
if [ "$tw_cli_Existing_work" = "YES" ]; then
$CLI_NAME help 2>/dev/null | $grep version | awk  '{ print $4 }' | sed -e 's/)//' > ./$fileName/script_workspace/tw_cli_Existing_version.txt
fi


########################################################################################################################### 
###########################################################################################################################
# Common - Collect system information 
###########################################################################################################################
###########################################################################################################################


echo "Collecting System info..."

uname -a > ./$fileName/uname-a.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
dmesg > ./$fileName/dmesg.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
ps -ea > ./$fileName/ps-ea.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
mkdir ./$fileName/conf
cp cversions_3w.txt ./$fileName/script_workspace
cp cversions_MR.txt ./$fileName/script_workspace
cp cversions_HBA.txt ./$fileName/script_workspace
cp lsigetlunix.sh ./$fileName/script_workspace
cp Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt ./$fileName/script_workspace

for i in sysconfig/diskdump sysconfig/harddisks sysconfig/hwconf fstab raidtab;do
if [ -f /etc/$i ] ; then cp -p /etc/$i ./$fileName/ 
fi
done

for i in a b c d e f g h i j k l m n o p q r s t u v w x y z;do
for j in vendor model timeout;do
if [ -e /sys/block/sd$i/device/$j ];then
#cho ".................................................||................................................."
echo "....................................cat /sys/block/sd$i/device/$j..................................." >> ./$fileName/sd_time_out_value.txt 2>&1
cat /sys/block/sd$i/device/$j >> ./$fileName/sd_time_out_value.txt 2>&1
fi
done
done

if [ -d /proc ] && mkdir -p ./$fileName/proc; then
for x in pci interrupts cpuinfo buddyinfo devices diskstats dma filesystems iomem ioports kallsyms mdstat meminfo misc modules mounts mtrr partitions pci slabinfo stat uptime version vmstat zoneinfo scsi
do 
	if [ -f /proc/$x ] ; then
		cat /proc/$x > ./$fileName/proc/$x 2>>./$fileName/script_workspace/lsiget_errorlog.txt
	fi
done
fi

if [ -d /proc/sys/vm ]; then for x in /proc/sys/vm/*; do 
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/proc/sys-vm.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo $x >> ./$fileName/proc/sys-vm.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
cat $x >> ./$fileName/proc/sys-vm.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
done
fi

if [ -d /proc/scsi/3w-xxxx ]; then for x in /proc/scsi/3w-xxxx/*; do 
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/proc/scsi-3w-xxxx.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo $x >> ./$fileName/proc/scsi-3w-xxxx.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
cat $x >> ./$fileName/proc/scsi-3w-xxxx.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
done
fi

if [ -d /proc/scsi/3w-9xxx ]; then for x in /proc/scsi/3w-9xxx/*; do 
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/proc/scsi-3w-9xxx.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo $x >> ./$fileName/proc/scsi-3w-9xxx.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
cat $x >> ./$fileName/proc/scsi-3w-9xxx.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
done
fi

if [ -d /proc/scsi/megaraid_sas ]; then for x in /proc/scsi/megaraid_sas/*; do 
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/proc/scsi-megaraid_sas.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo $x >> ./$fileName/proc/scsi-megaraid_sas.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
cat $x >> ./$fileName/proc/scsi-megaraid_sas.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
done
fi

if [ -d /proc/scsi/sg ]; then for x in /proc/scsi/sg/*; do 
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/proc/scsi-sg.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo $x >> ./$fileName/proc/scsi-sg.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
cat $x >> ./$fileName/proc/scsi-sg.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
done
fi

if [ -e /proc/scsi/scsi ]; then for x in /proc/scsi/scsi; do 
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/proc/scsi-scsi.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo $x >> ./$fileName/proc/scsi-scsi.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
cat $x >> ./$fileName/proc/scsi-scsi.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
done
fi
	

[ -f /proc/bus/pci/devices ] && cat /proc/bus/pci/devices > ./$fileName/proc/pci-devices 2>>./$fileName/script_workspace/lsiget_errorlog.txt
[ -f /proc/bus/usb/devices ] && cat /proc/bus/usb/devices > ./$fileName/proc/usb-devices 2>>./$fileName/script_workspace/lsiget_errorlog.txt
[ -f /proc/bus/input/devices ] && cat /proc/bus/input/devices > ./$fileName/proc/input-devices 2>>./$fileName/script_workspace/lsiget_errorlog.txt
[ -f /proc/net/dev ] && cat /proc/net/dev > ./$fileName/proc/net-dev 2>>./$fileName/script_workspace/lsiget_errorlog.txt

for i in warn boot.omsg boot.msg debug.log auth.log xdm.log crashreporter.log; do
        	if [ -e /var/log/$i ]; then cp /var/log/$i ./$fileName/.
        	fi
	done


if [ -e /var/log/dmesg.today ]; then cp /var/log/dmesg.* ./$fileName/.
fi

#Brackets get rid of messages on FreeBSD if files don't exist.
{ cp -p /etc/*.conf ./$fileName/conf; } 2>/dev/null 
{ cp -p /etc/*release ./$fileName/; } 2>/dev/null


#Device Mapping Info Linux
for i in by-id by-label by-path by-uuid; do
if [ -e  /dev/disk/$i ]; then ls -la /dev/disk/$i > ./$fileName/ls-la_dev_disk_$i.txt
fi
done

###########################################################################################################################
# Common - 3DM(2) data collection
###########################################################################################################################
echo "Collecting 3DM(2) version info..."

#3dm data collection
if [ -e  /usr/sbin/3dmd ]; then mkdir ./$fileName/3ware/3DM
fi
if [ -e  /usr/sbin/3dmd ]; then 
strings /usr/sbin/3dmd | fgrep 1.13. > ./$fileName/3ware/3DM/3dm_version.txt
fi
if [ -e  /etc/3dm.conf ]; then cp /etc/3dm.conf ./$fileName/3ware/3DM/
fi
if [ -e  /var/log/3w-aenlog.txt ]; then cp /var/log/3w-* ./$fileName/3ware/3DM/
fi
#Other 3dm logs????

#3dm2 data collection
if [ -e  /usr/sbin/3dm2 ]; then mkdir ./$fileName/3ware/3DM2
fi

###Update on Code Set Change
for i in 2.00.00.038 2.01. 2.02. 2.03. 2.04. 2.05. 2.06. 2.07. 2.08. 2.09.; do
	if [ -e  /usr/sbin/3dm2 ]; then 
strings /usr/sbin/3dm2 | fgrep $i >> ./$fileName/script_workspace/3dm2_api_ver.txt
	fi
done
if [ -e  ./$fileName/script_workspace/3dm2_api_ver.txt ]; then 
grep -n . ./$fileName/script_workspace/3dm2_api_ver.txt | $grep 1: | cut -d: -f2 > ./$fileName/3ware/3DM2/3dm2api_ver.txt
grep -n . ./$fileName/script_workspace/3dm2_api_ver.txt | $grep 3: | cut -d: -f2 > ./$fileName/3ware/3DM2/3dm2_ver.txt
fi


if [ -e /etc/3dm2/3dm2.conf ]; then cp /etc/3dm2/3dm2.conf ./$fileName/3ware/3DM2
fi

cp /var/log/tdm_aen*.txt ./$fileName/3ware/3DM2 2>>./$fileName/script_workspace/lsiget_errorlog.txt

if [ -e /opt/AMCC/log.txt ]; then cp /opt/AMCC/log.txt ./$fileName/3ware/3DM2 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi

if [ -e /var/log/tw_mgmt.log ]; then 
if [ -e ./$fileName/3ware/3DM2 ]; then cp /var/log/tw_mgmt.log ./$fileName/3ware/3DM2; else
cp /var/log/tw_mgmt.log ./$fileName/3ware/ 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi
fi

#Other 3dm2 logs????

###########################################################################################################################
# MegaRAID Storage Manager Log files - Other Unix distros?
###########################################################################################################################

if [ -d "$MSM_HOME"/MegaMonitor ] ; then
mkdir ./$fileName/MegaRAID/MSM
echo "Collecting MSM logs..."
cp "$MSM_HOME"/MegaMonitor/* ./$fileName/MegaRAID/MSM 2>/dev/null
cp "$MSM_HOME"/*.log ./$fileName/MegaRAID/MSM 2>/dev/null
cp "$MSM_HOME"/*.txt ./$fileName/MegaRAID/MSM 2>/dev/null
mrmonitord -v | cut -d m -f 2 | cut -d r -f 2 > ./$fileName/MegaRAID/MSM/mrmonitord_version.txt 2>/dev/null
fi

if [ "$MSM_HOME" = "" ] ; then
if [ -d /usr/local/"MegaRAID Storage Manager"/MegaMonitor ] ; then
mkdir ./$fileName/MegaRAID/MSM
echo "Collecting MSM logs..."
cp /usr/local/"MegaRAID Storage Manager"/MegaMonitor/* ./$fileName/MegaRAID/MSM 2>/dev/null
cp /usr/local/"MegaRAID Storage Manager"/*.log ./$fileName/MegaRAID/MSM 2>/dev/null
cp /usr/local/"MegaRAID Storage Manager"/*.txt ./$fileName/MegaRAID/MSM 2>/dev/null
mrmonitord -v | cut -d m -f 2 | cut -d r -f 2 > ./$fileName/MegaRAID/MSM/mrmonitord_version.txt 2>/dev/null
fi
fi


###########################################################################################################################
echo "Collecting and Processing system logs/messages files..."
###########################################################################################################################
#Linux, FreeBSD
###########################################################################################################################
if [ -e /var/log/messages ]; then cp -p /var/log/messages* ./$fileName/
ls -latr ./$fileName/messages* > ./$fileName/script_workspace/all_copied_messages.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi
###########################################################################################################################
#VMWare
###########################################################################################################################
if [ -e /var/log/vmkernel ]; then cp -p /var/log/vmkernel* ./$fileName/
ls -latr ./$fileName/vmkernel* > ./$fileName/script_workspace/all_copied_messages.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi
###########################################################################################################################
#MacOS
###########################################################################################################################
if [ -e /var/log/system.log ]; then cp -p /var/log/system.log* ./$fileName/
ls -latr ./$fileName/system.log* > ./$fileName/script_workspace/all_copied_messages.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi
###########################################################################################################################
#Solaris
###########################################################################################################################
if [ -e /var/adm/messages ]; then cp -p /var/adm/messages* ./$fileName/
ls -latr ./$fileName/messages* > ./$fileName/script_workspace/all_copied_messages.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi


###########################################################################################################################
#Start Linux Only Section
###########################################################################################################################


if [ "$OS_LSI" = "linux" ]; then 

		echo "...................................................................................................." >> ./$fileName/modinfo.txt

TwareDriver=`lsmod | awk '{print $1}' | $grep 3w`
if [ "$?" -eq "0" ] ; then
	for i in $TwareDriver
	do
		echo "LSI 3ware driver module name $i" >> ./$fileName/modinfo.txt
		modinfo $i >> ./$fileName/modinfo.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
		echo "...................................................................................................." >> ./$fileName/modinfo.txt
		if  modinfo -n $i >>/dev/null 2>>./$fileName/script_workspace/lsiget_errorlog.txt; then  
			cp -p `modinfo -n $i` ./$fileName/3ware
		fi  

	done
else
	echo "LSI 3ware driver module not installed or IN-Kernel driver used if driver installed." >> ./$fileName/modinfo.txt
	echo "...................................................................................................." >> ./$fileName/modinfo.txt
fi

MRSASDriver=`lsmod | awk '{print $1}' | $grep mega`
if [ "$?" -eq "0" ] ; then
	for i in $MRSASDriver
	do
		echo "LSI MegaRAID SAS driver module name $i" >> ./$fileName/modinfo.txt
		modinfo $i >> ./$fileName/modinfo.txt
		echo "...................................................................................................." >> ./$fileName/modinfo.txt
		if  modinfo -n $i >>/dev/null 2>>./$fileName/script_workspace/lsiget_errorlog.txt; then  
			cp -p `modinfo -n $i` ./$fileName/MegaRAID
		fi  

	done
else
	echo "LSI MegaRAID SAS driver module not installed or IN-Kernel driver used if driver installed." >> ./$fileName/modinfo.txt
	echo "...................................................................................................." >> ./$fileName/modinfo.txt
fi

LSISASDriver=`lsmod | awk '{print $1}' | $grep mpt`
if [ "$?" -eq "0" ] ; then
	for i in $LSISASDriver
	do
		echo "LSI SAS HBA driver module name $i" >> ./$fileName/modinfo.txt
		modinfo $i >> ./$fileName/modinfo.txt
		echo "...................................................................................................." >> ./$fileName/modinfo.txt
		if  modinfo -n $i >>/dev/null 2>>./$fileName/script_workspace/lsiget_errorlog.txt; then  
			cp -p `modinfo -n $i` ./$fileName/HBA
		fi  

	done
else
	echo "LSI SAS HBA driver module not installed or IN-Kernel driver used if driver installed." >> ./$fileName/modinfo.txt
	echo "...................................................................................................." >> ./$fileName/modinfo.txt
fi



uptime > ./$fileName/uptime.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lsmod > ./$fileName/lsmod.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lspci -vv > ./$fileName/lspci-vv.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lspci -x > ./$fileName/lspci-x.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
scanpci -v > ./$fileName/scanpci-v.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
rpm -q -a -i > ./$fileName/rpm-qai.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
df -haT > ./$fileName/df-haT.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
who -b > ./$fileName/who-b.txt  2>>./$fileName/script_workspace/lsiget_errorlog.txt
top -b -n 1 > ./$fileName/top-b-n1.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt

showsel  > /dev/null 2>&1
if [ "$?" -ne "127" ] ; then
showsel  > ./$fileName/showsel.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi

lshw  > /dev/null 2>&1
if [ "$?" -ne "127" ] ; then
lshw > ./$fileName/lshw.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
fi


#
#Add additional md data gathering lines
#



#
#All 3ware Performance Tuning parameters should be gathered here!
#
echo "Collecting 3ware SD Device Performance Tuning Data..."

for t in a b c d e f g h i j k l m n o p q r s t u v w x y z; do
		if [ -e /sys/block/sd$t ]; then
			udevinfo -q all -n /dev/sd$t | $grep -e AMCC_ -e 3ware_ >> /dev/null 2>>./$fileName/script_workspace/lsiget_errorlog.txt
			if [ "$?" -eq "0" ] ; then
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "Recommended settings are listed below for fw 3.08.00.004 & later." >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "For earlier fw use 64 for max_sectors. The latest code set should" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "be used for best performance. Feel free to experiment with" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "these setting for your particular environment, especially if you are" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "using the MD driver. These settings are primarily for the 95/6xx" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "class of controllers but may be beneficial for earlier controllers." >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "...................................................................................................." >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "See http://www.3ware.com/kb/article.aspx?id=11050 for more information of Performance Tuning." >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "...................................................................................................." >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "echo "128" > /sys/block/sd$t/queue/max_sectors_kb" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "echo "1024" > /sys/block/sd$t/queue/nr_requests" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
				if [ -e /sys/block/sd$t/queue/scheduler ]; then
				echo "echo "deadline" > /sys/block/sd$t/queue/scheduler" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
				fi
echo "blockdev --setra 16384 /dev/sd$t" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "Note: setra MUST be done last otherwise it goes back to default!" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "........................................Current Settings for........................................" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		udevinfo -q all -n /dev/sd$t >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo "...................................................................................................."  >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		echo "cat /sys/block/sd$t/queue/max_sectors_kb" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		cat /sys/block/sd$t/queue/max_sectors_kb >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt

		echo "cat /sys/block/sd$t/queue/nr_requests" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		cat /sys/block/sd$t/queue/nr_requests >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt

		if [ -e /sys/block/sd$t/queue/scheduler ]; then 
		echo "cat /sys/block/sd$t/queue/scheduler" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		cat /sys/block/sd$t/queue/scheduler >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		fi

		echo "blockdev --getra /dev/sd$t" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		blockdev --getra /dev/sd$t >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt        	

echo "...................................................................................................."  >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "The following dumps all info in the /sys/block/sd$t/queue/ directory" >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		for j in /sys/block/sd$t/queue/*; do 
		echo $j >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt 2>&1
		cat $j >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt 2>&1
		done
		
		for j in /sys/block/sd$t/queue/iosched/*; do 
		echo $j `cat $j` >> ./$fileName/3ware/3ware_Perf_Tuning_sd$t.txt
		done

		

		fi
	fi
done

#
#All Generic Performance Tuning parameters should be gathered here!
#
echo "Collecting Generic SD Device Performance Tuning Data..."
echo "Collecting - parted -s /dev/sdX print..."
echo "Note: An active mkfs will cause this script to pause..."
for t in a b c d e f g h i j k l m n o p q r s t u v w x y z; do
		if [ -e /sys/block/sd$t ]; then
			
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "If this is NOT a 3ware device the recommendations may not apply!" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "The Generic version of the 3ware_Perf_Tuning_sdx.txt files are being created" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "since udevinfo -q all -n /dev/sd$t | $grep -e AMCC_ -e 3ware_ has not been" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "successful in all cases to identify a 3ware device. " >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "See http://www.3ware.com/kb/article.aspx?id=11050 for more information of Performance Tuning." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "Recommended settings are listed below for fw 3.08.00.004 & later." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "For earlier fw use 64 for max_sectors. The latest code set should" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "be used for best performance. Feel free to experiment with" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "these setting for your particular environment, especially if you are" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "using the MD driver. These settings are primarily for the 95/6xx" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "class of controllers but may be beneficial for earlier controllers." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................." >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "echo "128" > /sys/block/sd$t/queue/max_sectors_kb" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "echo "1024" > /sys/block/sd$t/queue/nr_requests" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
				if [ -e /sys/block/sd$t/queue/scheduler ]; then
				echo "echo "deadline" > /sys/block/sd$t/queue/scheduler" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
				fi
echo "blockdev --setra 16384 /dev/sd$t" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "Note: setra MUST be done last otherwise it goes back to default!" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "........................................Current Settings for........................................" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		udevinfo -q all -n /dev/sd$t >> ./$fileName/Generic_Perf_Tuning_sd$t.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
echo "...................................................................................................."  >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		echo "cat /sys/block/sd$t/queue/max_sectors_kb" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		cat /sys/block/sd$t/queue/max_sectors_kb >> ./$fileName/Generic_Perf_Tuning_sd$t.txt

		echo "cat /sys/block/sd$t/queue/nr_requests" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		cat /sys/block/sd$t/queue/nr_requests >> ./$fileName/Generic_Perf_Tuning_sd$t.txt

		if [ -e /sys/block/sd$t/queue/scheduler ]; then 
		echo "cat /sys/block/sd$t/queue/scheduler" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		cat /sys/block/sd$t/queue/scheduler >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		fi

		echo "blockdev --getra /dev/sd$t" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		blockdev --getra /dev/sd$t >> ./$fileName/Generic_Perf_Tuning_sd$t.txt        	

echo "...................................................................................................."  >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "The following dumps all info in the /sys/block/sd$t/queue/ directory" >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
echo "...................................................................................................."  >> ./$fileName/Generic_Perf_Tuning_sd$t.txt

		for j in /sys/block/sd$t/queue/*; do 
		echo $j >> ./$fileName/Generic_Perf_Tuning_sd$t.txt 2>&1
		cat $j >> ./$fileName/Generic_Perf_Tuning_sd$t.txt 2>&1
		done
		
		for j in /sys/block/sd$t/queue/iosched/*; do 
		echo $j `cat $j` >> ./$fileName/Generic_Perf_Tuning_sd$t.txt
		done

#cho ".................................................||................................................."
echo ".....................................parted -s /dev/sd$t print......................................." >> ./$fileName/parted_print_sdX.txt
parted -s /dev/sd$t print >> ./$fileName/parted_print_sdX.txt

		fi
done


echo "Notice: MR_MONITOR Error Codes are in Decimal, megasas_aen_polling Error Codes are in HEX, they report the same information." > ./$fileName/MegaRAID/Hex_Decimal_Numbering_Conventions.txt
echo "I.E. '"'megasas_aen_polling[1]: event code 0x0087'"' is the same as '"'MR_MONITOR[3226]: <MRMON135> Controller ID: 0  Global Hot Spare created: --:--:2'"'" >> ./$fileName/MegaRAID/Hex_Decimal_Numbering_Conventions.txt
echo "The MR_MONITOR error files have the Decimal equivalent embedded after the severity level for ease of identification." >> ./$fileName/MegaRAID/Hex_Decimal_Numbering_Conventions.txt
echo "The megasas error files have the Hex equivalent embedded after the severity level for ease of identification." >> ./$fileName/MegaRAID/Hex_Decimal_Numbering_Conventions.txt


echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with ' 3w' in the line#" > ./$fileName/3ware/3ware_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'MR_MONITOR' in the line#" > ./$fileName/MegaRAID/mrmonitord_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'kernel: megasas' in the line#" > ./$fileName/MegaRAID/megaraid_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'kernel: mpt' in the line#" > ./$fileName/HBA/hba_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'MR_MONITOR' OR 'kernel: megasas' in the line#" > ./$fileName/MegaRAID/megaraid_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with ' kernel: sd ' in the line#" > ./$fileName/OS_Disk_driver_messages.txt

#Make sure zipped messages don't overwrite unzipped.

for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e ./$fileName/message$i ]; then if [ -e  ./$fileName/message$i.gz ]; then mv ./$fileName/message$i.gz ./$fileName/message$i.gz.dupe_name
	fi
fi
done

#Checks for compressed/dated message files.

gunzip ./$fileName/messages-????????.gz 2>>./$fileName/script_workspace/lsiget_errorlog.txt
ls ./$fileName/messages-???????? > ./$fileName/script_workspace/messages_dated.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
for i in $( cat ./$fileName/script_workspace/messages_dated.txt );do
grep " 3w" $i >> ./$fileName/3ware/3ware_driver_messages.txt
grep "MR_MONITOR" $i >> ./$fileName/MegaRAID/mrmonitord_messages.txt
grep "kernel: megasas" $i >> ./$fileName/MegaRAID/megaraid_driver_messages.txt
grep "kernel: mpt" $i >> ./$fileName/HBA/hba_driver_messages.txt
egrep "MR_MONITOR|kernel: megasas" $i >> ./$fileName/MegaRAID/megaraid_messages.txt
grep " kernel: sd " $i >> ./$fileName/OS_Disk_driver_messages.txt
done


for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e  ./$fileName/message$i.gz ]; then gunzip ./$fileName/message$i.gz
fi
done


for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e ./$fileName/message$i ]; then $grep " 3w" ./$fileName/message$i >> ./$fileName/3ware/3ware_driver_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "MR_MONITOR" ./$fileName/message$i >> ./$fileName/MegaRAID/mrmonitord_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "kernel: megasas" ./$fileName/message$i >> ./$fileName/MegaRAID/megaraid_driver_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "kernel: mpt" ./$fileName/message$i >> ./$fileName/HBA/hba_driver_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then egrep "MR_MONITOR|kernel: megasas" ./$fileName/message$i >> ./$fileName/MegaRAID/megaraid_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep " kernel: sd " ./$fileName/message$i >> ./$fileName/OS_Disk_driver_messages.txt ; fi
done

grep " (0x03:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x03_9000_ERROR.txt 
grep " (0x04:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt 
grep " (0x06:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x06_9000_DRIVER.txt 
grep " (0x09:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x09_LINUX_OS.txt 
grep " (0x0B:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0B_API.txt 
grep " (0x0C:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0C_3DMPLUS.txt 
grep " (0x0D:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0D_CLI.txt 
grep " (0x0E:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0E_7000_ERROR.txt 
grep " (0x0F:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0F_7000_EVENT.txt 
grep " (0x11:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x11_7000_DRIVER.txt  

for i in _x03_9000_ERROR _x04_9000_EVENT _x06_9000_DRIVER _x09_LINUX_OS _x0B_API _x0C_3DMPLUS _x0D_CLI _x0E_7000_ERROR _x0F_7000_EVENT _x11_7000_DRIVER; do
	if [ ! -s ./$fileName/3ware/3ware_driver$i.txt ]; then rm ./$fileName/3ware/3ware_driver$i.txt ; fi
done

grep " (0x03:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x03_9000_ERROR.txt 
grep " (0x04:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x04_9000_EVENT.txt 
grep " (0x06:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x06_9000_DRIVER.txt 
grep " (0x09:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x09_LINUX_OS.txt 
grep " (0x0B:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0B_API.txt 
grep " (0x0C:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0C_3DMPLUS.txt 
grep " (0x0D:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0D_CLI.txt 
grep " (0x0E:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0E_7000_ERROR.txt 
grep " (0x0F:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0F_7000_EVENT.txt 
grep " (0x11:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x11_7000_DRIVER.txt  

for i in _x03_9000_ERROR _x04_9000_EVENT _x06_9000_DRIVER _x09_LINUX_OS _x0B_API _x0C_3DMPLUS _x0D_CLI _x0E_7000_ERROR _x0F_7000_EVENT _x11_7000_DRIVER; do
	if [ ! -s ./$fileName/3ware/OS_Disk_driver$i.txt ]; then rm ./$fileName/3ware/OS_Disk_driver$i.txt ; fi
done



# Final fi
fi
#
# End Linux Only Section
#

###########################################################################################################################
#Start VMWare Only Section
###########################################################################################################################

if [ "$OS_LSI" = "vmware" ]; then 

TwareDriver=`vmkload_mod -b | awk '{print $1}' | $grep 3w`
if [ "$?" -eq "0" ] ; then
	for i in $TwareDriver
	do
		echo "3ware driver module name " $i "\n" >> ./$fileName/modinfo.txt
		modinfo $i >> ./$fileName/modinfo.txt
		if  modinfo -n $i >>/dev/null 2>>./$fileName/script_workspace/lsiget_errorlog.txt; then  
			cp -p `modinfo -n $i` ./$fileName/
		fi  

	done
else
	echo "Driver Module not installed or IN-Kernel Driver used if driver installed." >> ./$fileName/modinfo.txt
fi

echo "" >> ./$fileName/modinfo.txt

MRSASDriver=`vmkload_mod -b | awk '{print $1}' | $grep megaraid_sas`
if [ "$?" -eq "0" ] ; then
	for i in $MRSASDriver
	do
		echo "MegaRAID SAS driver module name " $i "\n" >> ./$fileName/modinfo.txt
		modinfo $i >> ./$fileName/modinfo.txt
		if  modinfo -n $i >>/dev/null 2>>./$fileName/script_workspace/lsiget_errorlog.txt; then  
			cp -p `modinfo -n $i` ./$fileName/
		fi  

	done
else
	echo "3ware MegaRAID SAS Driver Module not installed or IN-Kernel Driver used if driver installed." >> ./$fileName/modinfo.txt
fi

uptime > ./$fileName/uptime.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lsmod > ./$fileName/lsmod.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
vmkload_mod -l > ./$fileName/vmkload_mod-l.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
vmkload_mod -b > ./$fileName/vmkload_mod-b.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lspci -vv > ./$fileName/lspci-vv.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lspci -x > ./$fileName/lspci-x.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lspci -v > ./$fileName/lspci-v.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lspci -t > ./$fileName/lspci-t.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
rpm -q -a -i > ./$fileName/rpm-qai.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
df -haT > ./$fileName/df-haT.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
who -b > ./$fileName/who-b.txt  2>>./$fileName/script_workspace/lsiget_errorlog.txt
top -b -n 1 > ./$fileName/top-b-n1.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt

if [ -d /proc/vmware ]; then
for x in watchpoints vmkstor version uptime timers thermmon stats procstats pci mem log intr-tracker interrupts cpuinfo chipset
do 
	if [ -f /proc/vmware/$x ] ; then
		cat /proc/vmware/$x > ./$fileName/proc/vmware-$x 2>>./$fileName/script_workspace/lsiget_errorlog.txt
	fi
done
fi

if [ -d /proc/vmware/config/Disk ]; then
for x in  UseReportLUN UseLunReset UseDeviceReset ThroughputCap SupportSparseLUN SPCmdsToSwitch SPBlksToSwitch SharesNormal SharesLow SharesHigh SectorMaxDiff SchedQuantum SchedQControlVMSwitches SchedQControlSeqReqs SchedNumReqOutstanding SANDevicesWithAPFailover RetryUnitAttention ResetThreadMin ResetThreadMax ResetThreadExpires ResetPeriod ResetOverdueLogPeriod ResetOnFailover ResetMaxRetries ResetLatency PreventVMFSOverwrite PathEvalTime MaxVCNotReadyTime MaxResetLatency MaxLUN MaxDS400NotReadyTime MaskLUNs EnableNaviReg DumpMaxRetries DiskMaxIOSize DelayOnBusy BandwidthCap
do 
	if [ -f /proc/vmware/config/Disk/$x ] ; then
		cat /proc/vmware/config/Disk/$x > ./$fileName/proc/vmware-config-Disk-$x 2>>./$fileName/script_workspace/lsiget_errorlog.txt
	fi
done
fi

if [ -d /proc/vmware/config/Scsi ]; then
for x in   TimeoutTMThreadRetry TimeoutTMThreadMin TimeoutTMThreadMax TimeoutTMThreadLatency TimeoutTMThreadExpires SCSITimeout_ScanTime SCSITimeout_ReabortTime ScsiRestartStalledQueueLatency ScsiRescanAllHbas ScanOnDriverLoad ReserveBacktrace PrintCmdErrors PassthroughLocking MaxReserveTotalTime MaxReserveTime MaxReserveBacktrace LogMultiPath LogAborts ConflictRetries CompareLUNNumber
do 
	if [ -f /proc/vmware/config/Scsi/$x ] ; then
		cat /proc/vmware/config/Scsi/$x > ./$fileName/proc/vmware-config-Scsi-$x 2>>./$fileName/script_workspace/lsiget_errorlog.txt
	fi
done
fi


echo "#All lines from all vmkernel files (vmkernel, vmkernel.0-20(.gz), vmkernel-????????(.gz) with '3w-9xxx or 3ware' in the line#" > ./$fileName/3ware/3ware_driver_messages.txt

echo "#All lines from all vmkernel files (vmkernel, vmkernel.0-20(.gz), vmkernel-????????(.gz) with 'SCSI or Scsi' in the line#" > ./$fileName/OS_Disk_driver_messages.txt

#Make sure zipped vmkernel don't overwrite unzipped.

for i in l.20 l.19 l.18 l.17 l.16 l.15 l.14 l.13 l.12 l.11 l.10 l.9 l.8 l.7 l.6 l.5 l.4 l.3 l.2 l.1 l.0 s; do
	if [ -e ./$fileName/vmkerne$i ]; then if [ -e  ./$fileName/vmkerne$i.gz ]; then mv ./$fileName/vmkerne$i.gz ./$fileName/vmkerne$i.gz.dupe_name
	fi
fi
done

#Checks for compressed/dated vmkernel files.

gunzip ./$fileName/vmkernel-????????.gz 2>>./$fileName/script_workspace/lsiget_errorlog.txt
ls ./$fileName/vmkernel-???????? > ./$fileName/script_workspace/messages_dated.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
for i in $( cat ./$fileName/script_workspace/messages_dated.txt );do
grep "3w-9xxx\|3ware" $i >> ./$fileName/3ware/3ware_driver_messages.txt
grep "SCSI\|Scsi" $i >> ./$fileName/OS_Disk_driver_messages.txt
done


for i in l.20 l.19 l.18 l.17 l.16 l.15 l.14 l.13 l.12 l.11 l.10 l.9 l.8 l.7 l.6 l.5 l.4 l.3 l.2 l.1 l.0 s; do
	if [ -e  ./$fileName/vmkerne$i.gz ]; then gunzip ./$fileName/vmkerne$i.gz
fi
done


for i in l.20 l.19 l.18 l.17 l.16 l.15 l.14 l.13 l.12 l.11 l.10 l.9 l.8 l.7 l.6 l.5 l.4 l.3 l.2 l.1 l.0 s; do
	if [ -e ./$fileName/vmkerne$i ]; then $grep "3w-9xxx\|3ware" ./$fileName/vmkerne$i >> ./$fileName/3ware/3ware_driver_messages.txt 
fi
	if [ -e ./$fileName/vmkerne$i ]; then $grep "SCSI\|Scsi" ./$fileName/vmkerne$i >> ./$fileName/OS_Disk_driver_messages.txt 
fi
done

grep -i " (0x03:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x03_9000_ERROR.txt 
grep -i " (0x04:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt 
grep -i " (0x06:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x06_9000_DRIVER.txt 
grep -i " (0x09:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x09_LINUX_OS.txt 
grep -i " (0x0B:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0B_API.txt 
grep -i " (0x0C:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0C_3DMPLUS.txt 
grep -i " (0x0D:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0D_CLI.txt 
grep -i " (0x0E:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0E_7000_ERROR.txt 
grep -i " (0x0F:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0F_7000_EVENT.txt 
grep -i " (0x11:0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x11_7000_DRIVER.txt  

for i in _x03_9000_ERROR _x04_9000_EVENT _x06_9000_DRIVER _x09_LINUX_OS _x0B_API _x0C_3DMPLUS _x0D_CLI _x0E_7000_ERROR _x0F_7000_EVENT _x11_7000_DRIVER; do
	if [ ! -s ./$fileName/3ware/3ware_driver$i.txt ]; then rm ./$fileName/3ware/3ware_driver$i.txt ; fi
done

grep -i " (0x03:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x03_9000_ERROR.txt 
grep -i " (0x04:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x04_9000_EVENT.txt 
grep -i " (0x06:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x06_9000_DRIVER.txt 
grep -i " (0x09:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x09_LINUX_OS.txt 
grep -i " (0x0B:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0B_API.txt 
grep -i " (0x0C:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0C_3DMPLUS.txt 
grep -i " (0x0D:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0D_CLI.txt 
grep -i " (0x0E:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0E_7000_ERROR.txt 
grep -i " (0x0F:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0F_7000_EVENT.txt 
grep -i " (0x11:0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x11_7000_DRIVER.txt  

for i in _x03_9000_ERROR _x04_9000_EVENT _x06_9000_DRIVER _x09_LINUX_OS _x0B_API _x0C_3DMPLUS _x0D_CLI _x0E_7000_ERROR _x0F_7000_EVENT _x11_7000_DRIVER; do
	if [ ! -s ./$fileName/3ware/OS_Disk_driver$i.txt ]; then rm ./$fileName/3ware/OS_Disk_driver$i.txt ; fi
done



# Final fi
fi
#
# End VMWare Only Section
#

###########################################################################################################################
#Start FreeBSD Only Section
###########################################################################################################################

if [ "$OS_LSI" = "freebsd" ]; then 

top -b -n 1 > ./$fileName/top-b-n1.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
who -m > ./$fileName/who-m.txt  2>>./$fileName/script_workspace/lsiget_errorlog.txt
sysctl -a > ./$fileName/sysctl-a.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
sysctl -ad > ./$fileName/sysctl-ad.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
sysctl -ah > ./$fileName/sysctl-ah.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
sysctl -adh > ./$fileName/sysctl-adh.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
devinfo -r > ./$fileName/devinfo-r.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
devinfo -ru > ./$fileName/devinfo-ru.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
devinfo -rv > ./$fileName/devinfo-rv.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
devinfo -ruv > ./$fileName/devinfo-ruv.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
pciconf -l -cv > ./$fileName/pciconf-l-cv.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
vmstat > ./$fileName/vmstat.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
vmstat -i > ./$fileName/vmstat-i.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
# kldstat like modinfo, kldload & kldunload are like modload & mod unload
kldstat -v > ./$fileName/kldstat-v.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
camcontrol devlist  > ./$fileName/camcontrol_inquiry.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
pkg_info > ./$fileName/pkg_info.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
lsvfs > ./$fileName/lsvfs.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
df -Hai > ./$fileName/df-Hai.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
df -Hami > ./$fileName/df-Hami.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt

df | $grep dev/ | cut -d "/" -f 3 | cut -d " " -f 1 > ./$fileName/script_workspace/df.out
for i in $( cat ./$fileName/script_workspace/df.out );do
dumpfs -m /dev/$i > ./$fileName/dumpfs-m_$i.txt
done



#
#Add additional SW Raid data gathering lines
#

#
#All 3ware Performance Tuning parameters should be gathered here!
#
echo "Collecting System Level Disk Performance Tuning Data..."
#cho ".................................................||................................................."
echo "...................................................................................................." >> ./$fileName/Perf_Tuning.txt

echo "http://www.3ware.com/KB/article.aspx?id=14852" >> ./$fileName/Perf_Tuning.txt
echo "http://www.3ware.com/KB/article.aspx?id=15244" >> ./$fileName/Perf_Tuning.txt
echo "These are some parameters that you can tune under FreeBSD." >> ./$fileName/Perf_Tuning.txt
echo  >> ./$fileName/Perf_Tuning.txt
echo "Read ahead caching:" >> ./$fileName/Perf_Tuning.txt
echo "Current: sysctl vfs.read_max (default is 8)" >> ./$fileName/Perf_Tuning.txt
echo "Recommended: sysctl vfs.read_max=256" >> ./$fileName/Perf_Tuning.txt 
echo  >> ./$fileName/Perf_Tuning.txt
echo "Write caching:" >> ./$fileName/Perf_Tuning.txt
echo "Current: sysctl vfs.write_behind (default is 1)" >> ./$fileName/Perf_Tuning.txt
echo "Recommended: sysctl vfs.write_behind=1" >> ./$fileName/Perf_Tuning.txt
echo >> ./$fileName/Perf_Tuning.txt
echo "Bytes Outstanding before Write Cache Flush:" >> ./$fileName/Perf_Tuning.txt
echo "Current: sysctl vfs.hirunningspace" >> ./$fileName/Perf_Tuning.txt
echo "Recommended: sysctl vfs.hirunningspace=1048576" >> ./$fileName/Perf_Tuning.txt
echo >> ./$fileName/Perf_Tuning.txt
echo "You will need to experiment with different values to" >> ./$fileName/Perf_Tuning.txt
echo "see what yields the best performance for you in your application." >> ./$fileName/Perf_Tuning.txt
echo "...................................................................................................." >> ./$fileName/Perf_Tuning.txt
if [ -e  ./$fileName/sysctl-ad.txt ]; then 
echo "Current settings..." >> ./$fileName/Perf_Tuning.txt
grep vfs.read_max ./$fileName/sysctl-ad.txt >> ./$fileName/Perf_Tuning.txt
grep vfs.read_max ./$fileName/sysctl-a.txt >> ./$fileName/Perf_Tuning.txt
grep vfs.write_behind ./$fileName/sysctl-ad.txt >> ./$fileName/Perf_Tuning.txt
grep vfs.write_behind ./$fileName/sysctl-a.txt >> ./$fileName/Perf_Tuning.txt
grep vfs.hirunningspace ./$fileName/sysctl-ad.txt >> ./$fileName/Perf_Tuning.txt
grep vfs.hirunningspace ./$fileName/sysctl-a.txt >> ./$fileName/Perf_Tuning.txt
fi


echo "#All lines from all message files (messages, messages.0-20(.bz2), messages-????????(.bz2) with 'kernel: twa' in the line#" > ./$fileName/3ware/3ware_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.bz2), messages-????????(.bz2) with 'kernel: da' in the line#" > ./$fileName/OS_Disk_driver_messages.txt

#echo "#All lines from all message files (messages, messages.0-20(.bz2), messages-????????(.bz2) with 'MR_MONITOR' in the line#" > ./$fileName/MegaRAID/mrmonitord_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.bz2), messages-????????(.bz2) with 'kernel: mfi' in the line#" > ./$fileName/MegaRAID/megaraid_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'kernel: mpt' in the line#" > ./$fileName/HBA/hba_driver_messages.txt

#echo "#All lines from all message files (messages, messages.0-20(.bz2), messages-????????(.bz2) with 'MR_MONITOR' OR 'kernel: mfi' in the line#" > ./$fileName/MegaRAID/megaraid_messages.txt


#Make sure zipped messages don't overwrite unzipped.

for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e ./$fileName/message$i ]; then if [ -e  ./$fileName/message$i.bz2 ]; then mv ./$fileName/message$i.bz2 ./$fileName/message$i.bz2.dupe_name
	fi
fi
done

#Checks for compressed/dated message files.

bzip2 -d ./$fileName/messages-????????.bz2 2>>./$fileName/script_workspace/lsiget_errorlog.txt
ls ./$fileName/messages-???????? > ./$fileName/script_workspace/messages_dated.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
for i in $( cat ./$fileName/script_workspace/messages_dated.txt );do
grep "kernel: twa" $i >> ./$fileName/3ware/3ware_driver_messages.txt
#grep "MR_MONITOR" $i >> ./$fileName/MegaRAID/mrmonitord_messages.txt
grep "kernel: mfi" $i >> ./$fileName/MegaRAID/megaraid_driver_messages.txt
grep "kernel: mpt" $i >> ./$fileName/HBA/hba_driver_messages.txt
#egrep "MR_MONITOR|kernel: mfi" $i >> ./$fileName/MegaRAID/megaraid_messages.txt
grep "kernel: da" $i >> ./$fileName/OS_Disk_driver_messages.txt
done


for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e  ./$fileName/message$i.bz2 ]; then bzip2 -d ./$fileName/message$i.bz2 ; fi
done


for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e ./$fileName/message$i ]; then $grep "kernel: twa" ./$fileName/message$i >> ./$fileName/3ware/3ware_driver_messages.txt ; fi
#	if [ -e ./$fileName/message$i ]; then $grep "MR_MONITOR" ./$fileName/message$i >> ./$fileName/MegaRAID/mrmonitord_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "kernel: mfi" ./$fileName/message$i >> ./$fileName/MegaRAID/megaraid_driver_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "kernel: mpt" ./$fileName/message$i >> ./$fileName/HBA/hba_driver_messages.txt ; fi
#	if [ -e ./$fileName/message$i ]; then egrep "MR_MONITOR|kernel: mfi" ./$fileName/message$i >> ./$fileName/MegaRAID/megaraid_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "kernel: da" ./$fileName/message$i >> ./$fileName/OS_Disk_driver_messages.txt ; fi
done


grep " (0x03: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x03_9000_ERROR.txt 
grep " (0x04: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt 
grep " (0x06: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x06_9000_DRIVER.txt 
grep " (0x09: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x09_FreeBSD_OS.txt 
grep " (0x0B: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0B_API.txt 
grep " (0x0C: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0C_3DMPLUS.txt 
grep " (0x0D: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0D_CLI.txt 
grep " (0x0E: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0E_7000_ERROR.txt 
grep " (0x0F: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x0F_7000_EVENT.txt 
grep " (0x11: 0x" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x11_7000_DRIVER.txt  

for i in _x03_9000_ERROR _x04_9000_EVENT _x06_9000_DRIVER _x09_FreeBSD_OS _x0B_API _x0C_3DMPLUS _x0D_CLI _x0E_7000_ERROR _x0F_7000_EVENT _x11_7000_DRIVER; do
	if [ ! -s ./$fileName/3ware/3ware_driver$i.txt ]; then rm ./$fileName/3ware/3ware_driver$i.txt ; fi
done

grep " (0x03: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x03_9000_ERROR.txt 
grep " (0x04: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x04_9000_EVENT.txt 
grep " (0x06: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x06_9000_DRIVER.txt 
grep " (0x09: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x09_FreeBSD_OS.txt 
grep " (0x0B: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0B_API.txt 
grep " (0x0C: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0C_3DMPLUS.txt 
grep " (0x0D: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0D_CLI.txt 
grep " (0x0E: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0E_7000_ERROR.txt 
grep " (0x0F: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x0F_7000_EVENT.txt 
grep " (0x11: 0x" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x11_7000_DRIVER.txt  

for i in _x03_9000_ERROR _x04_9000_EVENT _x06_9000_DRIVER _x09_FreeBSD_OS _x0B_API _x0C_3DMPLUS _x0D_CLI _x0E_7000_ERROR _x0F_7000_EVENT _x11_7000_DRIVER; do
	if [ ! -s ./$fileName/3ware/OS_Disk_driver$i.txt ]; then rm ./$fileName/3ware/OS_Disk_driver$i.txt ; fi
done


# Final fi
fi
#
# End FreeBSD Only Section
#

###########################################################################################################################
#Start MacOS Only Section
###########################################################################################################################


if [ "$OS_LSI" = "macos" ]; then 


system_profiler -detaillevel full > ./$fileName/system_profile.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
grep "System Version" ./$fileName/system_profile.txt > ./$fileName/Mac_OS_X_Version.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
grep "Kernel Version" ./$fileName/system_profile.txt >> ./$fileName/Mac_OS_X_Version.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt


kextstat > ./$fileName/kextstat.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
kextstat | $grep amcc > ./$fileName/3ware/kextstat_amcc.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
kextstat | $grep 3ware > ./$fileName/3ware/kextstat_3ware.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt

uptime > ./$fileName/uptime.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
who -m > ./$fileName/who-m.txt  2>>./$fileName/script_workspace/lsiget_errorlog.txt
df -h > ./$fileName/df-h.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
top -l1 > ./$fileName/top-l1.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt

#Add new logs as needed


echo "#All lines from all system.log files (system.log, system.log.0-20(.gz)) with 'AMCC3ware9000' OR 'LSI3ware9000' in the line#" > ./$fileName/3ware/3ware_driver_messages.txt
echo "#All lines from all system.log files (system.log, system.log.0-20(.gz)) with 'diskarbitrationd' in the line#" > ./$fileName/OS_Disk_driver_messages.txt


#Make sure zipped messages don't overwrite unzipped.

for i in g.20 g.19 g.18 g.17 g.16 g.15 g.14 g.13 g.12 g.11 g.10 g.9 g.8 g.7 g.6 g.5 g.4 g.3 g.2 g.1 g.0 g; do
	if [ -e ./$fileName/system.lo$i ]; then if [ -e  ./$fileName/system.lo$i.gz ]; then mv ./$fileName/system.lo$i.gz ./$fileName/system.lo$i.gz.dupe_name
	fi
fi
done

for i in g.20 g.19 g.18 g.17 g.16 g.15 g.14 g.13 g.12 g.11 g.10 g.9 g.8 g.7 g.6 g.5 g.4 g.3 g.2 g.1 g.0 g; do
	if [ -e  ./$fileName/system.lo$i.gz ]; then gunzip ./$fileName/system.lo$i.gz

fi
done


for i in g.20 g.19 g.18 g.17 g.16 g.15 g.14 g.13 g.12 g.11 g.10 g.9 g.8 g.7 g.6 g.5 g.4 g.3 g.2 g.1 g.0 g; do
	if [ -e ./$fileName/system.lo$i ]; then $grep "AMCC3ware9000" ./$fileName/system.lo$i >> ./$fileName/3ware/3ware_driver_messages.txt 
fi
	if [ -e ./$fileName/system.lo$i ]; then $grep "diskarbitrationd" ./$fileName/system.lo$i >> ./$fileName/OS_Disk_driver_messages.txt 
fi
done

egrep "AMCC3ware9000 AEN|LSI3ware9000 AEN" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt 

for i in _x04_9000_EVENT; do
	if [ ! -s ./$fileName/3ware/3ware_driver$i.txt ]; then rm ./$fileName/3ware/3ware_driver$i.txt > /dev/null 2>&1 ; fi
done

grep "diskarbitrationd" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x04_9000_EVENT.txt 

for i in _x04_9000_EVENT; do
	if [ ! -s ./$fileName/3ware/OS_Disk_driver$i.txt ]; then rm ./$fileName/3ware/OS_Disk_driver$i.txt > /dev/null 2>&1 ; fi
done



# Final fi
fi
#
# End MacOS Only Section
#

###########################################################################################################################
#Start Solaris Only Section
###########################################################################################################################

if [ "$OS_LSI" = "solaris" ]; then 

uptime > ./$fileName/uptime.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
df -ha > ./$fileName/df-ha.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
who > ./$fileName/who.txt  2>>./$fileName/script_workspace/lsiget_errorlog.txt
top -b -n 1 > ./$fileName/top-b-n1.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt





#
# All 3ware Performance Tuning parameters should be gathered here!
#
# echo "Collecting 3ware SD Device Performance Tuning Data..."


echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with ': tw' in the line#" > ./$fileName/3ware/3ware_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with ': mega_sas' in the line#" > ./$fileName/MegaRAID/megaraid_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with '] sd' in the line#" > ./$fileName/OS_Disk_driver_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'MR_MONITOR' in the line#" > ./$fileName/MegaRAID/mrmonitord_messages.txt

echo "#All lines from all message files (messages, messages.0-20(.gz), messages-????????(.gz) with 'MR_MONITOR' OR ': mega_sas' in the line#" > ./$fileName/MegaRAID/megaraid_messages.txt




#Make sure zipped messages don't overwrite unzipped.

for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e ./$fileName/message$i ]; then if [ -e  ./$fileName/message$i.gz ]; then mv ./$fileName/message$i.gz ./$fileName/message$i.gz.dupe_name
	fi
fi
done

#Checks for compressed/dated message files.

gunzip ./$fileName/messages-????????.gz 2>>./$fileName/script_workspace/lsiget_errorlog.txt
ls ./$fileName/messages-???????? > ./$fileName/script_workspace/messages_dated.txt 2>>./$fileName/script_workspace/lsiget_errorlog.txt
for i in $( cat ./$fileName/script_workspace/messages_dated.txt );do
grep ": tw" $i >> ./$fileName/3ware/3ware_driver_messages.txt
grep ": mega_sas" $i >> ./$fileName/MegaRAID/megaraid_driver_messages.txt
grep "MR_MONITOR" $i >> ./$fileName/MegaRAID/mrmonitord_messages.txt
egrep "MR_MONITOR|: mega_sas" $i >> ./$fileName/MegaRAID/megaraid_messages.txt
grep "] sd" $i >> ./$fileName/OS_Disk_driver_messages.txt
done


for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e  ./$fileName/message$i.gz ]; then gunzip ./$fileName/message$i.gz
fi
done


for i in s.20 s.19 s.18 s.17 s.16 s.15 s.14 s.13 s.12 s.11 s.10 s.9 s.8 s.7 s.6 s.5 s.4 s.3 s.2 s.1 s.0 s; do
	if [ -e ./$fileName/message$i ]; then $grep ": tw" ./$fileName/message$i >> ./$fileName/3ware/3ware_driver_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep ": mega_sas" ./$fileName/message$i >> ./$fileName/MegaRAID/megaraid_driver_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "MR_MONITOR" ./$fileName/message$i >> ./$fileName/MegaRAID/mrmonitord_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "MR_MONITOR|: mega_sas" ./$fileName/message$i >> ./$fileName/MegaRAID/megaraid_messages.txt ; fi
	if [ -e ./$fileName/message$i ]; then $grep "] sd" ./$fileName/message$i >> ./$fileName/OS_Disk_driver_messages.txt ; fi
done


grep "tw_aen_task AEN" ./$fileName/3ware/3ware_driver_messages.txt >> ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt 


for i in _x04_9000_EVENT; do
	if [ ! -s ./$fileName/3ware/3ware_driver$i.txt ]; then rm ./$fileName/3ware/3ware_driver$i.txt > /dev/null 2>&1 ; fi
done

grep "] sd" ./$fileName/OS_Disk_driver_messages.txt >> ./$fileName/3ware/OS_Disk_driver_x04_9000_EVENT.txt 


for i in _x04_9000_EVENT; do
	if [ ! -s ./$fileName/3ware/OS_Disk_driver$i.txt ]; then rm ./$fileName/3ware/OS_Disk_driver$i.txt > /dev/null 2>&1 ; fi
done







# Final fi
fi
#
# End Solaris Only Section
#

###########################################################################################################################
###########################################################################################################################
#Start Generic Section
###########################################################################################################################
###########################################################################################################################




###########################################################################################################################
###Update on Code Set Change
# Based on errorcode.h 4.06.00.004FW 9.5.1 codeset
# Errors = 0x03 
# Legacy error_codes, these are reserved on Apache 
###########################################################################################################################
x0000="no_error_status_dependent_code_for_this_error_status" 
x0001="no_request_ID_available_for_this_error_status" 
x0002="CP_queue_became_full" 
x0003="illegal_SGL_offset_in_CP_Header" 
x0004="illegal_number_of_SGL_entries_in_CPH" 
x0005="could_not_allocate_additional_memory" 
x0006="some_PCI_read_error_occurred" 
x0007="timeout_during_PCI_transaction" 
x0008="PCI_ERR_bit_for_a_PCI_transaction" 
x0009="unrecoverable_disk_error" 
x000A="completion_token_queue_overflow" 
x000B="error_reading_SGL" 
x000C="error_reading_CP_Header" 
x000D="abort_req_for_cmd_that_wasn't_active" 
x000E="illegal_size_in_CP_Header" 
x000F="got_a_CPH_with_an_already_active_req_ID"
x0010="lengths_in_SGLs_not_match_block_count_in_CP" 
x0011="requested_LBA_greater_than_maximum_LBA_of_the_unit" 
x0012="host_address_or_SGL_size_not_on_8_dw_boundary" 
x0013="data_integrity_error_on_read_or_write_test" 
x0014="subcmd_num_in_CP_hdr_is_undef_for_this_cmd" 
x0015="undefined_table_requested" 
x0016="param_requested_is_out_of_bounds_of_table" 
x0017="given_param_size_doesnt_match_param_size_in_table" 
x0018="host_address_or_SGL_size_not_on_a_sector_boundary" 
x0019="Achip_Unit__number_exceeds_maximum" 
x001A="bad_pairing_of_disk-op_or_xer-op_from_Aop_queue" 
x001B="Aport_timed_out_doing_an_Aop" 
x001C="an_Achip_GSR_interrupt_occurred" 
x001D="Aop_encountered_with_unknown_cmd_byte" 
x001E="PCI_was_busy_when_tried_to_do_a_PCI_read_or_write" 
x001F="next_Aop_should_have_been_a_disk-op_but_it_wasnt" 
x0020="param_0_unsupported_for_now_for_get_or_set_param" 
x0021="an_unimplemented_method_was_invoked" 
x0022="request_ID_took_too_long_to_complete" 
x0023="a_disk_task_file_error_occurred_during_a_1F_test" 
x0024="data_lines_shorted_in_Sbuf_RAM" 
x0025="data_lines_open_in_Sbuf_RAM" 
x0026="addr_line_problem_in_Sbuf_RAM" 
x0027="Sbuf_RAM_unreadable" 
x0028="command_requires_at_least_1_SGL" 
x0029="no_unit_num_is_available_for_use" 
x002A="CP_queue_was_empty_when_tried_to_get_a_CP_ptr_from_it" 
x002B="test_firmware_not_downloaded_to_RAM" 
x002C="an_attempt_was_made_to_nest_internal_requests" 
x002D="error_in_downloading_hex_file" 
x002E="error_in_programming_the_flash_ROM" 
x002F="error_in_rollcall" 
x0030="error_in_wait_disks_rdy" 
x0031="error_in_UIT_formatting" 
x0032="incorrect_unit_type_for_the_request" 
x0033="unit_does_not_have_the_logical_sub-unit_specified" 
x0034="unit_has_corrupted_data_on_it" 
x0035="could_not_write_DCB_to_disk" 
x0036="could_not_get_profiler_from_disk" 
x0037="unit_is_not_exportable" 
x0038="unit_is_missing_a_sub-unit" 
x0039="unit_is_not_operating_normally" 
x003A="not_enough_SBUF_segments_to_service_the_request" 
x003B="User_area_in_unit_was_not_written_with_zeroes" 
x003C="user_data_on_unit_did_not_verify" 
x003D="error_while_writing_0s_to_user_data" 
x003E="a_unit_does_not_contain_a_logical_mapping_for_a_phys_drive" 
x003F="drive_replacement_would_cause_a_double-degrade" 
x0040="capacity_of_replacement_drive_is_too_small" 
x0041="no_drive_detected" 
x0042="drive_detected_to_be_busy" 
x0043="aport_unavailable" 
x0044="unable_to_clear_sbuf" 
x0045="can_not_replace_drive_because_unit_not_degraded" 
x0046="we_have_no_routine_to_program_this_mfr_or_type_of_flash" 
x0047="cant_fill_Sbuf_with_zeros" 
x0048="byte_count_in_PARAM_field_is_too_big_for_this_cmd" 
x0049="timeout_while_waiting_for_data_from_display_panel" 
x004A="CRC_error_reported_on_BFB_transfer" 
x0051="for_drive_errors_the_status_register_gets_stuffed_into_LSB_of_ESDC" 
x0060="reserved_-_this_is_a_valid_drive_status_error_code" 
x0061="reserved_-_this_is_a_valid_drive_status_error_code" 
x0100="SGL_entry_contains_zero_data" 
x0101="Invalid_command_opcode" 
x0102="SGL_entry_has_unaligned_address" 
x0103="SGL_size_does_not_match_command" 
x0104="SGL_entry_has_illegal_length" 
x0105="Command_packet_is_not_aligned" 
x0106="Invalid_request_ID" 
x0107="Duplicate_request_ID" 
x0108="ID_not_locked" 
x0109="LBA_out_of_range" 
x010A="Logical_unit_not_present" 
x010B="Parameter_table_does_not_exist" 
x010C="Parameter_index_does_not_exist" 
x010D="Invalid_field_in_CDB" 
x010E="Invalid_operation_for_specified_port" 
x010F="Parameter_item_size_mismatch" 
x0110="Failed_memory_allocation" 
x0111="Memory_request_too_large" 
x0112="Out_of_memory_segments" 
x0113="Invalid_address_to_deallocate" 
x0114="Out_of_memory" 
x0115="Out_of_heap" 
x0116="Invalid_BIOS_buffer_id" 
x011E="Unrecovered_Read_Error"
x011F="Recovered_Data_with_error_correction_applied"
x0120="Double_degrade" 
x0121="Drive_not_degraded" 
x0122="Reconstruct_error" 
x0123="Replace_not_accepted" 
x0124="Drive_capacity_too_small" 
x0125="Sector_count_not_allowed" 
x0126="No_spares_left" 
x0127="Reconstruct_error" 
x0128="Unit_offline" 
x0129="Cannot_update_status_to_DCB" 
x012A="Invalid_configuration_for_split" 
x012B="Invalid_configuration_for_join" 
x012C="No_migration_recovery" 
x012D="No_SATA_spares" 
x012E="No_SAS_spares"  
x012F="Mixed_SAS_SATA_not_allowed_in_same_unit" 
x0130="Invalid_stripe_handle" 
x0131="Handle_that_was_not_locked" 
x0132="Handle_that_was_not_empty" 
x0133="Handle_has_different_owner" 
x0140="IPR_has_parent" 
x0150="Illegal_Pbuf_address_alignment" 
x0151="Illegal_Pbuf_transfer_length" 
x0152="Illegal_Sbuf_address_alignment" 
x0153="Illegal_Sbuf_transfer_length" 
x0160="Command_packet_too_large" 
x0161="SGL_exceeds_maximum_length" 
x0162="SGL_has_too_many_entries" 
x0170="Insufficient_resources_for_rebuilder" 
x0171="Verify_error_data_doesnt_equal_parity" 
x0180="Requested_segment_not_in_directory_of_this_DCB" 
x0181="DCB_segment_has_unsupported_version" 
x0182="DCB_segment_has_checksum_error" 
x0183="DCB_support_settings_segment_invalid" 
x0184="DCB_UDB_unit_descriptor_block_segment_invalid" 
x0185="DCB_GUID_globally_unique_identifier_segment_invalid" 
x01A0="Could_not_clear_Sbuf" 
x01C0="Flash_device_unsupported" 
x01C1="Flash_out_of_bounds" 
x01C2="Flash_write_verify_failed" 
x01C3="Flash_file_object_not_found" 
x01C4="Flash_file_already_present" 
x01C5="Flash_file_system_full" 
x01C6="Flash_file_not_present" 
x01C7="Flash_file_size_mismatch" 
x01C8="Flash_file_checksum_error" 
x01C9="Flash_file_version_unsupported" 
x01CA="Flash_file_system_error_detected" 
x01CB="Flash_file_component_directory_not_found" 
x01CC="Flash_file_component_not_found" 
x01CD="Flash_write_cycle_failed" 
x01CE="Flash_erase_cycle_failed" 
x01D0="Invalid_field_in_parameter_list" 
x01D1="Parameter_list_length_error" 
x01D2="Parameter_not_changeable" 
x01D3="Parameter_not_saveable" 
x01D4="Invalid_mode_page" 
x0200="Drive_CRC_error" 
x0201="Internal_bus_CRC_error" 
x0202="Drive_ECC_Medium_error" 
x0203="Drive_TFR_readback_error" 
x0204="Drive_timeout" 
x0205="Drive_power_on_reset" 
x0206="ADP_level_2_error" 
x0207="Drive_soft_reset_failed" 
x0208="Drive_not_ready" 
x0209="Unclassified_drive_error" 
x020A="Drive_aborted_command" 
x020D="Drive_not_ready_require_Spinup" 
x020B="Port_link_error_detected" 
x020C="Port_internal_error_detected" 
x0210="Internal_bus_CRC_error" 
x0211="PCI_bus_abort_error" 
x0212="PCI_bus_parity_error" 
x0213="Port_handler_error" 
x0214="Token_interrupt_count_error" 
x0215="PCI_bus_timeout" 
x0216="Buffer_ECC_error_corrected" 
x0217="Buffer_ECC_error_not_corrected" 
x0218="Xop_pool_parity_error" 
x0230="Unsupported_command_during_flash_recovery" 
x0231="Next_image_buffer_expected" 
x0232="Binary_image_architecture_ID_incompatible" 
x0233="Binary_image_no_signature_detected" 
x0234="Binary_image_checksum_error_detected" 
x0235="Binary_image_buffer_overflow_detected" 
x0236="Binary_image_SRL_incompatible" 
x0240="I2C_device_not_detected" 
x0241="I2C_transaction_aborted" 
x0242="SO-DIMM_parameters_incompatible_using_defaults" 
x0243="SO-DIMM_unsupported" 
x0244="I2C_clock_is_held_low_transfer_aborted" 
x0245="I2C_data_is_held_low_transfer_aborted" 
x0246="I2C_slave_device_NACKed_the_transfer" 
x0247="I2C_buffer_in-sufficient" 
x0248="SPI_transfer_status_error" 
x024A="I2C_interface_is_active" 
x024B="Lost_arbitration" 
x024C="I2C_transfer_error" 
x0250="Unit_descriptor_size_invalid" 
x0251="Unit_descriptor_size_exceeds_data_buffer" 
x0252="Invalid_value_in_unit_descriptor" 
x0253="Inadequate_disk_space_to_support_descriptor" 
x0254="Unable_to_create_data_channel_for_this_unit_descriptor" 
x0255="Unit_descriptor_specifies_a_drive_already_in_use" 
x0256="Unable_to_write_configuration_to_all_disks" 
x0257="Unit_descriptor_version_not_supported" 
x0258="Invalid_subunit_for_RAID_0_or_5" 
x0259="Too_many_unit_descriptors" 
x025A="Invalid_configuration_in_unit_descriptor" 
x025B="Invalid_LBA_offset_in_unit_descriptor" 
x025C="Invalid_stripelet_size_in_unit_descriptor" 
x025D="JBOD_unit_is_not_allowed" 
x025E="Operation_not_allowed_retained_cache_data" 
x025F="Exceeded_maximum_number_of_active_drives" 
x0261="Maximum_number_of_units_reached" 
x0260="SMART_threshold_exceeded" 
x0270="Unit_not_in_NORMAL_state" 
x0271="Invalid_drive_members" 
x0272="Converted_unit_not_supported" 
x0280="ResponseIU_status_code_EC_STATUS_BUSY" 
x0281="ResponseIU_status_code_EC_STATUS_QUEUE_FULL" 
x0282="ResponseIU_status_code_EC_STATUS_UNEXPECTED" 
x0283="IO_Hold_Error"
x0290="No_Sense_Info_EC_SK_NO_SENSE_INFO"  
x0291="Recovered_Error_EC_SK_RECOVERED_ERROR"  
x0293="Hardware_Error_EC_SK_HARDWARE_ERROR"  
x0294="Hardware_ECC_Error_EC_SK_HARDWARE_ECC"  
x0295="Illegal_Req_EC_SK_ILLEGAL_REQ"  
x0296="Unit_Attention_EC_SK_UNIT_ATTENTION"  
x0297="Unit_Attention_Reset_EC_SK_UNIT_ATTENTION" 
# note: The error code below is reused - Commented Out 
#x0205="ResponseIU_status_codeEC_SK_UNIT_REset" 
x0298="Aborted_Cmd_EC_SK_ABORTED_CMD"  
x0299="Sense_Keys_Unexpected_EC_SK_UNEXPECTED"  
x029A="Unit_Attention_Mode_Page_Changed_EC_SK_UNIT_ATTENTION" 
x029B="Current_command_Write_Fault"
x029C="Deferred_Drive_Write_Fault"
x029D="Lba_Out_Of_Range"
x02A0="SAS_error_code_EC_PAYLOAD_PARITY" 
x02A1="SAS_error_code_EC_UNDER_RUN_IN_RW" 
x02A2="SAS_error_code_EC_UNDER_RUN_OUT" 
x02A3="SAS_error_code_EC_OVER_RUN" 
x02A4="SAS_error_code_EC_OPEN_REJECT_BUSY"  
x02A5="SAS_error_code_EC_OPEN_REJECT_RETRY"   
x02A6="SAS_error_code_EC_OPEN_REJECT_ABANDON"   
x02A7="SAS_error_code_EC_OPEN_REJECT_STP_RES_BUSY"   
x02A8="SAS_error_code_EC_RX_FRAME_ERROR"   
x02A9="SAS_error_code_EC_RX_TRANSPORT_ERROR" 
x02AA="SAS_error_code_EC_PORT_OFFLINE"   
x02B0="Tx_failure_-_SATA_SYNC_received" 
x02B1="Tx_failure_-_BREAK_received" 
x02B2="Protocol_overrun" 
x02B3="Protocol_underrun" 
x02B4="Open_failure_-_Connection_rejected" 
x02B5="Open_failure_-_Bad_destination" 
x02B6="Open_failure_-_Wrong_destination" 
x02B7="Open_failure_-_Connection_rate_not_supported" 
x02B8="Open_failure_-_Protocol_not_supported" 
x02B9="Open_failure_-_STP_Resources_busy" 
x02BA="Open_failure_-_No_destination" 
x02BB="Open_failure_-_Pathway_blocked" 
x02BC="Open_failure_-_Retry" 
x02BD="Open_failure_-_Open_frame_timeout" 
x02BE="STP_Inactivity" 
x02BF="Failed_to_discover_Emulex_chip" 
x02C0="Emulex_flash_file_is_corrupted" 
x02C1="Error_while_flashing_Emulex" 
x02C2="Target_returned_valid_sense_data_during_a_SCSI_PASSTHROUGH" 
x02C3="Failed_to_unlock_flash_block_while_flashing_Emulex_ROM" 
x02C4="Failed_to_erase_flash_block_while_flashing_Emulex_ROM" 
x02C5="Failed_to_write_flash_block_while_flashing_Emulex_ROM" 
x02C6="Failed_to_lock_flash_block_while_flashing_Emulex_ROM" 
x02C7="ROM_size_is_not_a_multiple_of_128k" 
x02C8="Emulex_SLI_command_timeout" 
x02C9="Emulex_mailbox_status_error" 
x02CA="Emulex_mailbox_format_error" 
x02CB="Emulex_no_resources" 
x02CC="Emulex_protocol_check_error" 
x02CD="Emulex_protocol_fis_error" 
x0300="Internal_errorcode_BBU_base_-_should_not_occur" 
x0301="Invalid_BBU_state_change_request"  
x0302="The_BBU_resource_needed_is_in_use_retry_command_after_a_delay"  
x0303="Command_requires_a_battery_pack_to_be_present_and_enabled" 
x0310="BBU_command_packet_error" 
x0311="BBU_command_not_implemented" 
x0312="BBU_command_buffer_underflow" 
x0313="BBU_command_buffer_overflow" 
x0314="BBU_command_incomplete" 
x0315="BBU_command_checksum_error" 
x0316="BBU_command_timeout" 
x0317="BBU_flash_operation_failed" 
x0318="BBU_flash_Vpp_voltage_out_of_progamming_range" 
x0319="BBU_flash_incorrect_command_or_parameter_or_not_enough_space_in_stack" 
x031A="BBU_flash_not_yet_completed" 
x031B="BBU_flash_write_skip" 
x031C="BBU_flash_invalid_erase_sector" 
x0320="BBU_parameter_not_defined" 
x0321="BBU_parameter_size_mismatch" 
x0322="Cannot_write_a_read-only_BBU_parameter" 
x0323="Invalid_state_bits_in_BBU_SetportPins_command" 
x0380="BBU_firmware_version_string_not_found" 
x0381="BBU_operating_state_not_available" 
x0382="BBU_not_present" 
x0383="BBU_not_ready" 
x0384="BBU_S1_not_compatible_with_HBA" 
x0385="BBU_S0_not_compatible_with_HBA" 
x0386="BBU_not_compatible_with_HBA" 
x0387="BBU_not_in_S0" 
x0388="BBU_not_in_S1" 
x0389="Timeout_on_BBU_power_fail_interrupt" 
x038A="BBU_invalid_response_length" 
x038B="Not_S1_ident_or_event_packet" 
x038C="HBA_has_backup_data" 
x038D="Invalid_BBU_state" 
x038E="BBU_invalid_response_code" 
x0390="Log_updates_not_allowed" 
x0391="Logs_are_invalid" 
x0392="Logs_not_found" 
x0400="Invalid_enclosure_port_defined" 
x0401="Enclosure_resource_reserved" 
x0402="Enclosure_parameter_not_defined" 
x0403="Enclosure_parameter_re-defined" 
x0404="Enclosure_port_is_input_port" 
x0405="Invalid_SAFTE_page_requested" 
x0406="Invalid_SES_page_requested" 
x0407="EPCT_device_description_error" 
x0408="EPCT_device_redefined" 
x0409="EPCT_element_unknown" 
x040A="EPCT_device_unknown" 
x040B="EPCT_ID_unknown" 
x040C="Invalid_enclosure_device" 
x040D="EPCT_LED_descriptor_redefinition" 
x040F="Enclosure_device_not_initialized" 
x0410="Temperature_sensor_reading_unknown" 
x0411="Enclosure_not_present" 
x0412="Bad_EPCT_version" 
x0413="Failed_to_create_SEP_object" 
x0414="Too_many_enclosures_cannot_add_more" 
x0415="Failed_to_create_enclosure_object" 
x0416="Invalid_Sep_Command" 
x1000="EC_NEED_CMD_PROCESS" 
x1001="EC_UDMA_UPGRADE_SKIPPED" 
x1002="EC_DRIVE_NOT_IN_UDMA" 
x1003="EC_OFFLINE_TIMER_RUNNING" 
x1004="EC_BIN_HANDLE_NOT_EMPTY" 
x1005="EC_BIN_HANDLE_WRONG_OWNER" 
x1006="EC_CMD_IN_PBUF" 
x1007="EC_INVALID_DATA_CHKSUM" 
x1008="EC_LBA_OVERLAP" 
x1009="EC_SGL_NON_SECTOR_SIZE" 
x100A="Retry_CMD"
x1010="Error_recovery_in_progress" 
x1011="Error_recovery_complete" 
x1012="No_LBA_to_repair_sector" 
x1013="Retry_recovery_step" 
x1014="Do_error_action" 
x1015="Degrade_unit" 
x1016="Sector_repair_was_not_completed" 
x1017="Command_aborted" 
x1018="Drive_added" 
x1019="Drive_removed" 
x101A="Retry_queued_command" 
x101B="Drive_error" 
x101C="Non-Dma_Retry_no_recovery" 
x101D="Drive_removed_no_wait" 
x1020="Simulate_power_fail" 
x1021="Simulate_uC_error" 
x2000="Checksum_of_cache_meta_data_is_bad" 
x2001="Signature_of_cache_meta_data_is_bad" 
x2FFF="EC_FEATURE_NOT_IMPLEMENTED" 
x3013="Data_integrity_error_in_diagnostic_test" 
x3014="Undefined_Sub-command_for_diag_test" 
x3017="Drive_reset_error_thru_Marvell" 
x3018="Reading_config_space_error" 
x3019="Read_or_write_memory_space_data_integrity_error" 
x301A="Pchip_UCbuf_data_integrity_error" 
x301B="Pchip_Xop_Pool_data_integrity_error" 
x301C="Pchip_Cmd_Ram_data_integrity_error" 
x301E="iHandler_was_busy_before_diag_test" 
x3021="An_unimplemented_method_was_invoked" 
x3024="Data_lines_shorted_in_Sbuf_RAM" 
x3025="Data_lines_open_in_Sbuf_RAM" 
x3026="Addr_line_problem_in_Sbuf_RAM" 
x3027="Sbuf_RAM_unreadable" 
x3047="Cant_fill_Sbuf_with_zeros" 
x3062="iHandler_error_during_xfer_op" 
x3063="Bad_disk_sequencer_cmd_issued_to_Aport" 
x3064="Bad_RAM_location" 
x3065="Bad_Shadowed_RAM_location" 
x3066="Cant_determine_Sbuf_size" 
x3067="Pbuf_read_or_write_error" 
x3068="XOR_error" 
x3069="No_disk_found_on_requested_Aport" 
x306A="Interrupt_line_error" 
x306B="Unable_to_calculate_checksum" 
x306C="BBU_S0_or_S1_firmware_boundary_error" 
x306D="Old_method_selected_wrong_value_EC_DQS_FIFO_set_WRONG" 
x3070="NvRam_read_or_write_test_error" 
x3071="SpdRom_read_test_error" 
x3072="Hareware_strap_error" 
x3073="Clock_Generator_data_integrity_error" 
x3074="Inject_SBUF_ECC_incorrect_param"
x3100="Error_manufacturing_diagnostic_test_failed"
x3101="XScale_Core_Processor_Subtest"
x3102="SRAM_Subtest"
x3103="TPMI_Subtest"
x3104="Component_Internal_RAM_Subtest"
x3105="ASIC_Register_Subtest"
x3106="PCIX-E_Loopback_Subtest"
x3107="4.0G_FC_or_3.0G_SAS_Link_Internal_Analog_Loopback_Subtest"
x3108="1.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x3109="2.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x310A="4.0G_FC_or_3.0G_SAS_Link_External_Loopback_Subtest"
x310B="TDMA_Subtest"
x310C="Concurrent_DMA_Subtest"
x310D="SDRAM_Subtest"
x310E="Error_manufacturing_diagnostic_test-Coordinated_Reset_failed"
x310F="Error_manufacturing_diagnostic_test-Preemptive_Reset_failed"
x3110="Error_manufacturing_diagnostic_test-Invalid_Request_failed"
x3111="Hareware_strap_error"
x7E00="Error_manufacturing_diagnostic_test_failed"
x7E01="XScale_Core_Processor_Subtest"
x7E02="SRAM_Subtest"
x7E03="TPMI_Subtest"
x7E04="Component_Internal_RAM_Subtest"
x7E05="ASIC_Register_Subtest"
x7E06="PCIX-E_Loopback_Subtest"
x7E07="4.0G_FC_or_3.0G_SAS_Link_Internal_Analog_Loopback_Subtest"
x7E08="1.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x7E09="2.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x7E0A="4.0G_FC_or_3.0G_SAS_Link_External_Loopback_Subtest"
x7E0B="TDMA_Subtest"
x7E0C="Concurrent_DMA_Subtest"
x7E0D="SDRAM_Subtest"
x7E0E="Error_manufacturing_diagnostic_test-Coordinated_Reset_failed"
x7E0F="Error_manufacturing_diagnostic_test-Preemptive_Reset_failed"
x7E10="Error_manufacturing_diagnostic_test-Invalid_Request_failed"

for i in "x0000 $x0000" "x0001 $x0001" "x0002 $x0002" "x0003 $x0003" "x0004 $x0004" "x0005 $x0005" "x0006 $x0006" "x0007 $x0007" "x0008 $x0008" "x0009 $x0009" "x000A $x000A" "x000B $x000B" "x000C $x000C" "x000D $x000D" "x000E $x000E" "x000F $x000F" "x0010 $x0010" "x0011 $x0011" "x0012 $x0012" "x0013 $x0013" "x0014 $x0014" "x0015 $x0015" "x0016 $x0016" "x0017 $x0017" "x0018 $x0018" "x0019 $x0019" "x001A $x001A" "x001B $x001B" "x001C $x001C" "x001D $x001D" "x001E $x001E" "x001F $x001F" "x0020 $x0020" "x0021 $x0021" "x0022 $x0022" "x0023 $x0023" "x0024 $x0024" "x0025 $x0025" "x0026 $x0026" "x0027 $x0027" "x0028 $x0028" "x0029 $x0029" "x002A $x002A" "x002B $x002B" "x002C $x002C" "x002D $x002D" "x002E $x002E" "x002F $x002F" "x0030 $x0030" "x0031 $x0031" "x0032 $x0032" "x0033 $x0033" "x0034 $x0034" "x0035 $x0035" "x0036 $x0036" "x0037 $x0037" "x0038 $x0038" "x0039 $x0039" "x003A $x003A" "x003B $x003B" "x003C $x003C" "x003D $x003D" "x003E $x003E" "x003F $x003F" "x0040 $x0040" "x0041 $x0041" "x0042 $x0042" "x0043 $x0043" "x0044 $x0044" "x0045 $x0045" "x0046 $x0046" "x0047 $x0047" "x0048 $x0048" "x0049 $x0049" "x004A $x004A" "x0051 $x0051" "x0060 $x0060" "x0061 $x0061" "x0100 $x0100" "x0101 $x0101" "x0102 $x0102" "x0103 $x0103" "x0104 $x0104" "x0105 $x0105" "x0106 $x0106" "x0107 $x0107" "x0108 $x0108" "x0109 $x0109" "x010A $x010A" "x010B $x010B" "x010C $x010C" "x010D $x010D" "x010E $x010E" "x010F $x010F" "x0110 $x0110" "x0111 $x0111" "x0112 $x0112" "x0113 $x0113" "x0114 $x0114" "x0115 $x0115" "x0116 $x0116" "x011E $x011E" "x011F $x011F" "x0120 $x0120" "x0121 $x0121" "x0122 $x0122" "x0123 $x0123" "x0124 $x0124" "x0125 $x0125" "x0126 $x0126" "x0127 $x0127" "x0128 $x0128" "x0129 $x0129" "x012A $x012A" "x012B $x012B" "x012C $x012C" "x012D $x012D" "x012E $x012E" "x012F $x012F" "x0130 $x0130" "x0131 $x0131" "x0132 $x0132" "x0133 $x0133" "x0140 $x0140" "x0150 $x0150" "x0151 $x0151" "x0152 $x0152" "x0153 $x0153" "x0160 $x0160" "x0161 $x0161" "x0162 $x0162" "x0170 $x0170" "x0171 $x0171" "x0180 $x0180" "x0181 $x0181" "x0182 $x0182" "x0183 $x0183" "x0184 $x0184" "x0185 $x0185" "x01A0 $x01A0" "x01C0 $x01C0" "x01C1 $x01C1" "x01C2 $x01C2" "x01C3 $x01C3" "x01C4 $x01C4" "x01C5 $x01C5" "x01C6 $x01C6" "x01C7 $x01C7" "x01C8 $x01C8" "x01C9 $x01C9" "x01CA $x01CA" "x01CB $x01CB" "x01CC $x01CC" "x01CD $x01CD" "x01CE $x01CE" "x01D0 $x01D0" "x01D1 $x01D1" "x01D2 $x01D2" "x01D3 $x01D3" "x01D4 $x01D4" "x0200 $x0200" "x0201 $x0201" "x0202 $x0202" "x0203 $x0203" "x0204 $x0204" "x0205 $x0205" "x0206 $x0206" "x0207 $x0207" "x0208 $x0208" "x0209 $x0209" "x020A $x020A" "x020B $x020B" "x020C $x020C" "x020D $x020D" "x0210 $x0210" "x0211 $x0211" "x0212 $x0212" "x0213 $x0213" "x0214 $x0214" "x0215 $x0215" "x0216 $x0216" "x0217 $x0217" "x0218 $x0218" "x0230 $x0230" "x0231 $x0231" "x0232 $x0232" "x0233 $x0233" "x0234 $x0234" "x0235 $x0235" "x0236 $x0236" "x0240 $x0240" "x0241 $x0241" "x0242 $x0242" "x0243 $x0243" "x0244 $x0244" "x0245 $x0245" "x0246 $x0246" "x0247 $x0247" "x0248 $x0248" "x024A $x024A" "x024B $x024B" "x024C $x024C" "x0250 $x0250" "x0251 $x0251" "x0252 $x0252" "x0253 $x0253" "x0254 $x0254" "x0255 $x0255" "x0256 $x0256" "x0257 $x0257" "x0258 $x0258" "x0259 $x0259" "x025A $x025A" "x025B $x025B" "x025C $x025C" "x025D $x025D" "x025E $x025E" "x025F $x025F" "x0261 $x0261" "x0260 $x0260" "x0270 $x0270" "x0271 $x0271" "x0272 $x0272" "x0280 $x0280" "x0281 $x0281" "x0282 $x0282" "x0283 $x0283" "x0290 $x0290" "x0291 $x0291" "x0293 $x0293" "x0294 $x0294" "x0295 $x0295" "x0296 $x0296" "x0297 $x0297" "x0298 $x0298" "x0299 $x0299" "x029A $x029A" "x029B $x029B" "x029C $x029C" "x029D $x029D" "x02A0 $x02A0" "x02A1 $x02A1" "x02A2 $x02A2" "x02A3 $x02A3" "x02A4 $x02A4" "x02A5 $x02A5" "x02A6 $x02A6" "x02A7 $x02A7" "x02A8 $x02A8" "x02A9 $x02A9" "x02AA $x02AA" "x02B0 $x02B0" "x02B1 $x02B1" "x02B2 $x02B2" "x02B3 $x02B3" "x02B4 $x02B4" "x02B5 $x02B5" "x02B6 $x02B6" "x02B7 $x02B7" "x02B8 $x02B8" "x02B9 $x02B9" "x02BA $x02BA" "x02BB $x02BB" "x02BC $x02BC" "x02BD $x02BD" "x02BE $x02BE" "x02BF $x02BF" "x02C0 $x02C0" "x02C1 $x02C1" "x02C2 $x02C2" "x02C3 $x02C3" "x02C4 $x02C4" "x02C5 $x02C5" "x02C6 $x02C6" "x02C7 $x02C7" "x02C8 $x02C8" "x02C9 $x02C9" "x02CA $x02CA" "x02CB $x02CB" "x02CC $x02CC" "x02CD $x02CD" "x0300 $x0300" "x0301 $x0301" "x0302 $x0302" "x0303 $x0303" "x0310 $x0310" "x0311 $x0311" "x0312 $x0312" "x0313 $x0313" "x0314 $x0314" "x0315 $x0315" "x0316 $x0316" "x0317 $x0317" "x0318 $x0318" "x0319 $x0319" "x031A $x031A" "x031B $x031B" "x031C $x031C" "x0320 $x0320" "x0321 $x0321" "x0322 $x0322" "x0323 $x0323" "x0380 $x0380" "x0381 $x0381" "x0382 $x0382" "x0383 $x0383" "x0384 $x0384" "x0385 $x0385" "x0386 $x0386" "x0387 $x0387" "x0388 $x0388" "x0389 $x0389" "x038A $x038A" "x038B $x038B" "x038C $x038C" "x038D $x038D" "x038E $x038E" "x0390 $x0390" "x0391 $x0391" "x0392 $x0392" "x0400 $x0400" "x0401 $x0401" "x0402 $x0402" "x0403 $x0403" "x0404 $x0404" "x0405 $x0405" "x0406 $x0406" "x0407 $x0407" "x0408 $x0408" "x0409 $x0409" "x040A $x040A" "x040B $x040B" "x040C $x040C" "x040D $x040D" "x040F $x040F" "x0410 $x0410" "x0411 $x0411" "x0412 $x0412" "x0413 $x0413" "x0414 $x0414" "x0415 $x0415" "x0416 $x0416" "x1000 $x1000" "x1001 $x1001" "x1002 $x1002" "x1003 $x1003" "x1004 $x1004" "x1005 $x1005" "x1006 $x1006" "x1007 $x1007" "x1008 $x1008" "x1009 $x1009" "x100A $x100A" "x1010 $x1010" "x1011 $x1011" "x1012 $x1012" "x1013 $x1013" "x1014 $x1014" "x1015 $x1015" "x1016 $x1016" "x1017 $x1017" "x1018 $x1018" "x1019 $x1019" "x101A $x101A" "x101B $x101B" "x101C $x101C" "x101D $x101D" "x1020 $x1020" "x1021 $x1021" "x2000 $x2000" "x2001 $x2001" "x2FFF $x2FFF" "x3013 $x3013" "x3014 $x3014" "x3017 $x3017" "x3018 $x3018" "x3019 $x3019" "x301A $x301A" "x301B $x301B" "x301C $x301C" "x301E $x301E" "x3021 $x3021" "x3024 $x3024" "x3025 $x3025" "x3026 $x3026" "x3027 $x3027" "x3047 $x3047" "x3062 $x3062" "x3063 $x3063" "x3064 $x3064" "x3065 $x3065" "x3066 $x3066" "x3067 $x3067" "x3068 $x3068" "x3069 $x3069" "x306A $x306A" "x306B $x306B" "x306C $x306C" "x306D $x306D" "x3070 $x3070" "x3071 $x3071" "x3072 $x3072" "x3073 $x3073" "x3074 $x3074" "x3100 $x3100" "x3101 $x3101" "x3102 $x3102" "x3103 $x3103" "x3104 $x3104" "x3105 $x3105" "x3106 $x3106" "x3107 $x3107" "x3108 $x3108" "x3109 $x3109" "x310A $x310A" "x310B $x310B" "x310C $x310C" "x310D $x310D" "x310E $x310E" "x310F $x310F" "x3110 $x3110" "x3111 $x3111" "x7E00 $x7E00" "x7E01 $x7E01" "x7E02 $x7E02" "x7E03 $x7E03" "x7E04 $x7E04" "x7E05 $x7E05" "x7E06 $x7E06" "x7E07 $x7E07" "x7E08 $x7E08" "x7E09 $x7E09" "x7E0A $x7E0A" "x7E0B $x7E0B" "x7E0C $x7E0C" "x7E0D $x7E0D" "x7E0E $x7E0E" "x7E0F $x7E0F" "x7E10 $x7E10"; do

set $i

if [ -e ./$fileName/3ware/3ware_driver_x03_9000_ERROR.txt ]; then
       $grep -i $1 ./$fileName/3ware/3ware_driver_x03_9000_ERROR.txt > ./$fileName/3ware/3ware_driver_x03_$1_$2.txt

		if [ ! -s ./$fileName/3ware/3ware_driver_x03_$1_$2.txt ]; then rm ./$fileName/3ware/3ware_driver_x03_$1_$2.txt > /dev/null 2>&1 ; fi

fi

done

###########################################################################################################################
# Deferred errors (AENs) 0x04 
###########################################################################################################################
x0000="AEN_queue_empty" 
x0001="Controller_reset_occurred" 
x0002="Degraded_unit" 
x0003="Controller_error_occurred" 
x0004="Rebuild_failed" 
x0005="Rebuild_completed" 
x0006="Incomplete_unit_detected" 
x0007="Initialize_completed" 
x0008="Unclean_shutdown_detected" 
x0009="Drive_timeout_detected" 
x000A="Drive_error_detected" 
x000B="Rebuild_started" 
x000C="Initialize_started" 
x000D="Unit_deleted" 
x000E="Initialize_failed" 
x000F="SMART_threshold_exceeded" 
x0010="Power_supply_reported_AC_under_range" 
x0011="Power_supply_reported_DC_out_of_range" 
x0012="Power_supply_reported_a_malfunction" 
x0013="Power_supply_predicted_malfunction" 
x0014="Battery_charge_below_threshold" 
x0015="Fan_speed_below_threshold" 
x0016="Temperature_sensor_above_threshold" 
x0017="Power_supply_removed" 
x0018="Power_supply_inserted" 
x0019="Drive_removed" 
x001A="Drive_inserted" 
x001B="Drive_bay_cover_door_was_opened" 
x001C="Drive_bay_cover_door_was_closed" 
x001D="Product_case_was_opened" 
x001E="Unit_inoperable" 
x001F="Unit_operational" 
x0020="Prepare_for_shutdown_power-off" 
x0021="Downgrade_UDMA_mode" 
x0022="Upgrade_UDMA_mode" 
x0023="Sector_repair_completed" 
x0024="Buffer_integrity_test_failed" 
x0025="Cache_flush_failed_some_data_lost" 
x0026="Drive_ECC_error_reported" 
x0027="DCB_checksum_error_detected" 
x0028="DCB_version_unsupported" 
x0029="Verify_started" 
x002A="Verify_failed" 
x002B="Verify_completed" 
x002C="Source_drive_ECC_error_overwritten" 
x002D="Source_drive_error_occurred" 
x002E="Replacement_drive_capacity_too_small" 
x002F="Verify_not_started_unit_never_initialized" 
x0030="Drive_not_supported" 
x0031="Synchronize_host_or_controller_time" 
x0032="Spare_capacity_too_small_for_some_units" 
x0033="Migration_started" 
x0034="Migration_failed" 
x0035="Migration_completed" 
x0036="Verify_fixed_data_or_parity_mismatch" 
x0037="SO-DIMM_not_compatible" 
x0038="SO-DIMM_not_detected" 
x0039="Buffer_ECC_error_corrected" 
x003A="Drive_power_on_reset_detected" 
x003B="Rebuild_paused" 
x003C="Initialize_paused" 
x003D="Verify_paused" 
x003E="Migration_paused" 
x003F="Flash_file_system_error_detected" 
x0040="Flash_file_system_repaired" 
x0041="Unit_number_assignments_lost" 
x0042="Primary_DCB_read_error_occurred" 
x0043="Backup_DCB_read_error_detected" 
x0044="Battery_voltage_is_normal" 
x0045="Battery_voltage_is_low" 
x0046="Battery_voltage_is_high" 
x0047="Battery_voltage_is_too_low" 
x0048="Battery_voltage_is_too_high" 
x0049="Battery_temperature_is_normal" 
x004A="Battery_temperature_is_low" 
x004B="Battery_temperature_is_high" 
x004C="Battery_temperature_is_too_low" 
x004D="Battery_temperature_is_too_high" 
x004E="Battery_capacity_test_started" 
x004F="Cache_synchronization_skipped" 
x0050="Battery_capacity_test_completed" 
x0051="Battery_health_check_started" 
x0052="Battery_health_check_completed" 
x0053="Battery_capacity_test_is_overdue" 
x0054="Charge_termination_voltage_is_at_high_level" 
x0055="Battery_charging_started" 
x0056="Battery_charging_completed" 
x0057="Battery_charging_fault" 
x0058="Battery_capacity_is_below_warning_level" 
x0059="Battery_capacity_is_below_error_level" 
x005A="Battery_is_present" 
x005B="Battery_is_not_present" 
x005C="Battery_is_weak" 
x005D="Battery_health_check_failed" 
x005E="Cache_synchronization_completed" 
x005F="Cache_synchronization_failed_some_data_lost" 
x0060="Redundancy_level_decreased" 
x0061="Redundancy_level_increased" 
#x0062="Enclosure_removed__9.5.0_CodeSet_and_Later" 
#x0062="Local_link_up__PRE_9.5.0_CodeSet" 
x0062="Shared_x0062" 
#x0063="Enclosure_added__9.5.0_CodeSet_and_Later" 
#x0063="Local_link_down__PRE_9.5.0_CodeSet" 
x0063="Shared_x0063" 
#x0064="Local_link_up__9.5.0_CodeSet_and_Later" 
#x0064="Enclosure_removed__Only_9.4.3_CodeSet"  
x0064="Shared_x0064"  
#x0065="Local_link_down__9.5.0_CodeSet_and_Later" 
#x0065="Enclosure_added__Only_9.4.3_CodeSet"  
x0065="Shared_x0065"  
x0067="NVRAM_data_preserved_over_power_fail"
x0068="NVRAM_data_not_preserved_over_power_fail"
x0070="Drive_Write_Fault"
x00F7="Bad_cache_metadata_checksum" 
x00F8="Bad_cache_metadata_signature" 
x00F9="Cache_metadata_restore_failed" 
x00FA="BBU_not_found_after_power_fail" 
x00FB="BBU_and_HBA_state_out_of_sync" 
x00FC="Recovered_or_finished_array_membership_update" 
x00FD="Handler_lockup" 
x00FE="Retrying_PCI_transfer" 
x00FF="AEN_queue_is_full" 
x0100="Error_occurred_during_device_discovery" 
x8000="Enclosure_fan_normal"
x8001="Enclosure_fan_error"
x8002="Enclosure_fan_removed"
x8003="Enclosure_fan_added"
x8004="Enclosure_fan_status_unknown"
x8005="Enclosure_fan_on"
x8006="Enclosure_fan_off"
x8010="Enclosure_fan_stopped"
x8011="Enclosure_fan_started"
x8012="Enclosure_fan_speed_increased"
x8013="Enclosure_fan_speed_decreased"
x8020="Enclosure_temperature_normal"
x8021="Enclosure_temperature_low"
x8022="Enclosure_temperature_high"
x8023="Enclosure_temperature_too_low"
x8024="Enclosure_temperature_too_high"
x8025="Enclosure_temperature_sensor_removed"
x8026="Enclosure_temperature_sensor_added"
x8027="Enclosure_temperature_sensor_error"
x8028="Enclosure_temperature_status_unknown"
x8030="Enclosure_power_supply_normal"
x8031="Enclosure_power_supply_failed"
x8032="Enclosure_power_supply_removed"
x8033="Enclosure_power_supply_added"
x8034="Enclosure_power_supply_status_unknown"
x8036="Enclosure_power_supply_on"
x8037="Enclosure_power_supply_off"
x8040="Enclosure_power_supply_voltage_normal"
x8041="Enclosure_power_supply_voltage_high"
x8042="Enclosure_power_supply_voltage_low"
x8043="Enclosure_power_supply_voltage_status_unknown"
x8044="Enclosure_power_supply_current_normal"
x8045="Enclosure_power_supply_current_high"
x8046="Enclosure_power_supply_current_status_unknown"
 
#Deferred errors(AENs)0x04 
for i in "x0000 $x0000" "x0001 $x0001" "x0002 $x0002" "x0003 $x0003" "x0004 $x0004" "x0005 $x0005" "x0006 $x0006" "x0007 $x0007" "x0008 $x0008" "x0009 $x0009" "x000A $x000A" "x000B $x000B" "x000C $x000C" "x000D $x000D" "x000E $x000E" "x000F $x000F" "x0010 $x0010" "x0011 $x0011" "x0012 $x0012" "x0013 $x0013" "x0014 $x0014" "x0015 $x0015" "x0016 $x0016" "x0017 $x0017" "x0018 $x0018" "x0019 $x0019" "x001A $x001A" "x001B $x001B" "x001C $x001C" "x001D $x001D" "x001E $x001E" "x001F $x001F" "x0020 $x0020" "x0021 $x0021" "x0022 $x0022" "x0023 $x0023" "x0024 $x0024" "x0025 $x0025" "x0026 $x0026" "x0027 $x0027" "x0028 $x0028" "x0029 $x0029" "x002A $x002A" "x002B $x002B" "x002C $x002C" "x002D $x002D" "x002E $x002E" "x002F $x002F" "x0030 $x0030" "x0031 $x0031" "x0032 $x0032" "x0033 $x0033" "x0034 $x0034" "x0035 $x0035" "x0036 $x0036" "x0037 $x0037" "x0038 $x0038" "x0039 $x0039" "x003A $x003A" "x003B $x003B" "x003C $x003C" "x003D $x003D" "x003E $x003E" "x003F $x003F" "x0040 $x0040" "x0041 $x0041" "x0042 $x0042" "x0043 $x0043" "x0044 $x0044" "x0045 $x0045" "x0046 $x0046" "x0047 $x0047" "x0048 $x0048" "x0049 $x0049" "x004A $x004A" "x004B $x004B" "x004C $x004C" "x004D $x004D" "x004E $x004E" "x004F $x004F" "x0050 $x0050" "x0051 $x0051" "x0052 $x0052" "x0053 $x0053" "x0054 $x0054" "x0055 $x0055" "x0056 $x0056" "x0057 $x0057" "x0058 $x0058" "x0059 $x0059" "x005A $x005A" "x005B $x005B" "x005C $x005C" "x005D $x005D" "x005E $x005E" "x005F $x005F" "x0060 $x0060" "x0061 $x0061" "x0062 $x0062" "x0063 $x0063" "x0064 $x0064" "x0065 $x0065" "x0067 $x0067" "x0068 $x0068" "x0070 $x0070" "x00F7 $x00F7" "x00F8 $x00F8" "x00F9 $x00F9" "x00FA $x00FA" "x00FB $x00FB" "x00FC $x00FC" "x00FD $x00FD" "x00FE $x00FE" "x00FF $x00FF" "x0100 $x0100" "x8000 $x8000" "x8001 $x8001" "x8002 $x8002" "x8003 $x8003" "x8004 $x8004" "x8005 $x8005" "x8006 $x8006" "x8010 $x8010" "x8011 $x8011" "x8012 $x8012" "x8013 $x8013" "x8020 $x8020" "x8021 $x8021" "x8022 $x8022" "x8023 $x8023" "x8024 $x8024" "x8025 $x8025" "x8026 $x8026" "x8027 $x8027" "x8028 $x8028" "x8030 $x8030" "x8031 $x8031" "x8032 $x8032" "x8033 $x8033" "x8034 $x8034" "x8036 $x8036" "x8037 $x8037" "x8040 $x8040" "x8041 $x8041" "x8042 $x8042" "x8043 $x8043" "x8044 $x8044" "x8045 $x8045" "x8046 $x8046"; do

set $i

if [ -e ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt ]; then

       $grep -i $1 ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt > ./$fileName/3ware/3ware_driver_x04_$1_$2.txt

		if [ ! -s ./$fileName/3ware/3ware_driver_x04_$1_$2.txt ]; then rm ./$fileName/3ware/3ware_driver_x04_$1_$2.txt > /dev/null 2>&1 ; fi

fi
done

if [ -e ./$fileName/3ware/3ware_driver_x04_x0062_Shared_x0062.txt ]; then
grep -i "Enclosure removed" ./$fileName/3ware/3ware_driver_x04_x0062_Shared_x0062.txt > ./$fileName/3ware/3ware_driver_x04_x0062_Enclosure_removed.txt
grep -i "Local link up" ./$fileName/3ware/3ware_driver_x04_x0062_Shared_x0062.txt > ./$fileName/3ware/3ware_driver_x04_x0062_Local_link_up.txt
rm ./$fileName/3ware/3ware_driver_x04_x0062_Shared_x0062.txt
fi

if [ -e ./$fileName/3ware/3ware_driver_x04_x0063_Shared_x0063.txt ]; then
grep -i "Enclosure added" ./$fileName/3ware/3ware_driver_x04_x0063_Shared_x0063.txt > ./$fileName/3ware/3ware_driver_x04_x0063_Enclosure_added.txt
grep -i "Local link down" ./$fileName/3ware/3ware_driver_x04_x0063_Shared_x0063.txt > ./$fileName/3ware/3ware_driver_x04_x0063_Local_link_down.txt
rm ./$fileName/3ware/3ware_driver_x04_x0063_Shared_x0063.txt
fi

if [ -e ./$fileName/3ware/3ware_driver_x04_x0064_Shared_x0064.txt ]; then
grep -i "Local link up" ./$fileName/3ware/3ware_driver_x04_x0064_Shared_x0064.txt > ./$fileName/3ware/3ware_driver_x04_x0064_Local_link_up.txt
grep -i "Enclosure removed" ./$fileName/3ware/3ware_driver_x04_x0064_Shared_x0064.txt > ./$fileName/3ware/3ware_driver_x04_x0064_Enclosure_removed.txt
rm ./$fileName/3ware/3ware_driver_x04_x0064_Shared_x0064.txt
fi

if [ -e ./$fileName/3ware/3ware_driver_x04_x0065_Shared_x0065.txt ]; then
grep -i "Local link down" ./$fileName/3ware/3ware_driver_x04_x0065_Shared_x0065.txt > ./$fileName/3ware/3ware_driver_x04_x0065_Local_link_down.txt
grep -i "Enclosure added" ./$fileName/3ware/3ware_driver_x04_x0065_Shared_x0065.txt > ./$fileName/3ware/3ware_driver_x04_x0065_Enclosure_added.txt
rm ./$fileName/3ware/3ware_driver_x04_x0065_Shared_x0065.txt
fi

for i in _x0062_Enclosure_removed.txt _x0062_Local_link_up.txt _x0063_Enclosure_added.txt _x0063_Local_link_down.txt _x0064_Local_link_up.txt _x0064_Enclosure_removed.txt _x0065_Local_link_down.txt _x0065_Enclosure_added.txt; do

		if [ ! -s ./$fileName/3ware/3ware_driver_x04$l ]; then rm ./$fileName/3ware/3ware_driver_x04$l > /dev/null 2>&1 ; fi

done

###########################################################################################################################
###Update on CodeSet Change
# Based on errorcode.h 4.06.00.004FW 9.5.1 codeset
# Errors = 0x03 that accompany AEN's 0x04's don't have preceeding 0's
# Duplicate of 0x03 errors without preceeding 0's
# Example -  3w-9xxx: scsi0: AEN: WARNING (0x04:0x0043): Backup DCB read error detected:port=2, error=0x202.
# Legacy error_codes, these are reserved on Apache 
###########################################################################################################################
x0="no_error_status_dependent_code_for_this_error_status" 
x1="no_request_ID_available_for_this_error_status" 
x2="CP_queue_became_full" 
x3="illegal_SGL_offset_in_CP_Header" 
x4="illegal_number_of_SGL_entries_in_CPH" 
x5="could_not_allocate_additional_memory" 
x6="some_PCI_read_error_occurred" 
x7="timeout_during_PCI_transaction" 
x8="PCI_ERR_bit_for_a_PCI_transaction" 
x9="unrecoverable_disk_error" 
xA="completion_token_queue_overflow" 
xB="error_reading_SGL" 
xC="error_reading_CP_Header" 
xD="abort_req_for_cmd_that_wasn't_active" 
xE="illegal_size_in_CP_Header" 
xF="got_a_CPH_with_an_already_active_req_ID" 
x10="lengths_in_SGLs_not_match_block_count_in_CP" 
x11="requested_LBA_greater_than_maximum_LBA_of_the_unit" 
x12="host_address_or_SGL_size_not_on_8_dw_boundary" 
x13="data_integrity_error_on_read_or_write_test" 
x14="subcmd_num_in_CP_hdr_is_undef_for_this_cmd" 
x15="undefined_table_requested" 
x16="param_requested_is_out_of_bounds_of_table" 
x17="given_param_size_doesnt_match_param_size_in_table" 
x18="host_address_or_SGL_size_not_on_a_sector_boundary" 
x19="Achip_Unit_number_exceeds_maximum" 
x1A="bad_pairing_of_disk-op_or_xer-op_from_Aop_queue" 
x1B="Aport_timed_out_doing_an_Aop" 
x1C="an_Achip_GSR_interrupt_occurred" 
x1D="Aop_encountered_with_unknown_cmd_byte" 
x1E="PCI_was_busy_when_tried_to_do_a_PCI_read_or_write" 
x1F="next_Aop_should_have_been_a_disk-op_but_it_wasnt" 
x20="param_0_unsupported_for_now_for_get_or_set_param" 
x21="an_unimplemented_method_was_invoked" 
x22="request_ID_took_too_long_to_complete" 
x23="a_disk_task_file_error_occurred_during_a_1F_test" 
x24="data_lines_shorted_in_Sbuf_RAM" 
x25="data_lines_open_in_Sbuf_RAM" 
x26="addr_line_problem_in_Sbuf_RAM" 
x27="Sbuf_RAM_unreadable" 
x28="command_requires_at_least_1_SGL" 
x29="no_unit_num_is_available_for_use" 
x2A="CP_queue_was_empty_when_tried_to_get_a_CP_ptr_from_it" 
x2B="test_firmware_not_downloaded_to_RAM" 
x2C="an_attempt_was_made_to_nest_internal_requests" 
x2D="error_in_downloading_hex_file" 
x2E="error_in_programming_the_flash_ROM" 
x2F="error_in_rollcall" 
x30="error_in_wait_disks_rdy" 
x31="error_in_UIT_formatting" 
x32="incorrect_unit_type_for_the_request" 
x33="unit_does_not_have_the_logical_sub-unit_specified" 
x34="unit_has_corrupted_data_on_it" 
x35="could_not_write_DCB_to_disk" 
x36="could_not_get_profiler_from_disk" 
x37="unit_is_not_exportable" 
x38="unit_is_missing_a_sub-unit" 
x39="unit_is_not_operating_normally" 
x3A="not_enough_SBUF_segments_to_service_the_request" 
x3B="User_area_in_unit_was_not_written_with_zeroes" 
x3C="user_data_on_unit_did_not_verify" 
x3D="error_while_writing_0s_to_user_data" 
x3E="a_unit_does_not_contain_a_logical_mapping_for_a_phys_drive" 
x3F="drive_replacement_would_cause_a_double-degrade" 
x40="capacity_of_replacement_drive_is_too_small" 
x41="no_drive_detected" 
x42="drive_detected_to_be_busy" 
x43="aport_unavailable" 
x44="unable_to_clear_sbuf" 
x45="can_not_replace_drive_because_unit_not_degraded" 
x46="we_have_no_routine_to_program_this_mfr_or_type_of_flash" 
x47="can't_fill_Sbuf_with_zeros" 
x48="byte_count_in_PARAM_field_is_too_big_for_this_cmd" 
x49="timeout_while_waiting_for_data_from_display_panel" 
x4A="CRC_error_reported_on_BFB_transfer" 
x51="for_drive_errors_the_status_register_gets_stuffed_into_LSB_of_ESDC" 
x60="reserved_-_this_is_a_valid_drive_status_error_code" 
x61="reserved_-_this_is_a_valid_drive_status_error_code" 
x100="SGL_entry_contains_zero_data" 
x101="Invalid_command_opcode" 
x102="SGL_entry_has_unaligned_address" 
x103="SGL_size_does_not_match_command" 
x104="SGL_entry_has_illegal_length" 
x105="Command_packet_is_not_aligned" 
x106="Invalid_request_ID" 
x107="Duplicate_request_ID" 
x108="ID_not_locked" 
x109="LBA_out_of_range" 
x10A="Logical_unit_not_present" 
x10B="Parameter_table_does_not_exist" 
x10C="Parameter_index_does_not_exist" 
x10D="Invalid_field_in_CDB" 
x10E="Invalid_operation_for_specified_port" 
x10F="Parameter_item_size_mismatch" 
x110="Failed_memory_allocation" 
x111="Memory_request_too_large" 
x112="Out_of_memory_segments" 
x113="Invalid_address_to_deallocate" 
x114="Out_of_memory" 
x115="Out_of_heap" 
x116="Invalid_BIOS_buffer_id" 
x11E="Unrecovered_Read_Error"
x11F="Recovered_Data_with_error_correction_applied"
x120="Double_degrade" 
x121="Drive_not_degraded" 
x122="Reconstruct_error" 
x123="Replace_not_accepted" 
x124="Drive_capacity_too_small" 
x125="Sector_count_not_allowed" 
x126="No_spares_left" 
x127="Reconstruct_error" 
x128="Unit_offline" 
x129="Cannot_update_status_to_DCB" 
x12A="Invalid_configuration_for_split" 
x12B="Invalid_configuration_for_join" 
x12C="No_migration_recovery" 
x12D="No_SATA_spares" 
x12E="No_SAS_spares"  
x12F="Mixed_SAS_SATA_not_allowed_in_same_unit" 
x130="Invalid_stripe_handle" 
x131="Handle_that_was_not_locked" 
x132="Handle_that_was_not_empty" 
x133="Handle_has_different_owner" 
x140="IPR_has_parent" 
x150="Illegal_Pbuf_address_alignment" 
x151="Illegal_Pbuf_transfer_length" 
x152="Illegal_Sbuf_address_alignment" 
x153="Illegal_Sbuf_transfer_length" 
x160="Command_packet_too_large" 
x161="SGL_exceeds_maximum_length" 
x162="SGL_has_too_many_entries" 
x170="Insufficient_resources_for_rebuilder" 
x171="Verify_error_data_doesnt_equal_parity" 
x180="Requested_segment_not_in_directory_of_this_DCB" 
x181="DCB_segment_has_unsupported_version" 
x182="DCB_segment_has_checksum_error" 
x183="DCB_support_settings_segment_invalid" 
x184="DCB_UDB_unit_descriptor_block_segment_invalid" 
x185="DCB_GUID_globally_unique_identifier_segment_invalid" 
x1A0="Could_not_clear_Sbuf" 
x1C0="Flash_device_unsupported" 
x1C1="Flash_out_of_bounds" 
x1C2="Flash_write_verify_failed" 
x1C3="Flash_file_object_not_found" 
x1C4="Flash_file_already_present" 
x1C5="Flash_file_system_full" 
x1C6="Flash_file_not_present" 
x1C7="Flash_file_size_mismatch" 
x1C8="Flash_file_checksum_error" 
x1C9="Flash_file_version_unsupported" 
x1CA="Flash_file_system_error_detected" 
x1CB="Flash_file_component_directory_not_found" 
x1CC="Flash_file_component_not_found" 
x1CD="Flash_write_cycle_failed" 
x1CE="Flash_erase_cycle_failed" 
x1D0="Invalid_field_in_parameter_list" 
x1D1="Parameter_list_length_error" 
x1D2="Parameter_not_changeable" 
x1D3="Parameter_not_saveable" 
x1D4="Invalid_mode_page" 
x200="Drive_CRC_error" 
x201="Internal_bus_CRC_error" 
x202="Drive_ECC_Medium_error" 
x203="Drive_TFR_readback_error" 
x204="Drive_timeout" 
x205="Drive_power_on_reset" 
x206="ADP_level_2_error" 
x207="Drive_soft_reset_failed" 
x208="Drive_not_ready" 
x209="Unclassified_drive_error" 
x20A="Drive_aborted_command" 
x20D="Drive_not_ready_require_Spinup" 
x20B="Port_link_error_detected" 
x20C="Port_internal_error_detected" 
x210="Internal_bus_CRC_error" 
x211="PCI_bus_abort_error" 
x212="PCI_bus_parity_error" 
x213="Port_handler_error" 
x214="Token_interrupt_count_error" 
x215="PCI_bus_timeout" 
x216="Buffer_ECC_error_corrected" 
x217="Buffer_ECC_error_not_corrected" 
x218="Xop_pool_parity_error" 
x230="Unsupported_command_during_flash_recovery" 
x231="Next_image_buffer_expected" 
x232="Binary_image_architecture_ID_incompatible" 
x233="Binary_image_no_signature_detected" 
x234="Binary_image_checksum_error_detected" 
x235="Binary_image_buffer_overflow_detected" 
x236="Binary_image_SRL_incompatible" 
x240="I2C_device_not_detected" 
x241="I2C_transaction_aborted" 
x242="SO-DIMM_parameters_incompatible_using_defaults" 
x243="SO-DIMM_unsupported" 
x244="I2C_clock_is_held_low_transfer_aborted" 
x245="I2C_data_is_held_low_transfer_aborted" 
x246="I2C_slave_device_NACKed_the_transfer" 
x247="I2C_buffer_in-sufficient" 
x248="SPI_transfer_status_error" 
x24A="I2C_interface_is_active" 
x24B="Lost_arbitration" 
x24C="I2C_transfer_error" 
x250="Unit_descriptor_size_invalid" 
x251="Unit_descriptor_size_exceeds_data_buffer" 
x252="Invalid_value_in_unit_descriptor" 
x253="Inadequate_disk_space_to_support_descriptor" 
x254="Unable_to_create_data_channel_for_this_unit_descriptor" 
x255="Unit_descriptor_specifies_a_drive_already_in_use" 
x256="Unable_to_write_configuration_to_all_disks" 
x257="Unit_descriptor_version_not_supported" 
x258="Invalid_subunit_for_RAID_0_or_5" 
x259="Too_many_unit_descriptors" 
x25A="Invalid_configuration_in_unit_descriptor" 
x25B="Invalid_LBA_offset_in_unit_descriptor" 
x25C="Invalid_stripelet_size_in_unit_descriptor" 
x25D="JBOD_unit_is_not_allowed" 
x25E="Operation_not_allowed_retained_cache_data" 
x25F="Exceeded_maximum_number_of_active_drives" 
x261="Maximum_number_of_units_reached" 
x260="SMART_threshold_exceeded" 
x270="Unit_not_in_NORMAL_state" 
x271="Invalid_drive_members" 
x272="Converted_unit_not_supported" 
x280="ResponseIU_status_code_EC_STATUS_BUSY" 
x281="ResponseIU_status_code_EC_STATUS_QUEUE_FULL" 
x282="ResponseIU_status_code_EC_STATUS_UNEXPECTED" 
x283="IO_Hold_Error"
x290="No_Sense_Info_EC_SK_NO_SENSE_INFO"  
x291="Recovered_Error_EC_SK_RECOVERED_ERROR"  
x293="Hardware_Error_EC_SK_HARDWARE_ERROR"  
x294="Hardware_ECC_Error_EC_SK_HARDWARE_ECC"  
x295="Illegal_Req_EC_SK_ILLEGAL_REQ"  
x296="Unit_Attention_EC_SK_UNIT_ATTENTION"  
x297="Unit_Attention_Reset_EC_SK_UNIT_ATTENTION" 
# note: The error code below is reused - Commented Out 
#x205="ResponseIU_status_codeEC_SK_UNIT_REset" 
x298="Aborted_Cmd_EC_SK_ABORTED_CMD"  
x299="Sense_Keys_Unexpected_EC_SK_UNEXPECTED"  
x29A="Unit_Attention_Mode_Page_Changed_EC_SK_UNIT_ATTENTION" 
x29B="Current_command_Write_Fault"
x29C="Deferred_Drive_Write_Fault"
x29D="Lba_Out_Of_Range"
x2A0="SAS_error_code_EC_PAYLOAD_PARITY" 
x2A1="SAS_error_code_EC_UNDER_RUN_IN_RW" 
x2A2="SAS_error_code_EC_UNDER_RUN_OUT" 
x2A3="SAS_error_code_EC_OVER_RUN" 
x2A4="SAS_error_code_EC_OPEN_REJECT_BUSY"  
x2A5="SAS_error_code_EC_OPEN_REJECT_RETRY"   
x2A6="SAS_error_code_EC_OPEN_REJECT_ABANDON"   
x2A7="SAS_error_code_EC_OPEN_REJECT_STP_RES_BUSY"   
x2A8="SAS_error_code_EC_RX_FRAME_ERROR"   
x2A9="SAS_error_code_EC_RX_TRANSPORT_ERROR" 
x2AA="SAS_error_code_EC_PORT_OFFLINE"   
x2B0="Tx_failure_-_SATA_SYNC_received" 
x2B1="Tx_failure_-_BREAK_received" 
x2B2="Protocol_overrun" 
x2B3="Protocol_underrun" 
x2B4="Open_failure_-_Connection_rejected" 
x2B5="Open_failure_-_Bad_destination" 
x2B6="Open_failure_-_Wrong_destination" 
x2B7="Open_failure_-_Connection_rate_not_supported" 
x2B8="Open_failure_-_Protocol_not_supported" 
x2B9="Open_failure_-_STP_Resources_busy" 
x2BA="Open_failure_-_No_destination" 
x2BB="Open_failure_-_Pathway_blocked" 
x2BC="Open_failure_-_Retry" 
x2BD="Open_failure_-_Open_frame_timeout" 
x2BE="STP_Inactivity" 
x2BF="Failed_to_discover_Emulex_chip" 
x2C0="Emulex_flash_file_is_corrupted" 
x2C1="Error_while_flashing_Emulex" 
x2C2="Target_returned_valid_sense_data_during_a_SCSI_PASSTHROUGH" 
x2C3="Failed_to_unlock_flash_block_while_flashing_Emulex_ROM" 
x2C4="Failed_to_erase_flash_block_while_flashing_Emulex_ROM" 
x2C5="Failed_to_write_flash_block_while_flashing_Emulex_ROM" 
x2C6="Failed_to_lock_flash_block_while_flashing_Emulex_ROM" 
x2C7="ROM_size_is_not_a_multiple_of_128k" 
x2C8="Emulex_SLI_command_timeout" 
x2C9="Emulex_mailbox_status_error" 
x2CA="Emulex_mailbox_format_error" 
x2CB="Emulex_no_resources" 
x2CC="Emulex_protocol_check_error" 
x2CD="Emulex_protocol_fis_error" 
x300="Internal_errorcode_BBU_base_-_should_not_occur" 
x301="Invalid_BBU_state_change_request"  
x302="The_BBU_resource_needed_is_in_use_retry_command_after_a_delay"  
x303="Command_requires_a_battery_pack_to_be_present_and_enabled" 
x310="BBU_command_packet_error" 
x311="BBU_command_not_implemented" 
x312="BBU_command_buffer_underflow" 
x313="BBU_command_buffer_overflow" 
x314="BBU_command_incomplete" 
x315="BBU_command_checksum_error" 
x316="BBU_command_timeout" 
x317="BBU_flash_operation_failed" 
x318="BBU_flash_Vpp_voltage_out_of_progamming_range" 
x319="BBU_flash_incorrect_command_or_parameter_or_not_enough_space_in_stack" 
x31A="BBU_flash_not_yet_completed" 
x31B="BBU_flash_write_skip" 
x31C="BBU_flash_invalid_erase_sector" 
x320="BBU_parameter_not_defined" 
x321="BBU_parameter_size_mismatch" 
x322="Cannot_write_a_read-only_BBU_parameter" 
x323="Invalid_state_bits_in_BBU_SetportPins_command" 
x380="BBU_firmware_version_string_not_found" 
x381="BBU_operating_state_not_available" 
x382="BBU_not_present" 
x383="BBU_not_ready" 
x384="BBU_S1_not_compatible_with_HBA" 
x385="BBU_S0_not_compatible_with_HBA" 
x386="BBU_not_compatible_with_HBA" 
x387="BBU_not_in_S0" 
x388="BBU_not_in_S1" 
x389="Timeout_on_BBU_power_fail_interrupt" 
x38A="BBU_invalid_response_length" 
x38B="Not_S1_ident_or_event_packet" 
x38C="HBA_has_backup_data" 
x38D="Invalid_BBU_state" 
x38E="BBU_invalid_response_code" 
x390="Log_updates_not_allowed" 
x391="Logs_are_invalid" 
x392="Logs_not_found" 
x400="Invalid_enclosure_port_defined" 
x401="Enclosure_resource_reserved" 
x402="Enclosure_parameter_not_defined" 
x403="Enclosure_parameter_re-defined" 
x404="Enclosure_port_is_input_port" 
x405="Invalid_SAFTE_page_requested" 
x406="Invalid_SES_page_requested" 
x407="EPCT_device_description_error" 
x408="EPCT_device_redefined" 
x409="EPCT_element_unknown" 
x40A="EPCT_device_unknown" 
x40B="EPCT_ID_unknown" 
x40C="Invalid_enclosure_device" 
x40D="EPCT_LED_descriptor_redefinition" 
x40F="Enclosure_device_not_initialized" 
x410="Temperature_sensor_reading_unknown" 
x411="Enclosure_not_present" 
x412="Bad_EPCT_version" 
x413="Failed_to_create_SEP_object" 
x414="Too_many_enclosures_cannot_add_more" 
x415="Failed_to_create_enclosure_object" 
x416="Invalid_Sep_Command" 
x1000="EC_NEED_CMD_PROCESS" 
x1001="EC_UDMA_UPGRADE_SKIPPED" 
x1002="EC_DRIVE_NOT_IN_UDMA" 
x1003="EC_OFFLINE_TIMER_RUNNING" 
x1004="EC_BIN_HANDLE_NOT_EMPTY" 
x1005="EC_BIN_HANDLE_WRONG_OWNER" 
x1006="EC_CMD_IN_PBUF" 
x1007="EC_INVALID_DATA_CHKSUM" 
x1008="EC_LBA_OVERLAP" 
x1009="EC_SGL_NON_SECTOR_SIZE" 
x100A="Retry_CMD"
x1010="Error_recovery_in_progress" 
x1011="Error_recovery_complete" 
x1012="No_LBA_to_repair_sector" 
x1013="Retry_recovery_step" 
x1014="Do_error_action" 
x1015="Degrade_unit" 
x1016="Sector_repair_was_not_completed" 
x1017="Command_aborted" 
x1018="Drive_added" 
x1019="Drive_removed" 
x101A="Retry_queued_command" 
x101B="Drive_error" 
x101C="Non-Dma_Retry_no_recovery" 
x101D="Drive_removed_no_wait" 
x1020="Simulate_power_fail" 
x1021="Simulate_uC_error" 
x2000="Checksum_of_cache_meta_data_is_bad" 
x2001="Signature_of_cache_meta_data_is_bad" 
x2FFF="EC_FEATURE_NOT_IMPLEMENTED" 
x3013="Data_integrity_error_in_diagnostic_test" 
x3014="Undefined_Sub-command_for_diag_test" 
x3017="Drive_reset_error_thru_Marvell" 
x3018="Reading_config_space_error" 
x3019="Read_or_write_memory_space_data_integrity_error" 
x301A="Pchip_UCbuf_data_integrity_error" 
x301B="Pchip_Xop_Pool_data_integrity_error" 
x301C="Pchip_Cmd_Ram_data_integrity_error" 
x301E="iHandler_was_busy_before_diag_test" 
x3021="An_unimplemented_method_was_invoked" 
x3024="Data_lines_shorted_in_Sbuf_RAM" 
x3025="Data_lines_open_in_Sbuf_RAM" 
x3026="Addr_line_problem_in_Sbuf_RAM" 
x3027="Sbuf_RAM_unreadable" 
x3047="Can't_fill_Sbuf_with_zeros" 
x3062="iHandler_error_during_xfer_op" 
x3063="Bad_disk_sequencer_cmd_issued_to_Aport" 
x3064="Bad_RAM_location" 
x3065="Bad_Shadowed_RAM_location" 
x3066="Cant_determine_Sbuf_size" 
x3067="Pbuf_read_or_write_error" 
x3068="XOR_error" 
x3069="No_disk_found_on_requested_Aport" 
x306A="Interrupt_line_error" 
x306B="Unable_to_calculate_checksum" 
x306C="BBU_S0_or_S1_firmware_boundary_error" 
x306D="Old_method_selected_wrong_value_EC_DQS_FIFO_set_WRONG" 
x3070="NvRam_read_or_write_test_error" 
x3071="SpdRom_read_test_error" 
x3072="Hareware_strap_error" 
x3073="Clock_Generator_data_integrity_error" 
x3074="Inject_SBUF_ECC_incorrect_param"
x3100="Error_manufacturing_diagnostic_test_failed"
x3101="XScale_Core_Processor_Subtest"
x3102="SRAM_Subtest"
x3103="TPMI_Subtest"
x3104="Component_Internal_RAM_Subtest"
x3105="ASIC_Register_Subtest"
x3106="PCIX-E_Loopback_Subtest"
x3107="4.0G_FC_or_3.0G_SAS_Link_Internal_Analog_Loopback_Subtest"
x3108="1.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x3109="2.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x310A="4.0G_FC_or_3.0G_SAS_Link_External_Loopback_Subtest"
x310B="TDMA_Subtest"
x310C="Concurrent_DMA_Subtest"
x310D="SDRAM_Subtest"
x310E="Error_manufacturing_diagnostic_test-Coordinated_Reset_failed"
x310F="Error_manufacturing_diagnostic_test-Preemptive_Reset_failed"
x3110="Error_manufacturing_diagnostic_test-Invalid_Request_failed"
x3111="Hareware_strap_error"
x7E00="Error_manufacturing_diagnostic_test_failed"
x7E01="XScale_Core_Processor_Subtest"
x7E02="SRAM_Subtest"
x7E03="TPMI_Subtest"
x7E04="Component_Internal_RAM_Subtest"
x7E05="ASIC_Register_Subtest"
x7E06="PCIX-E_Loopback_Subtest"
x7E07="4.0G_FC_or_3.0G_SAS_Link_Internal_Analog_Loopback_Subtest"
x7E08="1.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x7E09="2.0G_FC_or_1.5G_SAS_Link_External_Loopback_Subtest"
x7E0A="4.0G_FC_or_3.0G_SAS_Link_External_Loopback_Subtest"
x7E0B="TDMA_Subtest"
x7E0C="Concurrent_DMA_Subtest"
x7E0D="SDRAM_Subtest"
x7E0E="Error_manufacturing_diagnostic_test-Coordinated_Reset_failed"
x7E0F="Error_manufacturing_diagnostic_test-Preemptive_Reset_failed"
x7E10="Error_manufacturing_diagnostic_test-Invalid_Request_failed"

for i in "x0 $x0" "x1 $x1" "x2 $x2" "x3 $x3" "x4 $x4" "x5 $x5" "x6 $x6" "x7 $x7" "x8 $x8" "x9 $x9" "xA $xA" "xB $xB" "xC $xC" "xD $xD" "xE $xE" "xF $xF" "x10 $x10" "x11 $x11" "x12 $x12" "x13 $x13" "x14 $x14" "x15 $x15" "x16 $x16" "x17 $x17" "x18 $x18" "x19 $x19" "x1A $x1A" "x1B $x1B" "x1C $x1C" "x1D $x1D" "x1E $x1E" "x1F $x1F" "x20 $x20" "x21 $x21" "x22 $x22" "x23 $x23" "x24 $x24" "x25 $x25" "x26 $x26" "x27 $x27" "x28 $x28" "x29 $x29" "x2A $x2A" "x2B $x2B" "x2C $x2C" "x2D $x2D" "x2E $x2E" "x2F $x2F" "x30 $x30" "x31 $x31" "x32 $x32" "x33 $x33" "x34 $x34" "x35 $x35" "x36 $x36" "x37 $x37" "x38 $x38" "x39 $x39" "x3A $x3A" "x3B $x3B" "x3C $x3C" "x3D $x3D" "x3E $x3E" "x3F $x3F" "x40 $x40" "x41 $x41" "x42 $x42" "x43 $x43" "x44 $x44" "x45 $x45" "x46 $x46" "x47 $x47" "x48 $x48" "x49 $x49" "x4A $x4A" "x51 $x51" "x60 $x60" "x61 $x61" "x100 $x100" "x101 $x101" "x102 $x102" "x103 $x103" "x104 $x104" "x105 $x105" "x106 $x106" "x107 $x107" "x108 $x108" "x109 $x109" "x10A $x10A" "x10B $x10B" "x10C $x10C" "x10D $x10D" "x10E $x10E" "x10F $x10F" "x110 $x110" "x111 $x111" "x112 $x112" "x113 $x113" "x114 $x114" "x115 $x115" "x116 $x116" "x11E $x11E" "x11F $x11F" "x120 $x120" "x121 $x121" "x122 $x122" "x123 $x123" "x124 $x124" "x125 $x125" "x126 $x126" "x127 $x127" "x128 $x128" "x129 $x129" "x12A $x12A" "x12B $x12B" "x12C $x12C" "x12D $x12D" "x12E $x12E" "x12F $x12F" "x130 $x130" "x131 $x131" "x132 $x132" "x133 $x133" "x140 $x140" "x150 $x150" "x151 $x151" "x152 $x152" "x153 $x153" "x160 $x160" "x161 $x161" "x162 $x162" "x170 $x170" "x171 $x171" "x180 $x180" "x181 $x181" "x182 $x182" "x183 $x183" "x184 $x184" "x185 $x185" "x1A0 $x1A0" "x1C0 $x1C0" "x1C1 $x1C1" "x1C2 $x1C2" "x1C3 $x1C3" "x1C4 $x1C4" "x1C5 $x1C5" "x1C6 $x1C6" "x1C7 $x1C7" "x1C8 $x1C8" "x1C9 $x1C9" "x1CA $x1CA" "x1CB $x1CB" "x1CC $x1CC" "x1CD $x1CD" "x1CE $x1CE" "x1D0 $x1D0" "x1D1 $x1D1" "x1D2 $x1D2" "x1D3 $x1D3" "x1D4 $x1D4" "x200 $x200" "x201 $x201" "x202 $x202" "x203 $x203" "x204 $x204" "x205 $x205" "x206 $x206" "x207 $x207" "x208 $x208" "x209 $x209" "x20A $x20A" "x20B $x20B" "x20C $x20C" "x20D $x20D" "x210 $x210" "x211 $x211" "x212 $x212" "x213 $x213" "x214 $x214" "x215 $x215" "x216 $x216" "x217 $x217" "x218 $x218" "x230 $x230" "x231 $x231" "x232 $x232" "x233 $x233" "x234 $x234" "x235 $x235" "x236 $x236" "x240 $x240" "x241 $x241" "x242 $x242" "x243 $x243" "x244 $x244" "x245 $x245" "x246 $x246" "x247 $x247" "x248 $x248" "x24A $x24A" "x24B $x24B" "x24C $x24C" "x250 $x250" "x251 $x251" "x252 $x252" "x253 $x253" "x254 $x254" "x255 $x255" "x256 $x256" "x257 $x257" "x258 $x258" "x259 $x259" "x25A $x25A" "x25B $x25B" "x25C $x25C" "x25D $x25D" "x25E $x25E" "x25F $x25F" "x261 $x261" "x260 $x260" "x270 $x270" "x271 $x271" "x272 $x272" "x280 $x280" "x281 $x281" "x282 $x282" "x283 $x283" "x290 $x290" "x291 $x291" "x293 $x293" "x294 $x294" "x295 $x295" "x296 $x296" "x297 $x297" "x298 $x298" "x299 $x299" "x29A $x29A" "x29B $x29B" "x29C $x29C" "x29D $x29D" "x2A0 $x2A0" "x2A1 $x2A1" "x2A2 $x2A2" "x2A3 $x2A3" "x2A4 $x2A4" "x2A5 $x2A5" "x2A6 $x2A6" "x2A7 $x2A7" "x2A8 $x2A8" "x2A9 $x2A9" "x2AA $x2AA" "x2B0 $x2B0" "x2B1 $x2B1" "x2B2 $x2B2" "x2B3 $x2B3" "x2B4 $x2B4" "x2B5 $x2B5" "x2B6 $x2B6" "x2B7 $x2B7" "x2B8 $x2B8" "x2B9 $x2B9" "x2BA $x2BA" "x2BB $x2BB" "x2BC $x2BC" "x2BD $x2BD" "x2BE $x2BE" "x2BF $x2BF" "x2C0 $x2C0" "x2C1 $x2C1" "x2C2 $x2C2" "x2C3 $x2C3" "x2C4 $x2C4" "x2C5 $x2C5" "x2C6 $x2C6" "x2C7 $x2C7" "x2C8 $x2C8" "x2C9 $x2C9" "x2CA $x2CA" "x2CB $x2CB" "x2CC $x2CC" "x2CD $x2CD" "x300 $x300" "x301 $x301" "x302 $x302" "x303 $x303" "x310 $x310" "x311 $x311" "x312 $x312" "x313 $x313" "x314 $x314" "x315 $x315" "x316 $x316" "x317 $x317" "x318 $x318" "x319 $x319" "x31A $x31A" "x31B $x31B" "x31C $x31C" "x320 $x320" "x321 $x321" "x322 $x322" "x323 $x323" "x380 $x380" "x381 $x381" "x382 $x382" "x383 $x383" "x384 $x384" "x385 $x385" "x386 $x386" "x387 $x387" "x388 $x388" "x389 $x389" "x38A $x38A" "x38B $x38B" "x38C $x38C" "x38D $x38D" "x38E $x38E" "x390 $x390" "x391 $x391" "x392 $x392" "x400 $x400" "x401 $x401" "x402 $x402" "x403 $x403" "x404 $x404" "x405 $x405" "x406 $x406" "x407 $x407" "x408 $x408" "x409 $x409" "x40A $x40A" "x40B $x40B" "x40C $x40C" "x40D $x40D" "x40F $x40F" "x410 $x410" "x411 $x411" "x412 $x412" "x413 $x413" "x414 $x414" "x415 $x415" "x416 $x416" "x1000 $x1000" "x1001 $x1001" "x1002 $x1002" "x1003 $x1003" "x1004 $x1004" "x1005 $x1005" "x1006 $x1006" "x1007 $x1007" "x1008 $x1008" "x1009 $x1009" "x100A $x100A" "x1010 $x1010" "x1011 $x1011" "x1012 $x1012" "x1013 $x1013" "x1014 $x1014" "x1015 $x1015" "x1016 $x1016" "x1017 $x1017" "x1018 $x1018" "x1019 $x1019" "x101A $x101A" "x101B $x101B" "x101C $x101C" "x101D $x101D" "x1020 $x1020" "x1021 $x1021" "x2000 $x2000" "x2001 $x2001" "x2FFF $x2FFF" "x3013 $x3013" "x3014 $x3014" "x3017 $x3017" "x3018 $x3018" "x3019 $x3019" "x301A $x301A" "x301B $x301B" "x301C $x301C" "x301E $x301E" "x3021 $x3021" "x3024 $x3024" "x3025 $x3025" "x3026 $x3026" "x3027 $x3027" "x3047 $x3047" "x3062 $x3062" "x3063 $x3063" "x3064 $x3064" "x3065 $x3065" "x3066 $x3066" "x3067 $x3067" "x3068 $x3068" "x3069 $x3069" "x306A $x306A" "x306B $x306B" "x306C $x306C" "x306D $x306D" "x3070 $x3070" "x3071 $x3071" "x3072 $x3072" "x3073 $x3073" "x3074 $x3074" "x3100 $x3100" "x3101 $x3101" "x3102 $x3102" "x3103 $x3103" "x3104 $x3104" "x3105 $x3105" "x3106 $x3106" "x3107 $x3107" "x3108 $x3108" "x3109 $x3109" "x310A $x310A" "x310B $x310B" "x310C $x310C" "x310D $x310D" "x310E $x310E" "x310F $x310F" "x3110 $x3110" "x3111 $x3111" "x7E00 $x7E00" "x7E01 $x7E01" "x7E02 $x7E02" "x7E03 $x7E03" "x7E04 $x7E04" "x7E05 $x7E05" "x7E06 $x7E06" "x7E07 $x7E07" "x7E08 $x7E08" "x7E09 $x7E09" "x7E0A $x7E0A" "x7E0B $x7E0B" "x7E0C $x7E0C" "x7E0D $x7E0D" "x7E0E $x7E0E" "x7E0F $x7E0F" "x7E10 $x7E10"; do

set $i

if [ -e ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt ]; then
       $grep -i error'='0$1"\." ./$fileName/3ware/3ware_driver_x04_9000_EVENT.txt > ./$fileName/3ware/3ware_driver_Ext_AEN_Error_$1_$2.txt

		if [ ! -s ./$fileName/3ware/3ware_driver_Ext_AEN_Error_$1_$2.txt ]; then rm ./$fileName/3ware/3ware_driver_Ext_AEN_Error_$1_$2.txt > /dev/null 2>&1 ; fi

fi

done
###########################################################################################################################
# 0x06 Driver Errors from 9.0, 9.4.1.2 & 9.5.1 3w-9xxx.c
###########################################################################################################################
x0001="Found_unaligned_address_during_AEN_drain"
x0002="Error_posting_request_sense"
x0003="No_valid_response_while_draining_AEN_queue"
x0004="Post_failed_while_reading_AEN_queue"
x0005="Memory_allocation_failed"
x0006="Failed_to_allocate_correctly_aligned_memory"
x0007="Initconnection_failed_while_checking_SRL"
x000A="Initconnection_base_mode_failed_while_checking_SRL"
x000B="Incompatible_firmware_on_controller"
#x000C="Character_ioctl_0xXX_timed_out_resetting_card." # 9.4.1.2
#x000C="PCI_Parity_Error_clearing" # 9.4.1.2
x000C="Shared_x000C"
x000D="PCI_Abort_clearing"
x000E="Controller_Queue_Error_clearing"
x0010="Microcontroller_Error_clearing"
x0011="Failed_to_allocate_memory_for_firmware_flash"
x0012="No_valid_response_while_flashing_firmware"
x0013="No_valid_response_during_get_param"
x0014="No_valid_response_during_hard_reset"
x0015="No_valid_response_during_init_connection"
x0016="Command_packet_memory_allocation_failed"
x0017="Generic_memory_allocation_failed"
x0018="Event_info_memory_allocation_failed"
x0019="Found_request_id_that_wasnt_pending"
x001A="Received_a_request_id_that_wasnt_posted"
x001B="Error_completing_AEN_during_attention_interrupt"
x001C="Failed_to_map_scatter_gather_list"
x001D="Failed_to_map_page"
x001E="Found_unexpected_request_id_while_polling_for_response"
x001F="Microcontroller_not_ready_during_reset_sequence"
x0020="Response_queue_empty_failed_during_reset_sequence"
x0021="Compatibility_check_failed_during_reset_sequence"
x0022="AEN_drain_failed_during_reset_sequence"
x0023="Failed_to_set_dma_mask"
x0024="Failed_to_allocate_memory_for_device_extension"
x0025="Failed_to_initialize_device_extension"
x0026="Failed_to_get_mem_region"
x0027="scsi_add_host_failed"
x0028="Bad_scsi_host_data"
x0029="Failed_to_register_character_device"
x002B="Controller_reset_failed_during_scsi_host_reset"
#x002C="Command_0xXX_timed_out_resetting_card" # 9.4.1.2
#x002C="No_device_extension_for_proc_operation" # 9.0
x002C="Shared_x002C" 
x002D="Found_unaligned_address_during_execute_scsi"
x002E="Found_unaligned_sgl_address_during_execute_scsi"
x002F="Found_unaligned_sgl_address_during_internal_post"
x0030="Error_requesting_IRQ"
x0031="Connection_shutdown_failed"
x0032="Firmware_and_driver_incompatibility_please_upgrade_firmware"
x0033="Firmware_and_driver_incompatibility_please_upgrade_driver"
x0034="Failed_to_enable_pci_device"
x0035="Failed_to_ioremap"
x0036="Response_queue_large_empty_failed_during_reset_sequence"
x0037="Character_ioctl_timed_out_resetting_card"

for i in "x0001 $x0001" "x0002 $x0002" "x0003 $x0003" "x0004 $x0004" "x0005 $x0005" "x0006 $x0006" "x0007 $x0007" "x000A $x000A" "x000B $x000B" "x000C $x000C" "x000D $x000D" "x000E $x000E" "x0010 $x0010" "x0011 $x0011" "x0012 $x0012" "x0013 $x0013" "x0014 $x0014" "x0015 $x0015" "x0016 $x0016" "x0017 $x0017" "x0018 $x0018" "x0019 $x0019" "x001A $x001A" "x001B $x001B" "x001C $x001C" "x001D $x001D" "x001E $x001E" "x001F $x001F" "x0020 $x0020" "x0021 $x0021" "x0022 $x0022" "x0023 $x0023" "x0024 $x0024" "x0025 $x0025" "x0026 $x0026" "x0027 $x0027" "x0028 $x0028" "x0029 $x0029" "x002B $x002B" "x002C $x002C" "x002D $x002D" "x002E $x002E" "x002F $x002F" "x0030 $x0030" "x0031 $x0031" "x0032 $x0032" "x0033 $x0033" "x0034 $x0034" "x0035 $x0035" "x0036 $x0036" "x0037 $x0037" ; do

set $i
#Note: Appending to file rather than creating (>> vs >) due to duplicate error codes 0xc & 0x2c.

if [ -e ./$fileName/3ware/3ware_driver_x06_9000_DRIVER.txt ]; then

       $grep -i $1 ./$fileName/3ware/3ware_driver_x06_9000_DRIVER.txt >> ./$fileName/3ware/3ware_driver_x06_$1_$2.txt

		if [ ! -s ./$fileName/3ware/3ware_driver_x06_$1_$2.txt ]; then rm ./$fileName/3ware/3ware_driver_x06_$1_$2.txt > /dev/null 2>&1 ; fi
fi

if [ -e ./$fileName/3ware/OS_Disk_driver_x06_9000_DRIVER.txt ]; then

       $grep -i $1 ./$fileName/3ware/OS_Disk_driver_x06_9000_DRIVER.txt >> ./$fileName/3ware/OS_Disk_driver_x06_$1_$2.txt

		if [ ! -s ./$fileName/3ware/OS_Disk_driver_x06_$1_$2.txt ]; then rm ./$fileName/3ware/OS_Disk_driver_x06_$1_$2.txt > /dev/null 2>&1 ; fi

fi

done

if [ -e ./$fileName/3ware/3ware_driver_x06_x000C_Shared_x000C.txt ]; then

grep -i "Character ioctl" ./$fileName/3ware/3ware_driver_x06_x000C_Shared_x000C.txt > ./$fileName/3ware/3ware_driver_x06_x000C_Character_ioctl_0xXX_timed_out_resetting_card.txt

grep -i "PCI Parity Error" ./$fileName/3ware/3ware_driver_x06_x000C_Shared_x000C.txt > ./$fileName/3ware/3ware_driver_x06_x000C_PCI_Parity_Error_clearing.txt

rm ./$fileName/3ware/3ware_driver_x06_x000C_Shared_x000C.txt
fi


if [ -e ./$fileName/3ware/3ware_driver_x06_x002C_Shared_x002C.txt ]; then


grep -i "resetting card" ./$fileName/3ware/3ware_driver_x06_x002C_Shared_x002C.txt > ./$fileName/3ware/3ware_driver_x06_x002C_Command_0xXX_timed_out_resetting_card.txt

grep -i "No device extension" ./$fileName/3ware/3ware_driver_x06_x002C_Shared_x002C.txt > ./$fileName/3ware/3ware_driver_x06_x002C_No_device_extension_for_proc_operation.txt

rm ./$fileName/3ware/3ware_driver_x06_x002C_Shared_x002C.txt

fi

for i in _x002C_Command_0xXX_timed_out_resetting_card.txt _x002C_No_device_extension_for_proc_operation.txt _x000C_Character_ioctl_0xXX_timed_out_resetting_card.txt _x000C_PCI_Parity_Error_clearing.txt; do

		if [ ! -s ./$fileName/3ware/3ware_driver_x06$i ]; then rm ./$fileName/3ware/3ware_driver_x06$i > /dev/null 2>&1 ; fi

done

if [ -e ./$fileName/3ware/OS_Disk_driver_x06_x000C_Shared_x000C.txt ]; then

grep -i "Character ioctl" ./$fileName/3ware/3ware_driver_x06_x002C_Shared_x002C.txt > ./$fileName/3ware/OS_Disk_driver_x06_x000C_Character_ioctl_0xXX_timed_out_resetting_card.txt

grep -i "PCI Parity Error" ./$fileName/3ware/3ware_driver_x06_x002C_Shared_x002C.txt > ./$fileName/3ware/OS_Disk_driver_x06_x000C_PCI_Parity_Error_clearing.txt

rm ./$fileName/3ware/OS_Disk_driver_x06_x000C_Shared_x000C.txt
fi


if [ -e ./$fileName/3ware/OS_Disk_driver_x06_x002C_Shared_x002C.txt ]; then


grep -i "resetting card" ./$fileName/3ware/OS_Disk_driver_x06_x002C_Shared_x002C.txt > ./$fileName/3ware/OS_Disk_driver_x06_x002C_Command_0xXX_timed_out_resetting_card.txt

grep -i "No device extension" ./$fileName/3ware/OS_Disk_driver_x06_x002C_Shared_x002C.txt > ./$fileName/3ware/OS_Disk_driver_x06_x002C_No_device_extension_for_proc_operation.txt

rm ./$fileName/3ware/OS_Disk_driver_x06_x002C_Shared_x002C.txt

fi

for i in _x002C_Command_0xXX_timed_out_resetting_card.txt _x002C_No_device_extension_for_proc_operation.txt _x000C_Character_ioctl_0xXX_timed_out_resetting_card.txt _x000C_PCI_Parity_Error_clearing.txt; do

		if [ ! -s ./$fileName/3ware/OS_Disk_driver_x06$i ]; then rm ./$fileName/3ware/OS_Disk_driver_x06$i > /dev/null 2>&1 ; fi

done

###########################################################################################################################
# MegaRAID Hex AENs from SAS SW Users Guide July 2009 80-00156-01 Rev. H
###########################################################################################################################

# FreeBSD doesnt report errors in the same format & no MR_monitord support
if [ "$OS_LSI" != "freebsd" ]; then 
# No MacOS Support for MegaRAID
if [ "$OS_LSI" != "macos" ] ; then

date '+%H:%M:%S.%N'
echo "Evaluating MegaRAID AENs..."
echo "This may take over 5 minutes, please be patient..."


x0000="Info_000d_MegaRAID_FW_init_started"
x0001="Info_001d_MegaRAID_FW_version_X"
x0002="Fatal_002d_Unable_to_recover_cache_data_from_TBBU"
x0003="Info_003d_Cache_data_recovered_from_TBBU_successfully"
x0004="Info_004d_config_cleared"
x0005="Warning_005d_Cluster_down_com_with_peer_lost"
x0006="Info_006d_Virtual_drive_X_ownership_changed"
x0007="Info_007d_Alarm_disabled_by_user"
x0008="Info_008d_Alarm_enabled_by_user"
x0009="Info_009d_Bkgrnd_init_rate_changed_to_X"
x000a="Fatal_010d_Ctrl_cache_discarded_due_to_memory-BBU_problems"
x000b="Fatal_011d_Unable_to_recover_cache_data_due_to_config_mismatch"
x000c="Info_012d_Cache_data_recovered_successfully"
x000d="Fatal_013d_Ctrl_cache_discarded_due_to_FW_version_incomp"
x000e="Info_014d_CC_rate_changed_to_X"
x000f="Fatal_015d_FW_error_X"
x0010="Info_016d_Factory_defaults_restored"
x0011="Info_017d_Flash_downloaded_image_corrupt"
x0012="Critical_018d_Flash_erase_error"
x0013="Critical_019d_Flash_timeout_during_erase"
x0014="Critical_020d_Flash_error"
x0015="Info_021d_Flashing_image_X"
x0016="Info_022d_Flash_of_new_FW_images_complete"
x0017="Critical_023d_Flash_programming_error"
x0018="Critical_024d_Flash_timeout_during_programming"
x0019="Critical_025d_Flash_chip_type_unknown"
x001a="Critical_026d_Flash_command_set_unknown"
x001b="Critical_027d_Flash_verify_failure"
x001c="Info_028d_Flush_rate_changed_to_X_seconds"
x001d="Info_029d_Hibernate_command_received_from_host"
x001e="Info_030d_Event_log_cleared"
x001f="Info_031d_Event_log_wrapped"
x0020="Fatal_032d_Multi-bit_ECC_error_ECAR_X_ELOG_X_X"
x0021="Warning_033d_Single-bit_ECC_error_ECAR_X_ELOG_X_X"
x0022="Fatal_034d_Not_enough_Ctrl_memory"
x0023="Info_035d_Patrol_Read_complete"
x0024="Info_036d_Patrol_Read_paused"
x0025="Info_037d_Patrol_Read_Rate_changed_to_X"
x0026="Info_038d_Patrol_Read_resumed"
x0027="Info_039d_Patrol_Read_started"
x0028="Info_040d_Rebuild_rate_changed_to_X"
x0029="Info_041d_Drive_group_mod_rate_changed_to_X"
x002a="Info_042d_Shutdown_command_received_from_host"
x002b="Info_043d_Test_event_X"
x002c="Info_044d_Time_established_as_X_X_seconds_since_power_on"
x002d="Info_045d_User_entered_FW_debugger"
x002e="Warning_046d_Bkgrnd_init_aborted_on_X"
x002f="Warning_047d_Bkgrnd_init_corrected_medium_error_X_at_X"
x0030="Info_048d_Bkgrnd_init_completed_on_X"
x0031="Fatal_049d_Bkgrnd_init_completed_with_uncorrectable_errors"
x0032="Fatal_050d_Bkgrnd_init_detect_uncorrect_double_medium_errors"
x0033="Critical_051d_Bkgrnd_init_failed_on_X"
x0034="Progress_052d_Bkgrnd_init_on_X_is_X"
x0035="Info_053d_Bkgrnd_init_started_on_X"
x0036="Info_054d_Policy_change_on_X_from_X_to_X"
x0038="Warning_056d_CC_aborted_on_X"
x0039="Warning_057d_CC_corrected_medium_error_X_at_X"
x003a="Info_058d_CC_done_on_X"
x003b="Info_059d_CC_done_with_corrections_on_X"
x003c="Fatal_060d_CC_detected_uncorrectable_double_medium_errors"
x003d="Critical_061d_CC_failed_on_X"
x003e="Fatal_062d_CC_completed_with_uncorrectable_data_on_X"
x003f="Warning_063d_CC_found_inconsistent_parity_on_X_at_strip_X"
x0040="Warning_064d_CC_inconsistency_logging_disabled_too_many"
x0041="Progress_065d_CC_on_X_is_X"
x0042="Info_066d_CC_started_on_X"
x0043="Warning_067d_init_aborted_on_X"
x0044="Critical_068d_init_failed_on_X"
x0045="Progress_069d_init_on_X_is_X"
x0046="Info_070d_Fast_init_started_on_X"
x0047="Info_071d_Full_init_started_on_X"
x0048="Info_072d_init_complete_on_X"
x0049="Info_073d_LD_Properties_updated_to_X_from_X"
x004a="Info_074d_Drive_group_mod_complete_on_X"
x004b="Fatal_075d_Drive_group_mod_stopped_due_to_unrecov_errors"
x004c="Fatal_076d_Recon_detected_uncorrect_double_medium_errors"
x004d="Progress_077d_Drive_group_mod_on_X_is_X"
x004e="Info_078d_Drive_group_mod_resumed_on_X"
x004f="Fatal_079d_Drv_group_mod_resume_failed_due_to_config_mismatch"
x0050="Info_080d_Modifying_drive_group_started_on_X"
x0051="Info_081d_State_change_on_X_from_X_to_X"
x0052="Info_082d_Drive_Clear_aborted_on_X"
x0053="Critical_083d_Drive_Clear_failed_on_X_Error_X"
x0054="Progress_084d_Drive_Clear_on_X_is_X"
x0055="Info_085d_Drive_Clear_started_on_X"
x0056="Info_086d_Drive_Clear_completed_on_X"
x0057="Warning_087d_Error_on_X_Error_X"
x0058="Info_088d_Format_complete_on_X"
x0059="Info_089d_Format_started_on_X"
x005a="Critical_090d_Hot_Spare_SMART_polling_failed_on_X_Error_X"
x005b="Info_091d_Drive_inserted_X"
x005c="Warning_092d_Drive_X_is_not_supported"
x005d="Warning_093d_Patrol_Read_corrected_medium_error_on_X_at_X"
x005e="Progress_094d_Patrol_Read_on_X_is_X"
x005f="Fatal_095d_Patrol_Read_found_an_uncorrectable_medium_error"
x0060="Critical_096d_Predictive_failure_CDB_X"
x0061="Fatal_097d_Patrol_Read_puncturing_bad_block_on_X_at_X"
x0062="Info_098d_Rebuild_aborted_by_user_on_X"
x0063="Info_099d_Rebuild_complete_on_X"
x0064="Info_100d_Rebuild_complete_on_X"
x0065="Critical_101d_Rebuild_failed_on_X_due_to_source_drive_error"
x0066="Critical_102d_Rebuild_failed_on_X_due_to_target_drive_error"
x0067="Progress_103d_Rebuild_on_X_is_X"
x0068="Info_104d_Rebuild_resumed_on_X"
x0069="Info_105d_Rebuild_started_on_X"
x006a="Info_106d_Rebuild_automatically_started_on_X"
x006b="Critical_107d_Rebuild_stopped_loss_of_cluster_ownership"
x006c="Fatal_108d_Reassign_write_operation_failed_on_X_at_X"
x006d="Fatal_109d_Unrecoverable_medium_error_during_rebuild"
x006e="Info_110d_Corrected_medium_error_during_recovery"
x006f="Fatal_111d_Unrecoverable_medium_error_during_recovery"
x0070="Info_112d_Drive_removed_X"
x0071="Warning_113d_Unexpected_sense_X_CDBX_Sense_X"
x0072="Info_114d_State_change_on_X_from_X_to_X"
x0073="Info_115d_State_change_by_user_on_X_from_X_to_X"
x0074="Warning_116d_Redundant_path_to_X_broken"
x0075="Info_117d_Redundant_path_to_X_restored"
x0076="Info_118d_Dedicated_Hot_Spare_Drive_X_no_longer_useful"
x0077="Critical_119d_SAS_topo_error_Loop_detected"
x0078="Critical_120d_SAS_topo_error_Unaddressable_device"
x0079="Critical_121d_SAS_topo_error_Multiple_ports_same_SAS_address"
x007a="Critical_122d_SAS_topo_error_Expander_error"
x007b="Critical_123d_SAS_topo_error_SMP_timeout"
x007c="Critical_124d_SAS_topo_error_Out_of_route_entries"
x007d="Critical_125d_SAS_topo_error_Index_not_found"
x007e="Critical_126d_SAS_topo_error_SMP_function_failed"
x007f="Critical_127d_SAS_topo_error_SMP_CRC_error"
x0080="Critical_128d_SAS_topo_error_Multiple_subtractive"
x0081="Critical_129d_SAS_topo_error_Table_to_table"
x0082="Critical_130d_SAS_topo_error_Multiple_paths"
x0083="Fatal_131d_Unable_to_access_device_X"
x0084="Info_132d_Dedicated_Hot_Spare_created_on_X_X"
x0085="Info_133d_Dedicated_Hot_Spare_X_disabled"
x0086="Critical_134d_Dedicated_Hot_Spare_X_no_longer_useful"
x0087="Info_135d_Global_Hot_Spare_created_on_X_X"
x0088="Info_136d_Global_Hot_Spare_X_disabled"
x0089="Critical_137d_Global_Hot_Spare_does_not_cover_all_drive_groups"
x008a="Info_138d_Created_X"
x008b="Info_139d_Deleted_X"
x008c="Info_140d_Marking_LD_X_inconsistent"
x008d="Info_141d_BBU_Present"
x008e="Warning_142d_BBU_Not_Present"
x008f="Info_143d_New_BBU_Detected"
x0090="Info_144d_BBU_has_been_replaced"
x0091="Critical_145d_BBU_temp_is_high"
x0092="Warning_146d_BBU_voltage_low"
x0093="Info_147d_BBU_started_charging"
x0094="Info_148d_BBU_is_discharging"
x0095="Info_149d_BBU_temp_is_normal"
x0096="Fatal_150d_BBU_needs_to_be_replacement_SOH_Bad"
x0097="Info_151d_BBU_relearn_started"
x0098="Info_152d_BBU_relearn_in_progress"
x0099="Info_153d_BBU_relearn_completed"
x009a="Critical_154d_BBU_relearn_timed_out"
x009b="Info_155d_BBU_relearn_pending_BBU_is_under_charge"
x009c="Info_156d_BBU_relearn_postponed"
x009d="Info_157d_BBU_relearn_will_start_in_4_days"
x009e="Info_158d_BBU_relearn_will_start_in_2_day"
x009f="Info_159d_BBU_relearn_will_start_in_1_day"
x00a0="Info_160d_BBU_relearn_will_start_in_5_hours"
x00a1="Info_161d_BBU_removed"
x00a2="Info_162d_Current_capacity_of_the_BBU_is_below_threshold"
x00a3="Info_163d_Current_capacity_of_the_BBU_is_above_threshold"
x00a4="Info_164d_Enc_SES_discovered_on_X"
x00a5="Info_165d_Enc_SAFTE_discovered_on_X"
x00a6="Critical_166d_Enc_X_com_lost"
x00a7="Info_167d_Enc_X_com_restored"
x00a8="Critical_168d_Enc_X_fan_X_failed"
x00a9="Info_169d_Enc_X_fan_X_inserted"
x00aa="Critical_170d_Enc_X_fan_X_removed"
x00ab="Critical_171d_Enc_X_power_supply_X_failed"
x00ac="Info_172d_Enc_X_power_supply_X_inserted"
x00ad="Critical_173d_Enc_X_power_supply_X_removed"
x00ae="Critical_174d_Enc_X_SIM_X_failed"
x00af="Info_175d_Enc_X_SIM_X_inserted"
x00b0="Critical_176d_Enc_X_SIM_X_removed"
x00b1="Warning_177d_Enc_X_temp_sensor_X_below_threshold"
x00b2="Critical_178d_Enc_X_temp_sensor_X_below_error_threshold"
x00b3="Warning_179d_Enc_X_temp_sensor_X_above_threshold"
x00b4="Critical_180d_Enc_X_temp_sensor_X_above_error_threshold"
x00b5="Critical_181d_Enc_X_shutdown"
x00b6="Warning_182d_Enc_X_not_supported_too_many_Encs_connected"
x00b7="Critical_183d_Enc_X_FW_mismatch"
x00b8="Warning_184d_Enc_X_sensor_X_bad"
x00b9="Critical_185d_Enc_X_phy_X_bad"
x00ba="Critical_186d_Enc_X_is_unstable"
x00bb="Critical_187d_Enc_X_hardware_error"
x00bc="Critical_188d_Enc_X_not_responding"
x00bd="Info_189d_SAS-SATA_mixing_not_supported_Drive_disabled"
x00be="Info_190d_Enc_SES_hotplug_was_detect_but_is_not_supported"
x00bf="Info_191d_Clustering_enabled"
x00c0="Info_192d_Clustering_disabled"
x00c1="Info_193d_Drive_too_small_to_be_used_for_auto-rebuild"
x00c2="Info_194d_BBU_enabled_changing_WT_VDs_to_WB"
x00c3="Warning_195d_BBU_disabled_changing_WB_VDs_to_WT"
x00c4="Warning_196d_Bad_block_table_on_drive_X_is_80pct_full"
x00c5="Fatal_197d_Bad_block_table_is_full_unable_to_log_block_X"
x00c6="Info_198d_CC_Aborted_due_to_ownership_loss_on_X"
x00c7="Info_199d_Bkgrnd_init_BGI_Aborted_Due_to_Ownership_Loss"
x00c8="Critical_200d_BBU-charger_problems_detected_SOH_Bad"
x00c9="Warning_201d_Single-bit_ECC_error_warn_threshold_exceeded"
x00ca="Critical_202d_Single-bit_ECC_error_crit_threshold_exceeded"
x00cb="Critical_203d_Single-bit_ECC_error_further_reporting_disabled"
x00cc="Critical_204d_Enc_X_Power_supply_X_switched_off"
x00cd="Info_205d_Enc_X_Power_supply_X_switched_on"
x00ce="Critical_206d_Enc_X_Power_supply_X_cable_removed"
x00cf="Info_207d_Enc_X_Power_supply_X_cable_inserted"
x00d0="Info_208d_Enc_X_Fan_X_returned_to_normal"
x00d1="Info_209d_BBU_Retention_test_was_initiated_on_previous_boot"
x00d2="Info_210d_BBU_Retention_test_passed"
x00d3="Critical_211d_BBU_Retention_test_failed"
x00d4="Info_212d_NVRAM_Retention_test_initiated_on_previous_boot"
x00d5="Info_213d_NVRAM_Retention_test_passed"
x00d6="Critical_214d_NVRAM_Retention_test_failed"
x00d7="Info_215d_X_test_completed_X_passes_successfully"
x00d8="Critical_216d_test_FAILED_on_X_pass_Fail_data_errorOffset"
x00d9="Info_217d_Self_Chk_diagnostics_completed"
x00da="Info_218d_Foreign_config_detected"
x00db="Info_219d_Foreign_config_imported"
x00dc="Info_220d_Foreign_config_cleared"
x00dd="Warning_221d_NVRAM_is_corrupt_reinitializing"
x00de="Warning_222d_NVRAM_mismatch_occurred"
x00df="Warning_223d_SAS_wide_port_X_lost_link_on_PHY_X"
x00e0="Info_224d_SAS_wide_port_X_restored_link_on_PHY_X"
x00e1="Warning_225d_SAS_port_PHY_has_exceeded_the_allowed_error_rate"
x00e2="Warning_226d_Bad_block_reassigned_on_X_at_X_to_X"
x00e3="Info_227d_Ctrl_Hot_Plug_detected"
x00e4="Warning_228d_Enc_X_temp_sensor_X_differential_detected"
x00e5="Info_229d_Drive_test_cannot_start_No_qualifying_drives_found"
x00e6="Info_230d_Time_duration_provided_not_sufficient_for_self_Chk"
x00e7="Info_231d_Marked_Missing_for_X_on_drive_group_X_row_X"
x00e8="Info_232d_Replaced_Missing_as_X_on_drive_group_X_row_X"
x00e9="Info_233d_Enc_X_temp_X_returned_to_normal"
x00ea="Info_234d_Enc_X_FW_download_in_progress"
x00eb="Warning_235d_Enc_X_FW_download_failed"
x00ec="Warning_236d_X_is_not_a_certified_drive"
x00ed="Info_237d_Dirty_cache_data_discarded_by_user"
x00ee="Info_238d_Drives_missing_from_config_at_boot"
x00ef="Info_239d_VDs_missing_drives_will_go_offline_at_boot"
x00f0="Info_240d_VDs_missing_at_boot_X"
x00f1="Info_241d_Previous_config_completely_missing_at_boot"
x00f2="Info_242d_BBU_charge_complete"
x00f3="Info_243d_Enc_X_fan_X_speed_changed"
x00f4="Info_244d_Dedicated_spare_imported_as_global_missing_arrays"
x00f5="Info_245d_Rebuild_not_possible_SAS-SATA_is_not_supp_in_array"
x00f6="Info_246d_SEP_has_been_rebooted_Enc_FW_download_unavailable"
x00f7="Info_247d_Inserted_PD_X_Info_X"
x00f8="Info_248d_Removed_PD_X_Info_X"
x00f9="Info_249d_VD_X_is_now_OPTIMAL"
x00fa="Warning_250d_VD_X_is_now_PARTIALLY_DEGRADED"
x00fb="Critical_251d_VD_X_is_now_DEGRADED"
x00fc="Fatal_252d_VD_X_is_now_OFFLINE"
x00fd="Warning_253d_BBU_requires_reconditioning_init_a_LEARN_cycle"
x00fe="Warning_254d_VD_X_disabled_RAID-5_not_supported_by_this_RAID_key"
x00ff="Warning_255d_VD_X_disabled_RAID-6_not_supported_by_this_Ctrl"
x0100="Warning_256d_VD_X_disabled_SAS_drvs_not_supp_by_this_RAID_key"
x0101="Warning_257d_PD_missing_X"
x0102="Warning_258d_Puncturing_of_LBAs_enabled"
x0103="Warning_259d_Puncturing_of_LBAs_disabled"
x0104="Critical_260d_Enc_X_EMM_X_not_installed"
x0105="Info_261d_Package_version_X"
x0106="Warning_262d_Global_affinity_Hot_Spare_commissioned_in_a_dif_Enc"
x0107="Warning_263d_Foreign_config_table_overflow"
x0108="Warning_264d_Partial_foreign_config_imported_PDs_not_imported"
x0109="Info_265d_Connector_X_is_active"
x010a="Info_266d_Board_Revision_X"
x010b="Warning_267d_Command_timeout_on_PD_X_CDBX"
x010c="Warning_268d_PD_X_reset_Type_X"
x010d="Warning_269d_VD_bad_block_table_on_X_is_80pct_full"
x010e="Fatal_270d_VD_bad_block_table_is_full_unable_to_log_block"
x010f="Fatal_271d_Uncorrectable_medium_error_logged"
x0110="Info_272d_VD_medium_error_corrected_on_X_at_X"
x0111="Warning_273d_Bad_block_table_on_PD_X_is_100pct_full"
x0112="Warning_274d_VD_bad_block_table_on_PD_X_is_100pct_full"
x0113="Fatal_275d_Ctrl_needs_replacement_IOP_is_faulty"
x0114="Info_276d_CopyBack_started_on_PD_X_from_PD_X"
x0115="Info_277d_CopyBack_aborted_on_PD_X_and_src_is_PD_X"
x0116="Info_278d_CopyBack_complete_on_PD_X_from_PD_X"
x0117="Progress_279d_CopyBack_on_PD_X_is_X"
x0118="Info_280d_CopyBack_resumed_on_PD_X_from_X"
x0119="Info_281d_CopyBack_automatically_started_on_PD_X_from_X"
x011a="Critical_282d_CopyBack_failed_on_PD_X_due_to_source_X_error"
x011b="Warning_283d_Early_Power_off_was_unsuccessful"
x011c="Info_284d_BBU_FRU_is_X"
x011d="Info_285d_X_FRU_is_X"
x011e="Info_286d_Ctrl_hardware_revision_ID_X"
x011f="Warning_287d_Foreign_import_incompatible_config_metadata"
x0120="Info_288d_Redundant_path_restored_for_PD_X"
x0121="Warning_289d_Redundant_path_broken_for_PD_X"
x0122="Info_290d_Redundant_Enc_EMM_X_inserted_for_EMM_X"
x0123="Info_291d_Redundant_Enc_EMM_X_removed_for_EMM_X"
x0124="Warning_292d_Patrol_Read_can't_be_started"
x0125="Info_293d_Copyback_aborted_by_user"
x0126="Critical_294d_Copyback_aborted_hot_spare_needed_for_rebuild"
x0127="Warning_295d_Copyback_aborted_PD_required_in_the_array"
x0128="Fatal_296d_Ctrl_cache_discarded_for_missing_or_offline_VD"
x0129="Info_297d_Copyback_cannot_be_started_PD_too_small"
x012a="Info_298d_Copyback_cannot_be_started_PD_not_supported"
x012b="Info_299d_Microcode_update_started_on_PD_X"
x012c="Info_300d_Microcode_update_completed_on_PD_X"
x012d="Warning_301d_Microcode_update_timeout_on_PD_X"
x012e="Warning_302d_Microcode_update_failed_on_PD_X"
x012f="Info_303d_Ctrl_properties_changed"
x0130="Info_304d_Patrol_Read_properties_changed"
x0131="Info_305d_CC_Schedule_properties_changed"
x0132="Info_306d_BBU_properties_changed"
x0133="Warning_307d_Periodic_BBU_Relearn_is_pending_init_manual_learn"
x0134="Info_308d_Drive_security_key_created"
x0135="Info_309d_Drive_security_key_backed_up"
x0136="Info_310d_Drive_security_key_from_escrow_verified"
x0137="Info_311d_Drive_security_key_changed"
x0138="Warning_312d_Drive_security_key_re-key_operation_failed"
x0139="Warning_313d_Drive_security_key_is_invalid"
x013a="Info_314d_Drive_security_key_destroyed"
x013b="Warning_315d_Drive_security_key_from_escrow_is_invalid"
x013c="Info_316d_VD_X_is_now_secured"
x013d="Warning_317d_VD_X_is_partially_secured"
x013e="Info_318d_PD_X_security_activated"
x013f="Info_319d_PD_X_security_disabled"
x0140="Info_320d_PD_X_is_reprovisioned"
x0141="Info_321d_PD_X_security_key_changed"
x0142="Fatal_322d_Security_subsystem_problems_detected_for_PD_X"
x0143="Fatal_323d_Ctrl_cache_pinned_for_missing_or_offline_VD_X"
x0144="Fatal_324d_Ctrl_cache_pinned_for_missing_or_offline_VDs_X"
x0145="Info_325d_Ctrl_cache_discarded_by_user_for_VDs_X"
x0146="Info_326d_Ctrl_cache_destaged_for_VD_X"
x0147="Warning_327d_CC_started_on_an_inconsistent_VD_X"
x0148="Warning_328d_Drive_security_key_failure_cannot_access_config"
x0149="Warning_329d_Drive_security_passphrase_from_user_is_invalid"
x014a="Warning_330d_Detected_error_remote_BBU_connector_cable"
x014b="Info_331d_Power_state_change_on_PD_X_from_X_to_X"
x014c="Info_332d_Enc_X_element_SES_code_0xX_status_changed"
x014d="Info_333d_PD_X_rebuild_not_possible_as_HDD-SSD_not_supported"
x014e="Info_334d_Copyback_cant_start_HDD-SSD_mix_not_supported"
x014f="Info_335d_VD_bad_block_table_on_X_is_cleared"
x0150="Caution_336d_Caution_SAS_topo_error_0xX"
x0151="Info_337d_A_cluster_of_medium-level_errors_were_corrected"
x0152="Info_338d_Ctrl_requests_a_rescan_of_the_host_bus_adapter"
x0153="Info_339d_Ctrl_repurposed_and_the_factory_defaults_restored"
x0154="Info_340d_Drive_security_key_binding_updated"



for i in "x0000 $x0000" "x0001 $x0001" "x0002 $x0002" "x0003 $x0003" "x0004 $x0004" "x0005 $x0005" "x0006 $x0006" "x0007 $x0007" "x0008 $x0008" "x0009 $x0009" "x000a $x000a" "x000b $x000b" "x000c $x000c" "x000d $x000d" "x000e $x000e" "x000f $x000f" "x0010 $x0010" "x0011 $x0011" "x0012 $x0012" "x0013 $x0013" "x0014 $x0014" "x0015 $x0015" "x0016 $x0016" "x0017 $x0017" "x0018 $x0018" "x0019 $x0019" "x001a $x001a" "x001b $x001b" "x001c $x001c" "x001d $x001d" "x001e $x001e" "x001f $x001f" "x0020 $x0020" "x0021 $x0021" "x0022 $x0022" "x0023 $x0023" "x0024 $x0024" "x0025 $x0025" "x0026 $x0026" "x0027 $x0027" "x0028 $x0028" "x0029 $x0029" "x002a $x002a" "x002b $x002b" "x002c $x002c" "x002d $x002d" "x002e $x002e" "x002f $x002f" "x0030 $x0030" "x0031 $x0031" "x0032 $x0032" "x0033 $x0033" "x0034 $x0034" "x0035 $x0035" "x0036 $x0036" "x0038 $x0038" "x0039 $x0039" "x003a $x003a" "x003b $x003b" "x003c $x003c" "x003d $x003d" "x003e $x003e" "x003f $x003f" "x0040 $x0040" "x0041 $x0041" "x0042 $x0042" "x0043 $x0043" "x0044 $x0044" "x0045 $x0045" "x0046 $x0046" "x0047 $x0047" "x0048 $x0048" "x0049 $x0049" "x004a $x004a" "x004b $x004b" "x004c $x004c" "x004d $x004d" "x004e $x004e" "x004f $x004f" "x0050 $x0050" "x0051 $x0051" "x0052 $x0052" "x0053 $x0053" "x0054 $x0054" "x0055 $x0055" "x0056 $x0056" "x0057 $x0057" "x0058 $x0058" "x0059 $x0059" "x005a $x005a" "x005b $x005b" "x005c $x005c" "x005d $x005d" "x005e $x005e" "x005f $x005f" "x0060 $x0060" "x0061 $x0061" "x0062 $x0062" "x0063 $x0063" "x0064 $x0064" "x0065 $x0065" "x0066 $x0066" "x0067 $x0067" "x0068 $x0068" "x0069 $x0069" "x006a $x006a" "x006b $x006b" "x006c $x006c" "x006d $x006d" "x006e $x006e" "x006f $x006f" "x0070 $x0070" "x0071 $x0071" "x0072 $x0072" "x0073 $x0073" "x0074 $x0074" "x0075 $x0075" "x0076 $x0076" "x0077 $x0077" "x0078 $x0078" "x0079 $x0079" "x007a $x007a" "x007b $x007b" "x007c $x007c" "x007d $x007d" "x007e $x007e" "x007f $x007f" "x0080 $x0080" "x0081 $x0081" "x0082 $x0082" "x0083 $x0083" "x0084 $x0084" "x0085 $x0085" "x0086 $x0086" "x0087 $x0087" "x0088 $x0088" "x0089 $x0089" "x008a $x008a" "x008b $x008b" "x008c $x008c" "x008d $x008d" "x008e $x008e" "x008f $x008f" "x0090 $x0090" "x0091 $x0091" "x0092 $x0092" "x0093 $x0093" "x0094 $x0094" "x0095 $x0095" "x0096 $x0096" "x0097 $x0097" "x0098 $x0098" "x0099 $x0099" "x009a $x009a" "x009b $x009b" "x009c $x009c" "x009d $x009d" "x009e $x009e" "x009f $x009f" "x00a0 $x00a0" "x00a1 $x00a1" "x00a2 $x00a2" "x00a3 $x00a3" "x00a4 $x00a4" "x00a5 $x00a5" "x00a6 $x00a6" "x00a7 $x00a7" "x00a8 $x00a8" "x00a9 $x00a9" "x00aa $x00aa" "x00ab $x00ab" "x00ac $x00ac" "x00ad $x00ad" "x00ae $x00ae" "x00af $x00af" "x00b0 $x00b0" "x00b1 $x00b1" "x00b2 $x00b2" "x00b3 $x00b3" "x00b4 $x00b4" "x00b5 $x00b5" "x00b6 $x00b6" "x00b7 $x00b7" "x00b8 $x00b8" "x00b9 $x00b9" "x00ba $x00ba" "x00bb $x00bb" "x00bc $x00bc" "x00bd $x00bd" "x00be $x00be" "x00bf $x00bf" "x00c0 $x00c0" "x00c1 $x00c1" "x00c2 $x00c2" "x00c3 $x00c3" "x00c4 $x00c4" "x00c5 $x00c5" "x00c6 $x00c6" "x00c7 $x00c7" "x00c8 $x00c8" "x00c9 $x00c9" "x00ca $x00ca" "x00cb $x00cb" "x00cc $x00cc" "x00cd $x00cd" "x00ce $x00ce" "x00cf $x00cf" "x00d0 $x00d0" "x00d1 $x00d1" "x00d2 $x00d2" "x00d3 $x00d3" "x00d4 $x00d4" "x00d5 $x00d5" "x00d6 $x00d6" "x00d7 $x00d7" "x00d8 $x00d8" "x00d9 $x00d9" "x00da $x00da" "x00db $x00db" "x00dc $x00dc" "x00dd $x00dd" "x00de $x00de" "x00df $x00df" "x00e0 $x00e0" "x00e1 $x00e1" "x00e2 $x00e2" "x00e3 $x00e3" "x00e4 $x00e4" "x00e5 $x00e5" "x00e6 $x00e6" "x00e7 $x00e7" "x00e8 $x00e8" "x00e9 $x00e9" "x00ea $x00ea" "x00eb $x00eb" "x00ec $x00ec" "x00ed $x00ed" "x00ee $x00ee" "x00ef $x00ef" "x00f0 $x00f0" "x00f1 $x00f1" "x00f2 $x00f2" "x00f3 $x00f3" "x00f4 $x00f4" "x00f5 $x00f5" "x00f6 $x00f6" "x00f7 $x00f7" "x00f8 $x00f8" "x00f9 $x00f9" "x00fa $x00fa" "x00fb $x00fb" "x00fc $x00fc" "x00fd $x00fd" "x00fe $x00fe" "x00ff $x00ff" "x0100 $x0100" "x0101 $x0101" "x0102 $x0102" "x0103 $x0103" "x0104 $x0104" "x0105 $x0105" "x0106 $x0106" "x0107 $x0107" "x0108 $x0108" "x0109 $x0109" "x010a $x010a" "x010b $x010b" "x010c $x010c" "x010d $x010d" "x010e $x010e" "x010f $x010f" "x0110 $x0110" "x0111 $x0111" "x0112 $x0112" "x0113 $x0113" "x0114 $x0114" "x0115 $x0115" "x0116 $x0116" "x0117 $x0117" "x0118 $x0118" "x0119 $x0119" "x011a $x011a" "x011b $x011b" "x011c $x011c" "x011d $x011d" "x011e $x011e" "x011f $x011f" "x0120 $x0120" "x0121 $x0121" "x0122 $x0122" "x0123 $x0123" "x0124 $x0124" "x0125 $x0125" "x0126 $x0126" "x0127 $x0127" "x0128 $x0128" "x0129 $x0129" "x012a $x012a" "x012b $x012b" "x012c $x012c" "x012d $x012d" "x012e $x012e" "x012f $x012f" "x0130 $x0130" "x0131 $x0131" "x0132 $x0132" "x0133 $x0133" "x0134 $x0134" "x0135 $x0135" "x0136 $x0136" "x0137 $x0137" "x0138 $x0138" "x0139 $x0139" "x013a $x013a" "x013b $x013b" "x013c $x013c" "x013d $x013d" "x013e $x013e" "x013f $x013f" "x0140 $x0140" "x0141 $x0141" "x0142 $x0142" "x0143 $x0143" "x0144 $x0144" "x0145 $x0145" "x0146 $x0146" "x0147 $x0147" "x0148 $x0148" "x0149 $x0149" "x014a $x014a" "x014b $x014b" "x014c $x014c" "x014d $x014d" "x014e $x014e" "x014f $x014f" "x0150 $x0150" "x0151 $x0151" "x0152 $x0152" "x0153 $x0153" "x0154 $x0154" ; do

set $i

if [ -e ./$fileName/MegaRAID/megaraid_driver_messages.txt ]; then
       $grep -i $1 ./$fileName/MegaRAID/megaraid_driver_messages.txt > ./$fileName/MegaRAID/megasas_$1_$2.txt

		if [ ! -s ./$fileName/MegaRAID/megasas_$1_$2.txt ]; then rm ./$fileName/MegaRAID/megasas_$1_$2.txt > /dev/null 2>&1 ; fi

fi

done

# Real error will be flagged by mrmonitord
if [ -e ./$fileName/MegaRAID/megasas_x0079_Critical_121d_SAS_topo_error_Multiple_ports_same_SAS_address.txt ]; then 
grep -i "same" ./$fileName/MegaRAID/megasas_x0079_Critical_121d_SAS_topo_error_Multiple_ports_same_SAS_address.txt > /dev/null 2>&1
	if [ "$?" -ne "0" ]; then
	rm ./$fileName/MegaRAID/megasas_x0079_Critical_121d_SAS_topo_error_Multiple_ports_same_SAS_address.txt > /dev/null 2>&1 
	fi
fi


###########################################################################################################################
# MegaRAID Decimal AENs from SAS SW Users Guide July 2009 80-00156-01 Rev. H
###########################################################################################################################

MRMON000="Info_0x0000h_MegaRAID_FW_init_started"
MRMON001="Info_0x0001h_MegaRAID_FW_version_0x"
MRMON002="Fatal_0x0002h_Unable_to_recover_cache_data_from_TBBU"
MRMON003="Info_0x0003h_Cache_data_recovered_from_TBBU_successfully"
MRMON004="Info_0x0004h_config_cleared"
MRMON005="Warning_0x0005h_Cluster_down_com_with_peer_lost"
MRMON006="Info_0x0006h_Virtual_drive_0x_ownership_changed"
MRMON007="Info_0x0007h_Alarm_disabled_by_user"
MRMON008="Info_0x0008h_Alarm_enabled_by_user"
MRMON009="Info_0x0009h_Bkgrnd_init_rate_changed_to_0x"
MRMON010="Fatal_0x000Ah_Ctrl_cache_discarded_due_to_memory-BBU_problems"
MRMON011="Fatal_0x000Bh_Unable_to_recover_cache_data_due_to_config_mismatch"
MRMON012="Info_0x000Ch_Cache_data_recovered_successfully"
MRMON013="Fatal_0x000Dh_Ctrl_cache_discarded_due_to_FW_version_incomp"
MRMON014="Info_0x000Eh_CC_rate_changed_to_0x"
MRMON015="Fatal_0x000Fh_FW_error_0x"
MRMON016="Info_0x0010h_Factory_defaults_restored"
MRMON017="Info_0x0011h_Flash_downloaded_image_corrupt"
MRMON018="Critical_0x0012h_Flash_erase_error"
MRMON019="Critical_0x0013h_Flash_timeout_during_erase"
MRMON020="Critical_0x0014h_Flash_error"
MRMON021="Info_0x0015h_Flashing_image_0x"
MRMON022="Info_0x0016h_Flash_of_new_FW_images_complete"
MRMON023="Critical_0x0017h_Flash_programming_error"
MRMON024="Critical_0x0018h_Flash_timeout_during_programming"
MRMON025="Critical_0x0019h_Flash_chip_type_unknown"
MRMON026="Critical_0x001Ah_Flash_command_set_unknown"
MRMON027="Critical_0x001Bh_Flash_verify_failure"
MRMON028="Info_0x001Ch_Flush_rate_changed_to_0x_seconds"
MRMON029="Info_0x001Dh_Hibernate_command_received_from_host"
MRMON030="Info_0x001Eh_Event_log_cleared"
MRMON031="Info_0x001Fh_Event_log_wrapped"
MRMON032="Fatal_0x0020h_Multi-bit_ECC_error_ECAR_0x_ELOG_0x_0x"
MRMON033="Warning_0x0021h_Single-bit_ECC_error_ECAR_0x_ELOG_0x_0x"
MRMON034="Fatal_0x0022h_Not_enough_Ctrl_memory"
MRMON035="Info_0x0023h_Patrol_Read_complete"
MRMON036="Info_0x0024h_Patrol_Read_paused"
MRMON037="Info_0x0025h_Patrol_Read_Rate_changed_to_0x"
MRMON038="Info_0x0026h_Patrol_Read_resumed"
MRMON039="Info_0x0027h_Patrol_Read_started"
MRMON040="Info_0x0028h_Rebuild_rate_changed_to_0x"
MRMON041="Info_0x0029h_Drive_group_mod_rate_changed_to_0x"
MRMON042="Info_0x002Ah_Shutdown_command_received_from_host"
MRMON043="Info_0x002Bh_Test_event_0x"
MRMON044="Info_0x002Ch_Time_established_as_0x_0x_seconds_since_power_on"
MRMON045="Info_0x002Dh_User_entered_FW_debugger"
MRMON046="Warning_0x002Eh_Bkgrnd_init_aborted_on_0x"
MRMON047="Warning_0x002Fh_Bkgrnd_init_corrected_medium_error_0x_at_0x"
MRMON048="Info_0x0030h_Bkgrnd_init_completed_on_0x"
MRMON049="Fatal_0x0031h_Bkgrnd_init_completed_with_uncorrectable_errors"
MRMON050="Fatal_0x0032h_Bkgrnd_init_detect_uncorrect_double_medium_errors"
MRMON051="Critical_0x0033h_Bkgrnd_init_failed_on_0x"
MRMON052="Progress_0x0034h_Bkgrnd_init_on_0x_is_0x"
MRMON053="Info_0x0035h_Bkgrnd_init_started_on_0x"
MRMON054="Info_0x0036h_Policy_change_on_0x_from_0x_to_0x"
MRMON056="Warning_0x0038h_CC_aborted_on_0x"
MRMON057="Warning_0x0039h_CC_corrected_medium_error_0x_at_0x"
MRMON058="Info_0x003Ah_CC_done_on_0x"
MRMON059="Info_0x003Bh_CC_done_with_corrections_on_0x"
MRMON060="Fatal_0x003Ch_CC_detected_uncorrectable_double_medium_errors"
MRMON061="Critical_0x003Dh_CC_failed_on_0x"
MRMON062="Fatal_0x003Eh_CC_completed_with_uncorrectable_data_on_0x"
MRMON063="Warning_0x003Fh_CC_found_inconsistent_parity_on_0x_at_strip_0x"
MRMON064="Warning_0x0040h_CC_inconsistency_logging_disabled_too_many"
MRMON065="Progress_0x0041h_CC_on_0x_is_0x"
MRMON066="Info_0x0042h_CC_started_on_0x"
MRMON067="Warning_0x0043h_init_aborted_on_0x"
MRMON068="Critical_0x0044h_init_failed_on_0x"
MRMON069="Progress_0x0045h_init_on_0x_is_0x"
MRMON070="Info_0x0046h_Fast_init_started_on_0x"
MRMON071="Info_0x0047h_Full_init_started_on_0x"
MRMON072="Info_0x0048h_init_complete_on_0x"
MRMON073="Info_0x0049h_LD_Properties_updated_to_0x_from_0x"
MRMON074="Info_0x004Ah_Drive_group_mod_complete_on_0x"
MRMON075="Fatal_0x004Bh_Drive_group_mod_stopped_due_to_unrecov_errors"
MRMON076="Fatal_0x004Ch_Recon_detected_uncorrect_double_medium_errors"
MRMON077="Progress_0x004Dh_Drive_group_mod_on_0x_is_0x"
MRMON078="Info_0x004Fh_Drive_group_mod_resumed_on_0x"
MRMON079="Fatal_0x004Fh_Drv_group_mod_resume_failed_due_to_config_mismatch"
MRMON080="Info_0x0050h_Modifying_drive_group_started_on_0x"
MRMON081="Info_0x0051h_State_change_on_0x_from_0x_to_0x"
MRMON082="Info_0x0052h_Drive_Clear_aborted_on_0x"
MRMON083="Critical_0x0053h_Drive_Clear_failed_on_0x_Error_0x"
MRMON084="Progress_0x0054h_Drive_Clear_on_0x_is_0x"
MRMON085="Info_0x0055h_Drive_Clear_started_on_0x"
MRMON086="Info_0x0056h_Drive_Clear_completed_on_0x"
MRMON087="Warning_0x0057h_Error_on_0x_Error_0x"
MRMON088="Info_0x0058h_Format_complete_on_0x"
MRMON089="Info_0x0059h_Format_started_on_0x"
MRMON090="Critical_0x005Ah_Hot_Spare_SMART_polling_failed_on_0x_Error_0x"
MRMON091="Info_0x005Bh_Drive_inserted_0x"
MRMON092="Warning_0x005Ch_Drive_0x_is_not_supported"
MRMON093="Warning_0x005Dh_Patrol_Read_corrected_medium_error_on_0x_at_0x"
MRMON094="Progress_0x005Eh_Patrol_Read_on_0x_is_0x"
MRMON095="Fatal_0x005Fh_Patrol_Read_found_an_uncorrectable_medium_error"
MRMON096="Critical_0x0060h_Predictive_failure_CDB_0x"
MRMON097="Fatal_0x0061h_Patrol_Read_puncturing_bad_block_on_0x_at_0x"
MRMON098="Info_0x0062h_Rebuild_aborted_by_user_on_0x"
MRMON099="Info_0x0063h_Rebuild_complete_on_0x"
MRMON100="Info_0x0064h_Rebuild_complete_on_0x"
MRMON101="Critical_0x0065h_Rebuild_failed_on_0x_due_to_source_drive_error"
MRMON102="Critical_0x0066h_Rebuild_failed_on_0x_due_to_target_drive_error"
MRMON103="Progress_0x0067h_Rebuild_on_0x_is_0x"
MRMON104="Info_0x0068h_Rebuild_resumed_on_0x"
MRMON105="Info_0x0069h_Rebuild_started_on_0x"
MRMON106="Info_0x006Ah_Rebuild_automatically_started_on_0x"
MRMON107="Critical_0x006Bh_Rebuild_stopped_loss_of_cluster_ownership"
MRMON108="Fatal_0x006Ch_Reassign_write_operation_failed_on_0x_at_0x"
MRMON109="Fatal_0x006Dh_Unrecoverable_medium_error_during_rebuild"
MRMON110="Info_0x006Eh_Corrected_medium_error_during_recovery"
MRMON111="Fatal_0x006Fh_Unrecoverable_medium_error_during_recovery"
MRMON112="Info_0x0070h_Drive_removed_0x"
MRMON113="Warning_0x0071h_Unexpected_sense_0x_CDBX_Sense_0x"
MRMON114="Info_0x0072h_State_change_on_0x_from_0x_to_0x"
MRMON115="Info_0x0073h_State_change_by_user_on_0x_from_0x_to_0x"
MRMON116="Warning_0x0074h_Redundant_path_to_0x_broken"
MRMON117="Info_0x0075h_Redundant_path_to_0x_restored"
MRMON118="Info_0x0076h_Dedicated_Hot_Spare_Drive_0x_no_longer_useful"
MRMON119="Critical_0x0077h_SAS_topo_error_Loop_detected"
MRMON120="Critical_0x0078h_SAS_topo_error_Unaddressable_device"
MRMON121="Critical_0x0079h_SAS_topo_error_Multiple_ports_same_SAS_address"
MRMON122="Critical_0x007Ah_SAS_topo_error_Expander_error"
MRMON123="Critical_0x007Bh_SAS_topo_error_SMP_timeout"
MRMON124="Critical_0x007Ch_SAS_topo_error_Out_of_route_entries"
MRMON125="Critical_0x007Dh_SAS_topo_error_Index_not_found"
MRMON126="Critical_0x007Eh_SAS_topo_error_SMP_function_failed"
MRMON127="Critical_0x007Fh_SAS_topo_error_SMP_CRC_error"
MRMON128="Critical_0x0080h_SAS_topo_error_Multiple_subtractive"
MRMON129="Critical_0x0081h_SAS_topo_error_Table_to_table"
MRMON130="Critical_0x0082h_SAS_topo_error_Multiple_paths"
MRMON131="Fatal_0x0083h_Unable_to_access_device_0x"
MRMON132="Info_0x0084h_Dedicated_Hot_Spare_created_on_0x_0x"
MRMON133="Info_0x0085h_Dedicated_Hot_Spare_0x_disabled"
MRMON134="Critical_0x0086h_Dedicated_Hot_Spare_0x_no_longer_useful"
MRMON135="Info_0x0087h_Global_Hot_Spare_created_on_0x_0x"
MRMON136="Info_0x0088h_Global_Hot_Spare_0x_disabled"
MRMON137="Critical_0x0089h_Global_Hot_Spare_does_not_cover_all_drive_groups"
MRMON138="Info_0x008Ah_Created_0x"
MRMON139="Info_0x008Bh_Deleted_0x"
MRMON140="Info_0x008Ch_Marking_LD_0x_inconsistent"
MRMON141="Info_0x008Dh_BBU_Present"
MRMON142="Warning_0x008Eh_BBU_Not_Present"
MRMON143="Info_0x008Fh_New_BBU_Detected"
MRMON144="Info_0x0090h_BBU_has_been_replaced"
MRMON145="Critical_0x0091h_BBU_temp_is_high"
MRMON146="Warning_0x0092h_BBU_voltage_low"
MRMON147="Info_0x0093h_BBU_started_charging"
MRMON148="Info_0x0094h_BBU_is_discharging"
MRMON149="Info_0x0095h_BBU_temp_is_normal"
MRMON150="Fatal_0x0096h_BBU_needs_to_be_replacement_SOH_Bad"
MRMON151="Info_0x0097h_BBU_relearn_started"
MRMON152="Info_0x0098h_BBU_relearn_in_progress"
MRMON153="Info_0x0099h_BBU_relearn_completed"
MRMON154="Critical_0x009Ah_BBU_relearn_timed_out"
MRMON155="Info_0x009Bh_BBU_relearn_pending_BBU_is_under_charge"
MRMON156="Info_0x009Ch_BBU_relearn_postponed"
MRMON157="Info_0x009Dh_BBU_relearn_will_start_in_4_days"
MRMON158="Info_0x009Eh_BBU_relearn_will_start_in_2_day"
MRMON159="Info_0x009Fh_BBU_relearn_will_start_in_1_day"
MRMON160="Info_0x00A0h_BBU_relearn_will_start_in_5_hours"
MRMON161="Info_0x00A1h_BBU_removed"
MRMON162="Info_0x00A2h_Current_capacity_of_the_BBU_is_below_threshold"
MRMON163="Info_0x00A3h_Current_capacity_of_the_BBU_is_above_threshold"
MRMON164="Info_0x00A4h_Enc_SES_discovered_on_0x"
MRMON165="Info_0x00A5h_Enc_SAFTE_discovered_on_0x"
MRMON166="Critical_0x00A6h_Enc_0x_com_lost"
MRMON167="Info_0x00A7h_Enc_0x_com_restored"
MRMON168="Critical_0x00A8h_Enc_0x_fan_0x_failed"
MRMON169="Info_0x00A9h_Enc_0x_fan_0x_inserted"
MRMON170="Critical_0x00AAh_Enc_0x_fan_0x_removed"
MRMON171="Critical_0x00ABh_Enc_0x_power_supply_0x_failed"
MRMON172="Info_0x00ACh_Enc_0x_power_supply_0x_inserted"
MRMON173="Critical_0x00ADh_Enc_0x_power_supply_0x_removed"
MRMON174="Critical_0x00AEh_Enc_0x_SIM_0x_failed"
MRMON175="Info_0x00AFh_Enc_0x_SIM_0x_inserted"
MRMON176="Critical_0x00B0h_Enc_0x_SIM_0x_removed"
MRMON177="Warning_0x00B1h_Enc_0x_temp_sensor_0x_below_threshold"
MRMON178="Critical_0x00B2h_Enc_0x_temp_sensor_0x_below_error_threshold"
MRMON179="Warning_0x00B3h_Enc_0x_temp_sensor_0x_above_threshold"
MRMON180="Critical_0x00B4h_Enc_0x_temp_sensor_0x_above_error_threshold"
MRMON181="Critical_0x00B5h_Enc_0x_shutdown"
MRMON182="Warning_0x00B6h_Enc_0x_not_supported_too_many_Encs_connected"
MRMON183="Critical_0x00B7h_Enc_0x_FW_mismatch"
MRMON184="Warning_0x00B8h_Enc_0x_sensor_0x_bad"
MRMON185="Critical_0x00B9h_Enc_0x_phy_0x_bad"
MRMON186="Critical_0x00BAh_Enc_0x_is_unstable"
MRMON187="Critical_0x00BBh_Enc_0x_hardware_error"
MRMON188="Critical_0x00BCh_Enc_0x_not_responding"
MRMON189="Info_0x00BDh_SAS-SATA_mixing_not_supported_Drive_disabled"
MRMON190="Info_0x00BEh_Enc_SES_hotplug_was_detect_but_is_not_supported"
MRMON191="Info_0x00BFh_Clustering_enabled"
MRMON192="Info_0x00C0h_Clustering_disabled"
MRMON193="Info_0x00C1h_Drive_too_small_to_be_used_for_auto-rebuild"
MRMON194="Info_0x00C2h_BBU_enabled_changing_WT_VDs_to_WB"
MRMON195="Warning_0x00C3h_BBU_disabled_changing_WB_VDs_to_WT"
MRMON196="Warning_0x00C4h_Bad_block_table_on_drive_0x_is_80pct_full"
MRMON197="Fatal_0x00C5h_Bad_block_table_is_full_unable_to_log_block_0x"
MRMON198="Info_0x00C6h_CC_Aborted_due_to_ownership_loss_on_0x"
MRMON199="Info_0x00C7h_Bkgrnd_init_BGI_Aborted_Due_to_Ownership_Loss"
MRMON200="Critical_0x00C8h_BBU-charger_problems_detected_SOH_Bad"
MRMON201="Warning_0x00C9h_Single-bit_ECC_error_warn_threshold_exceeded"
MRMON202="Critical_0x00CAh_Single-bit_ECC_error_crit_threshold_exceeded"
MRMON203="Critical_0x00CBh_Single-bit_ECC_error_further_reporting_disabled"
MRMON204="Critical_0x00CCh_Enc_0x_Power_supply_0x_switched_off"
MRMON205="Info_0x00CDh_Enc_0x_Power_supply_0x_switched_on"
MRMON206="Critical_0x00CEh_Enc_0x_Power_supply_0x_cable_removed"
MRMON207="Info_0x00CFh_Enc_0x_Power_supply_0x_cable_inserted"
MRMON208="Info_0x00D0h_Enc_0x_Fan_0x_returned_to_normal"
MRMON209="Info_0x00D1h_BBU_Retention_test_was_initiated_on_previous_boot"
MRMON210="Info_0x00D2h_BBU_Retention_test_passed"
MRMON211="Critical_0x00D3h_BBU_Retention_test_failed"
MRMON212="Info_0x00D4h_NVRAM_Retention_test_initiated_on_previous_boot"
MRMON213="Info_0x00D5h_NVRAM_Retention_test_passed"
MRMON214="Critical_0x00D6h_NVRAM_Retention_test_failed"
MRMON215="Info_0x00D7h_X_test_completed_0x_passes_successfully"
MRMON216="Critical_0x00D8h_test_FAILED_on_0x_pass_Fail_data_errorOffset"
MRMON217="Info_0x00D9h_Self_Chk_diagnostics_completed"
MRMON218="Info_0x00DAh_Foreign_config_detected"
MRMON219="Info_0x00DBh_Foreign_config_imported"
MRMON220="Info_0x00DCh_Foreign_config_cleared"
MRMON221="Warning_0x00DDh_NVRAM_is_corrupt_reinitializing"
MRMON222="Warning_0x00DEh_NVRAM_mismatch_occurred"
MRMON223="Warning_0x00DFh_SAS_wide_port_0x_lost_link_on_PHY_0x"
MRMON224="Info_0x00E0h_SAS_wide_port_0x_restored_link_on_PHY_0x"
MRMON225="Warning_0x00E1h_SAS_port_PHY_has_exceeded_the_allowed_error_rate"
MRMON226="Warning_0x00E2h_Bad_block_reassigned_on_0x_at_0x_to_0x"
MRMON227="Info_0x00E3h_Ctrl_Hot_Plug_detected"
MRMON228="Warning_0x00E4h_Enc_0x_temp_sensor_0x_differential_detected"
MRMON229="Info_0x00E5h_Drive_test_cannot_start_No_qualifying_drives_found"
MRMON230="Info_0x00Eh_Time_duration_provided_not_sufficient_for_self_Chk"
MRMON231="Info_0x00E7h_Marked_Missing_for_0x_on_drive_group_0x_row_0x"
MRMON232="Info_0x00E8h_Replaced_Missing_as_0x_on_drive_group_0x_row_0x"
MRMON233="Info_0x00E9h_Enc_0x_temp_0x_returned_to_normal"
MRMON234="Info_0x00EAh_Enc_0x_FW_download_in_progress"
MRMON235="Warning_0x00EBh_Enc_0x_FW_download_failed"
MRMON236="Warning_0x00ECh_X_is_not_a_certified_drive"
MRMON237="Info_0x00EDh_Dirty_cache_data_discarded_by_user"
MRMON238="Info_0x00EEh_Drives_missing_from_config_at_boot"
MRMON239="Info_0x00EFh_VDs_missing_drives_will_go_offline_at_boot"
MRMON240="Info_0x00F0h_VDs_missing_at_boot_0x"
MRMON241="Info_0x00F1h_Previous_config_completely_missing_at_boot"
MRMON242="Info_0x00F2h_BBU_charge_complete"
MRMON243="Info_0x00F3h_Enc_0x_fan_0x_speed_changed"
MRMON244="Info_0x00F4h_Dedicated_spare_imported_as_global_missing_arrays"
MRMON245="Info_0x00F5h_Rebuild_not_possible_SAS-SATA_is_not_supp_in_array"
MRMON246="Info_0x00F6h_SEP_has_been_rebooted_Enc_FW_download_unavailable"
MRMON247="Info_0x00F7_Inserted_PD_0x_Infoh_X"
MRMON248="Info_0x00F8_Removed_PD_0x_Infoh_X"
MRMON249="Info_0x00F9h_VD_0x_is_now_OPTIMAL"
MRMON250="Warning_0x00FAh_VD_0x_is_now_PARTIALLY_DEGRADED"
MRMON251="Critical_0x00FBh_VD_0x_is_now_DEGRADED"
MRMON252="Fatal_0x00FCh_VD_0x_is_now_OFFLINE"
MRMON253="Warning_0x00FDh_BBU_requires_reconditioning_init_a_LEARN_cycle"
MRMON254="Warning_0x00FEh_VD_0x_disabled_RAID-5_not_supported_by_this_RAID_key"
MRMON255="Warning_0x00FFh_VD_0x_disabled_RAID-6_not_supported_by_this_Ctrl"
MRMON256="Warning_0x0100h_VD_0x_disabled_SAS_drvs_not_supp_by_this_RAID_key"
MRMON257="Warning_0x0101h_PD_missing_0x"
MRMON258="Warning_0x0102h_Puncturing_of_LBAs_enabled"
MRMON259="Warning_0x0103h_Puncturing_of_LBAs_disabled"
MRMON260="Critical_0x0104h_Enc_0x_EMM_0x_not_installed"
MRMON261="Info_0x0105h_Package_version_0x"
MRMON262="Warning_0x0106h_Global_affinity_Hot_Spare_commissioned_in_a_dif_Enc"
MRMON263="Warning_0x0107h_Foreign_config_table_overflow"
MRMON264="Warning_0x0108h_Partial_foreign_config_imported_PDs_not_imported"
MRMON265="Info_0x0109h_Connector_0x_is_active"
MRMON266="Info_0x010Ah_Board_Revision_0x"
MRMON267="Warning_0x010Bh_Command_timeout_on_PD_0x_CDBX"
MRMON268="Warning_0x010Ch_PD_0x_reset_Type_0x"
MRMON269="Warning_0x010Dh_VD_bad_block_table_on_0x_is_80pct_full"
MRMON270="Fatal_0x010Eh_VD_bad_block_table_is_full_unable_to_log_block"
MRMON271="Fatal_0x010Fh_Uncorrectable_medium_error_logged"
MRMON272="Info_0x0110h_VD_medium_error_corrected_on_0x_at_0x"
MRMON273="Warning_0x0111h_Bad_block_table_on_PD_0x_is_100pct_full"
MRMON274="Warning_0x0112h_VD_bad_block_table_on_PD_0x_is_100pct_full"
MRMON275="Fatal_0x0113h_Ctrl_needs_replacement_IOP_is_faulty"
MRMON276="Info_0x0114h_CopyBack_started_on_PD_0x_from_PD_0x"
MRMON277="Info_0x0115h_CopyBack_aborted_on_PD_0x_and_src_is_PD_0x"
MRMON278="Info_0x0116h_CopyBack_complete_on_PD_0x_from_PD_0x"
MRMON279="Progress_0x0117h_CopyBack_on_PD_0x_is_0x"
MRMON280="Info_0x0118h_CopyBack_resumed_on_PD_0x_from_0x"
MRMON281="Info_0x0119h_CopyBack_automatically_started_on_PD_0x_from_0x"
MRMON282="Critical_0x011Ah_CopyBack_failed_on_PD_0x_due_to_source_0x_error"
MRMON283="Warning_0x011Bh_Early_Power_off_was_unsuccessful"
MRMON284="Info_0x011Ch_BBU_FRU_is_0x"
MRMON285="Info_0x011Dh_X_FRU_is_0x"
MRMON286="Info_0x011Eh_Ctrl_hardware_revision_ID_0x"
MRMON287="Warning_0x011Fh_Foreign_import_incompatible_config_metadata"
MRMON288="Info_0x0120h_Redundant_path_restored_for_PD_0x"
MRMON289="Warning_0x0121h_Redundant_path_broken_for_PD_0x"
MRMON290="Info_0x0122h_Redundant_Enc_EMM_0x_inserted_for_EMM_0x"
MRMON291="Info_0x0123h_Redundant_Enc_EMM_0x_removed_for_EMM_0x"
MRMON292="Warning_0x0124h_Patrol_Read_can't_be_started"
MRMON293="Info_0x0125h_Copyback_aborted_by_user"
MRMON294="Critical_0x0126h_Copyback_aborted_hot_spare_needed_for_rebuild"
MRMON295="Warning_0x0127h_Copyback_aborted_PD_required_in_the_array"
MRMON296="Fatal_0x0128h_Ctrl_cache_discarded_for_missing_or_offline_VD"
MRMON297="Info_0x0129h_Copyback_cannot_be_started_PD_too_small"
MRMON298="Info_0x012Ah_Copyback_cannot_be_started_PD_not_supported"
MRMON299="Info_0x012Bh_Microcode_update_started_on_PD_0x"
MRMON300="Info_0x012Ch_Microcode_update_completed_on_PD_0x"
MRMON301="Warning_0x012Dh_Microcode_update_timeout_on_PD_0x"
MRMON302="Warning_0x012Eh_Microcode_update_failed_on_PD_0x"
MRMON303="Info_0x012Fh_Ctrl_properties_changed"
MRMON304="Info_0x0130h_Patrol_Read_properties_changed"
MRMON305="Info_0x0131h_CC_Schedule_properties_changed"
MRMON306="Info_0x0132h_BBU_properties_changed"
MRMON307="Warning_0x0133h_Periodic_BBU_Relearn_is_pending_init_manual_learn"
MRMON308="Info_0x0134h_Drive_security_key_created"
MRMON309="Info_0x0135h_Drive_security_key_backed_up"
MRMON310="Info_0x0136h_Drive_security_key_from_escrow_verified"
MRMON311="Info_0x0137h_Drive_security_key_changed"
MRMON312="Warning_0x0138h_Drive_security_key_re-key_operation_failed"
MRMON313="Warning_0x0139h_Drive_security_key_is_invalid"
MRMON314="Info_0x013Ah_Drive_security_key_destroyed"
MRMON315="Warning_0x013Bh_Drive_security_key_from_escrow_is_invalid"
MRMON316="Info_0x013Ch_VD_0x_is_now_secured"
MRMON317="Warning_0x013Dh_VD_0x_is_partially_secured"
MRMON318="Info_0x013Eh_PD_0x_security_activated"
MRMON319="Info_0x013Fh_PD_0x_security_disabled"
MRMON320="Info_0x0140h_PD_0x_is_reprovisioned"
MRMON321="Info_0x0141h_PD_0x_security_key_changed"
MRMON322="Fatal_0x0142h_Security_subsystem_problems_detected_for_PD_0x"
MRMON323="Fatal_0x0143h_Ctrl_cache_pinned_for_missing_or_offline_VD_0x"
MRMON324="Fatal_0x0144h_Ctrl_cache_pinned_for_missing_or_offline_VDs_0x"
MRMON325="Info_0x0145h_Ctrl_cache_discarded_by_user_for_VDs_0x"
MRMON326="Info_0x0146h_Ctrl_cache_destaged_for_VD_0x"
MRMON327="Warning_0x0147h_CC_started_on_an_inconsistent_VD_0x"
MRMON328="Warning_0x0148h_Drive_security_key_failure_cannot_access_config"
MRMON329="Warning_0x0149h_Drive_security_passphrase_from_user_is_invalid"
MRMON330="Warning_0x014Ah_Detected_error_remote_BBU_connector_cable"
MRMON331="Info_0x014Bh_Power_state_change_on_PD_0x_from_0x_to_0x"
MRMON332="Info_0x014Ch_Enc_0x_element_SES_code_0xX_status_changed"
MRMON333="Info_0x014Dh_PD_0x_rebuild_not_possible_as_HDD-SSD_not_supported"
MRMON334="Info_0x014Eh_Copyback_cant_start_HDD-SSD_mix_not_supported"
MRMON335="Info_0x014Fh_VD_bad_block_table_on_0x_is_cleared"
MRMON336="Caution_0x0150h_Caution_SAS_topo_error_0xX"
MRMON337="Info_0x0151h_A_cluster_of_medium-level_errors_were_corrected"
MRMON338="Info_0x0152h_Ctrl_requests_a_rescan_of_the_host_bus_adapter"
MRMON339="Info_0x0153h_Ctrl_repurposed_and_the_factory_defaults_restored"
MRMON340="Info_0x0154h_Drive_security_key_binding_updated"


for i in "MRMON000 $MRMON000" "MRMON001 $MRMON001" "MRMON002 $MRMON002" "MRMON003 $MRMON003" "MRMON004 $MRMON004" "MRMON005 $MRMON005" "MRMON006 $MRMON006" "MRMON007 $MRMON007" "MRMON008 $MRMON008" "MRMON009 $MRMON009" "MRMON010 $MRMON010" "MRMON011 $MRMON011" "MRMON012 $MRMON012" "MRMON013 $MRMON013" "MRMON014 $MRMON014" "MRMON015 $MRMON015" "MRMON016 $MRMON016" "MRMON017 $MRMON017" "MRMON018 $MRMON018" "MRMON019 $MRMON019" "MRMON020 $MRMON020" "MRMON021 $MRMON021" "MRMON022 $MRMON022" "MRMON023 $MRMON023" "MRMON024 $MRMON024" "MRMON025 $MRMON025" "MRMON026 $MRMON026" "MRMON027 $MRMON027" "MRMON028 $MRMON028" "MRMON029 $MRMON029" "MRMON030 $MRMON030" "MRMON031 $MRMON031" "MRMON032 $MRMON032" "MRMON033 $MRMON033" "MRMON034 $MRMON034" "MRMON035 $MRMON035" "MRMON036 $MRMON036" "MRMON037 $MRMON037" "MRMON038 $MRMON038" "MRMON039 $MRMON039" "MRMON040 $MRMON040" "MRMON041 $MRMON041" "MRMON042 $MRMON042" "MRMON043 $MRMON043" "MRMON044 $MRMON044" "MRMON045 $MRMON045" "MRMON046 $MRMON046" "MRMON047 $MRMON047" "MRMON048 $MRMON048" "MRMON049 $MRMON049" "MRMON050 $MRMON050" "MRMON051 $MRMON051" "MRMON052 $MRMON052" "MRMON053 $MRMON053" "MRMON054 $MRMON054" "MRMON056 $MRMON056" "MRMON057 $MRMON057" "MRMON058 $MRMON058" "MRMON059 $MRMON059" "MRMON060 $MRMON060" "MRMON061 $MRMON061" "MRMON062 $MRMON062" "MRMON063 $MRMON063" "MRMON064 $MRMON064" "MRMON065 $MRMON065" "MRMON066 $MRMON066" "MRMON067 $MRMON067" "MRMON068 $MRMON068" "MRMON069 $MRMON069" "MRMON070 $MRMON070" "MRMON071 $MRMON071" "MRMON072 $MRMON072" "MRMON073 $MRMON073" "MRMON074 $MRMON074" "MRMON075 $MRMON075" "MRMON076 $MRMON076" "MRMON077 $MRMON077" "MRMON078 $MRMON078" "MRMON079 $MRMON079" "MRMON080 $MRMON080" "MRMON081 $MRMON081" "MRMON082 $MRMON082" "MRMON083 $MRMON083" "MRMON084 $MRMON084" "MRMON085 $MRMON085" "MRMON086 $MRMON086" "MRMON087 $MRMON087" "MRMON088 $MRMON088" "MRMON089 $MRMON089" "MRMON090 $MRMON090" "MRMON091 $MRMON091" "MRMON092 $MRMON092" "MRMON093 $MRMON093" "MRMON094 $MRMON094" "MRMON095 $MRMON095" "MRMON096 $MRMON096" "MRMON097 $MRMON097" "MRMON098 $MRMON098" "MRMON099 $MRMON099" "MRMON100 $MRMON100" "MRMON101 $MRMON101" "MRMON102 $MRMON102" "MRMON103 $MRMON103" "MRMON104 $MRMON104" "MRMON105 $MRMON105" "MRMON106 $MRMON106" "MRMON107 $MRMON107" "MRMON108 $MRMON108" "MRMON109 $MRMON109" "MRMON110 $MRMON110" "MRMON111 $MRMON111" "MRMON112 $MRMON112" "MRMON113 $MRMON113" "MRMON114 $MRMON114" "MRMON115 $MRMON115" "MRMON116 $MRMON116" "MRMON117 $MRMON117" "MRMON118 $MRMON118" "MRMON119 $MRMON119" "MRMON120 $MRMON120" "MRMON121 $MRMON121" "MRMON122 $MRMON122" "MRMON123 $MRMON123" "MRMON124 $MRMON124" "MRMON125 $MRMON125" "MRMON126 $MRMON126" "MRMON127 $MRMON127" "MRMON128 $MRMON128" "MRMON129 $MRMON129" "MRMON130 $MRMON130" "MRMON131 $MRMON131" "MRMON132 $MRMON132" "MRMON133 $MRMON133" "MRMON134 $MRMON134" "MRMON135 $MRMON135" "MRMON136 $MRMON136" "MRMON137 $MRMON137" "MRMON138 $MRMON138" "MRMON139 $MRMON139" "MRMON140 $MRMON140" "MRMON141 $MRMON141" "MRMON142 $MRMON142" "MRMON143 $MRMON143" "MRMON144 $MRMON144" "MRMON145 $MRMON145" "MRMON146 $MRMON146" "MRMON147 $MRMON147" "MRMON148 $MRMON148" "MRMON149 $MRMON149" "MRMON150 $MRMON150" "MRMON151 $MRMON151" "MRMON152 $MRMON152" "MRMON153 $MRMON153" "MRMON154 $MRMON154" "MRMON155 $MRMON155" "MRMON156 $MRMON156" "MRMON157 $MRMON157" "MRMON158 $MRMON158" "MRMON159 $MRMON159" "MRMON160 $MRMON160" "MRMON161 $MRMON161" "MRMON162 $MRMON162" "MRMON163 $MRMON163" "MRMON164 $MRMON164" "MRMON165 $MRMON165" "MRMON166 $MRMON166" "MRMON167 $MRMON167" "MRMON168 $MRMON168" "MRMON169 $MRMON169" "MRMON170 $MRMON170" "MRMON171 $MRMON171" "MRMON172 $MRMON172" "MRMON173 $MRMON173" "MRMON174 $MRMON174" "MRMON175 $MRMON175" "MRMON176 $MRMON176" "MRMON177 $MRMON177" "MRMON178 $MRMON178" "MRMON179 $MRMON179" "MRMON180 $MRMON180" "MRMON181 $MRMON181" "MRMON182 $MRMON182" "MRMON183 $MRMON183" "MRMON184 $MRMON184" "MRMON185 $MRMON185" "MRMON186 $MRMON186" "MRMON187 $MRMON187" "MRMON188 $MRMON188" "MRMON189 $MRMON189" "MRMON190 $MRMON190" "MRMON191 $MRMON191" "MRMON192 $MRMON192" "MRMON193 $MRMON193" "MRMON194 $MRMON194" "MRMON195 $MRMON195" "MRMON196 $MRMON196" "MRMON197 $MRMON197" "MRMON198 $MRMON198" "MRMON199 $MRMON199" "MRMON200 $MRMON200" "MRMON201 $MRMON201" "MRMON202 $MRMON202" "MRMON203 $MRMON203" "MRMON204 $MRMON204" "MRMON205 $MRMON205" "MRMON206 $MRMON206" "MRMON207 $MRMON207" "MRMON208 $MRMON208" "MRMON209 $MRMON209" "MRMON210 $MRMON210" "MRMON211 $MRMON211" "MRMON212 $MRMON212" "MRMON213 $MRMON213" "MRMON214 $MRMON214" "MRMON215 $MRMON215" "MRMON216 $MRMON216" MRMON217 $MRMON217" "MRMON218 $MRMON218" "MRMON219 $MRMON219" "MRMON220 $MRMON220" "MRMON221 $MRMON221" "MRMON222 $MRMON222" "MRMON223 $MRMON223" "MRMON224 $MRMON224" "MRMON225 $MRMON225" "MRMON226 $MRMON226" "MRMON227 $MRMON227" "MRMON228 $MRMON228" "MRMON229 $MRMON229" "MRMON230 $MRMON230" "MRMON231 $MRMON231" "MRMON232 $MRMON232" "MRMON233 $MRMON233" "MRMON234 $MRMON234" "MRMON235 $MRMON235" "MRMON236 $MRMON236" "MRMON237 $MRMON237" "MRMON238 $MRMON238" "MRMON239 $MRMON239" "MRMON240 $MRMON240" "MRMON241 $MRMON241" "MRMON242 $MRMON242" "MRMON243 $MRMON243" "MRMON244 $MRMON244" "MRMON245 $MRMON245" "MRMON246 $MRMON246" "MRMON247 $MRMON247" "MRMON248 $MRMON248" "MRMON249 $MRMON249" "MRMON250 $MRMON250" "MRMON251 $MRMON251" "MRMON252 $MRMON252" "MRMON253 $MRMON253" "MRMON254 $MRMON254" "MRMON255 $MRMON255" "MRMON256 $MRMON256" "MRMON257 $MRMON257" "MRMON258 $MRMON258" "MRMON259 $MRMON259" "MRMON260 $MRMON260" "MRMON261 $MRMON261" "MRMON262 $MRMON262" "MRMON263 $MRMON263" "MRMON264 $MRMON264" "MRMON265 $MRMON265" "MRMON266 $MRMON266" "MRMON267 $MRMON267" "MRMON268 $MRMON268" "MRMON269 $MRMON269" "MRMON270 $MRMON270" "MRMON271 $MRMON271" "MRMON272 $MRMON272" "MRMON273 $MRMON273" "MRMON274 $MRMON274" "MRMON275 $MRMON275" "MRMON276 $MRMON276" "MRMON277 $MRMON277" "MRMON278 $MRMON278" "MRMON279 $MRMON279" "MRMON280 $MRMON280" "MRMON281 $MRMON281" "MRMON282 $MRMON282" "MRMON283 $MRMON283" "MRMON284 $MRMON284" "MRMON285 $MRMON285" "MRMON286 $MRMON286" "MRMON287 $MRMON287" "MRMON288 $MRMON288" "MRMON289 $MRMON289" "MRMON290 $MRMON290" "MRMON291 $MRMON291" "MRMON292 $MRMON292" "MRMON293 $MRMON293" "MRMON294 $MRMON294" "MRMON295 $MRMON295" "MRMON296 $MRMON296" "MRMON297 $MRMON297" MRMON298 $MRMON298" "MRMON299 $MRMON299" "MRMON300 $MRMON300" "MRMON301 $MRMON301" "MRMON302 $MRMON302" "MRMON303 $MRMON303" "MRMON304 $MRMON304" "MRMON305 $MRMON305" "MRMON306 $MRMON306" "MRMON307 $MRMON307" "MRMON308 $MRMON308" "MRMON309 $MRMON309" "MRMON310 $MRMON310" "MRMON311 $MRMON311" "MRMON312 $MRMON312" "MRMON313 $MRMON313" "MRMON314 $MRMON314" "MRMON315 $MRMON315" "MRMON316 $MRMON316" "MRMON317 $MRMON317" "MRMON318 $MRMON318" "MRMON319 $MRMON319" "MRMON320 $MRMON320" "MRMON321 $MRMON321" "MRMON322 $MRMON322" "MRMON323 $MRMON323" "MRMON324 $MRMON324" "MRMON325 $MRMON325" "MRMON326 $MRMON326" "MRMON327 $MRMON327" "MRMON328 $MRMON328" "MRMON329 $MRMON329" "MRMON330 $MRMON330" "MRMON331 $MRMON331" "MRMON332 $MRMON332" "MRMON333 $MRMON333" "MRMON334 $MRMON334" "MRMON335 $MRMON335" "MRMON336 $MRMON336" "MRMON337 $MRMON337" "MRMON338 $MRMON338" "MRMON339 $MRMON339" "MRMON340 $MRMON340" ; do

set $i

if [ -e ./$fileName/MegaRAID/mrmonitord_messages.txt ]; then
       $grep -i $1 ./$fileName/MegaRAID/mrmonitord_messages.txt > ./$fileName/MegaRAID/$1_$2.txt

		if [ ! -s ./$fileName/MegaRAID/$1_$2.txt ]; then rm ./$fileName/MegaRAID/$1_$2.txt > /dev/null 2>&1 ; fi

fi

done

###########################################################################################################################
# Special Monitoring of specific errors
###########################################################################################################################


if [ -e ./$fileName/MegaRAID/MRMON113_Warning_0x0071h_Unexpected_sense_0x_CDBX_Sense_0x.txt ]; then 
grep -i "Sense =  0x70  0x00  0x0b  0x00  0x00  0x00  0x00  0x0a  0x00  0x00  0x00  0x00  0x47  0x03  0x00  0x00  0x00  0x00" ./$fileName/MegaRAID/MRMON113_Warning_0x0071h_Unexpected_sense_0x_CDBX_Sense_0x.txt > /dev/null
	if [ "$?" -eq "0" ]; then
	#cho ".................................................||................................................."
	echo ".......................................iuCRC Error Detected........................................." >> ./$fileName/MegaRAID/iuCRC_Error_Detected.txt
	echo "..........................................Contact Support..........................................." >> ./$fileName/MegaRAID/iuCRC_Error_Detected.txt
	grep -i "Sense =  0x70  0x00  0x0b  0x00  0x00  0x00  0x00  0x0a  0x00  0x00  0x00  0x00  0x47  0x03  0x00  0x00  0x00  0x00" ./$fileName/MegaRAID/MRMON113_Warning_0x0071h_Unexpected_sense_0x_CDBX_Sense_0x.txt >> ./$fileName/MegaRAID/iuCRC_Error_Detected.txt
	fi
fi
###########################################################################################################################


date '+%H:%M:%S.%N'
echo "Evaluating MegaRAID AENs completed..."

# Return from if FreeBSD - Different Error Codes and no MR_Monitord support
fi
# Return from if MacOS - No MacOS support for MegaRAID
fi

###########################################################################################################################
# 3ware CodeSet Check Start
###########################################################################################################################
#cho ".................................................||................................................."
echo "...................................................................................................." > ./$fileName/3ware/Versions_3w.txt 2>&1
echo "If a controller driver/fw/3dm2/3dm or tw_cli heading does not have a codeset version listed then " >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "this is either an older capture script or you may be running non standard code! " >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "However, not all In-Kernel drivers may be listed yet. " >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "" >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "Note: 3dm/3dm2 is only checked in the default install locations." >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "" >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "The version of the Included/Latest tw_cli is listed and possibly if present the  "  >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "Pre-Existing tw_cli that was found in the PATH. The tw_cli included with the capture "  >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "script was used for data collection unless it failed to run on the system." >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "The file tw_cli is deleted in the current working directory in order to search" >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "the path for a Pre-Existing tw_cli as well as to force the use of the Included tw_cli." >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "The included tw_cli is left in the working directory." >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "You "SHOULD" always use the latest available capture file!" >> ./$fileName/3ware/Versions_3w.txt 2>&1
#cho ".................................................||................................................."
echo "...................................................................................................."  >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "...........................................Latest Codeset..........................................." >> ./$fileName/3ware/Versions_3w.txt 2>&1
grep Latest_CodeSet ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
echo "...................................................................................................."  >> ./$fileName/3ware/Versions_3w.txt 2>&1


for i in $($CLI_LOCATION$CLI_NAME show |grep ^c | cut -b 2-3); do #Support for Controller IDs 0-99
	#cho ".................................................||................................................."
	echo "........................................Controller_C$i Firmware......................................" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	$CLI_LOCATION$CLI_NAME /c$i show model >> ./$fileName/3ware/Versions_3w.txt 2>&1
	$CLI_LOCATION$CLI_NAME /c$i show firmware | cut -s -d " " -f 6 > ./$fileName/script_workspace/fwC$i.txt 2>&1
	for j in $( cat ./$fileName/script_workspace/fwC$i.txt );do
	fgrep "$j"_FW ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
		if [ "$?" -ne "0" ] ; then
		echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
		cat ./$fileName/script_workspace/fwC$i.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
		fi
	done
	
	#cho ".................................................||................................................."
	echo "........................................Controller_C$i Driver........................................" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	$CLI_LOCATION$CLI_NAME /c$i show driver | cut -s -d " " -f 5 > ./$fileName/script_workspace/drvC$i.txt 2>&1
	for j in $( cat ./$fileName/script_workspace/drvC$i.txt );do
	fgrep "$j"_DRV ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
		if [ "$?" -ne "0" ] ; then
		echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
		cat ./$fileName/script_workspace/drvC$i.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
		fi
	done
done


if [ -e ./$fileName/3ware/3DM/3dm_version.txt ]; then 
#cho ".................................................||................................................."
echo "................................................3DM................................................." >> ./$fileName/3ware/Versions_3w.txt
for j in $( cat ./$fileName/3ware/3DM/3dm_version.txt );do
fgrep "$j"_3DM ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	cat ./$fileName/3ware/3DM/3dm_version.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	fi
done
fi

if [ -e ./$fileName/3ware/3DM2/3dm2_ver.txt ]; then 
#cho ".................................................||................................................."
echo "................................................3DM2................................................" >> ./$fileName/3ware/Versions_3w.txt

for j in $( cat ./$fileName/3ware/3DM2/3dm2_ver.txt );do
fgrep "$j"_3DM2 ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	cat ./$fileName/3ware/3DM2/3dm2_ver.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	fi
done
fi

if [ -e ./$fileName/3ware/3DM2/3dm2api_ver.txt ]; then 
#cho ".................................................||................................................."
#echo "..............................................3DM2 API.............................................." >> ./$fileName/3ware/Versions_3w.txt

for j in $( cat ./$fileName/3ware/3DM2/3dm2api_ver.txt );do
fgrep "$j"_API ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	cat ./$fileName/3ware/3DM2/3dm2api_ver.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	fi
done
fi


if [ -e ./$fileName/script_workspace/tw_cli_Bundled_version.txt ]; then 
#cho ".................................................||................................................."
echo "...................................Latest/Included TW_CLI version..................................." >> ./$fileName/3ware/Versions_3w.txt
for j in $( cat ./$fileName/script_workspace/tw_cli_Bundled_version.txt );do
fgrep "$j"_CLI ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	cat ./$fileName/script_workspace/tw_cli_Bundled_version.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	fi
done
fi

if [ -e ./$fileName/script_workspace/tw_cli_Existing_version.txt ]; then 
#cho ".................................................||................................................."
echo ".....................................Pre-Existing TW_CLI version...................................." >> ./$fileName/3ware/Versions_3w.txt
for j in $( cat ./$fileName/script_workspace/tw_cli_Existing_version.txt );do
fgrep "$j"_CLI ./$fileName/script_workspace/cversions_3w.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_3w.txt" >> ./$fileName/3ware/Versions_3w.txt 2>&1
	cat ./$fileName/script_workspace/tw_cli_Existing_version.txt >> ./$fileName/3ware/Versions_3w.txt 2>&1
	fi
done
fi

#
#Stop 3ware CodeSet Check
#

###########################################################################################################################
# LSI HBA CodeSet Check Start
###########################################################################################################################
# No MacOS Support for HBA
if [ "$OS_LSI" != "macos" ] ; then

#cho ".................................................||................................................."
echo "...................................................................................................." > ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "If an HBA driver/fw or MSM heading does not have a codeset version listed then " >> ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "this is either an older capture script or you may be running non standard code! " >> ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "However, not all In-Kernel drivers may be listed yet. " >> ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "You "SHOULD" always use the latest available capture file!" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
#cho ".................................................||................................................."
echo "...................................................................................................."  >> ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "...........................................Latest Codeset..........................................." >> ./$fileName/HBA/Versions_HBA.txt 2>&1
grep Latest_CodeSet ./$fileName/script_workspace/cversions_HBA.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
echo "...................................................................................................."  >> ./$fileName/HBA/Versions_HBA.txt 2>&1

if [ "$NO_LSI_HBAs" != "YES" ] ; then 

for i in $(./lsut 0 | $grep -A1 "Chip Vendor/Type/Rev" | $grep LSI | cut -d. -f1); do # Support for unlimited HBAs

	#cho ".................................................||................................................."
	echo "...................................Host Bus Adapter_$i Firmware......................................" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	./lsut -p $i 1 | $grep MPTFW | tr [:blank:] @ | cut -d@ -f5 > ./$fileName/script_workspace/fwH$i.txt 2>&1
	./lsut -p $i 47 | $grep "Board name is" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	for j in $( cat ./$fileName/script_workspace/fwH$i.txt );do
	fgrep "$j"_FW ./$fileName/script_workspace/cversions_HBA.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		if [ "$?" -ne "0" ] ; then
		echo "Version not listed in cversions_HBA.txt" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		cat ./$fileName/script_workspace/fwH$i.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		fi
	done

	#cho ".................................................||................................................."
	echo ".....................................Host Bus Adapter_$i BIOS........................................" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	./lsut -p $i 1 | $grep BIOS | tr [:blank:] @ | cut -d@ -f6 | cut -d- -f2 > ./$fileName/script_workspace/biosH$i.txt 2>&1
	for j in $( cat ./$fileName/script_workspace/biosH$i.txt );do
	fgrep "$j"_BIOS ./$fileName/script_workspace/cversions_HBA.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		if [ "$?" -ne "0" ] ; then
		echo "Version not listed in cversions_HBA.txt" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		cat ./$fileName/script_workspace/biosH$i.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		fi
	done
	
	#cho ".................................................||................................................."
	echo "....................................Host Bus Adapter_$i Driver......................................" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	./lsut -p $i 47 | $grep Driver | cut -dD -f2 | cut -d- -f2 > ./$fileName/script_workspace/drvH$i.txt 2>&1
	for j in $( cat ./$fileName/script_workspace/drvH$i.txt );do
	fgrep "$j"_DRV ./$fileName/script_workspace/cversions_HBA.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		if [ "$?" -ne "0" ] ; then
		echo "Version not listed in cversions_HBA.txt" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		cat ./$fileName/script_workspace/drvH$i.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
		fi
	done
done
fi

if [ -e ./$fileName/MegaRAID/MSM/mrmonitord_version.txt ]; then 
#cho ".................................................||................................................."
echo "..........................................MSM MRMONITORD............................................" >> ./$fileName/HBA/Versions_HBA.txt
for j in $( cat ./$fileName/MegaRAID/MSM/mrmonitord_version.txt );do
fgrep "$j"_MSMmd ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	cat ./$fileName/MegaRAID/MSM/mrmonitord_version.txt >> ./$fileName/HBA/Versions_HBA.txt 2>&1
	fi
done
fi

#
#Stop LSI HBA CodeSet Check
#

# Return no MacOS support for HBA
fi

###########################################################################################################################
# MegaRAID CodeSet Check Start
###########################################################################################################################
# No MacOS Support for MegaRAID
if [ "$OS_LSI" != "macos" ] ; then

#cho ".................................................||................................................."
echo "...................................................................................................." > ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "If a Adapter driver/fw/MSM or MegaCli heading does not have a codeset version listed then " >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "this is either an older capture script or you may be running non standard/OLD code! " >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "However, not all In-Kernel drivers may be listed yet. " >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "The version of the Included/Latest MegaCli(64) is listed and possibly if present the  "  >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "Pre-Existing tw_cli that was found in the PATH. The MegaCli(64) included with the capture "  >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "script was used for data collection unless it failed to run on the system." >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "The file MegaCli(64) is deleted in the current working directory in order to search" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "the path for a Pre-Existing MegaCli(64) as well as to force the use of the Included MegaCli(64)." >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "The included tw_cli is left in the working directory." >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "You "SHOULD" always use the latest available capture file!" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
#cho ".................................................||................................................."
echo "...................................................................................................."  >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "...........................................Latest Codeset..........................................." >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
grep Latest_CodeSet ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
echo "...................................................................................................."  >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1

# Make sure at least 1 MegaRAID Adapter is identified
if [ -f ./$fileName/script_workspace/adapter_numbers.txt ] ; then

for i in `cat ./$fileName/script_workspace/adapter_numbers.txt` ; do #Support for all adapter IDs 
	#cho ".................................................||................................................."
	echo "........................................Adapter_A$i Firmware........................................." >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpallinfo a$i nolog | $grep -e "Product Name" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	$MCLI_LOCATION$MCLI_NAME adpallinfo a$i | $grep Package | cut -d' ' -f4 > ./$fileName/script_workspace/fwA$i.txt 2>&1
	for j in $( cat ./$fileName/script_workspace/fwA$i.txt );do
	fgrep "$j"_FWp ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
		if [ "$?" -ne "0" ] ; then
		echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
		cat ./$fileName/script_workspace/fwA$i.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
		fi
	done
	
if [ "$OS_LSI" = "linux" ]; then 

# Need Adpalilog fixed to show driver rev per adapter.

if [ ! -f ./$fileName/script_workspace/megaraid_sas_ver.txt ] ; then
lsmod | $grep megaraid_sas >/dev/null
	if [ "$?" -eq "0" ] ; then
	modinfo megaraid_sas | $grep "version:        00." | cut -d: -f2 | tr [:blank:] @ | tr -d @ >> ./$fileName/script_workspace/megaraid_sas_ver.txt
	fi
fi
if [ ! -f ./$fileName/script_workspace/megasr_ver.txt ] ; then
lsmod | $grep megasr >/dev/null
	if [ "$?" -eq "0" ] ; then
	modinfo megasr | $grep "version:        00." | cut -d: -f2 | tr [:blank:] @ | tr -d @ >> ./$fileName/script_workspace/megasr_ver.txt
	fi
fi

	#cho ".................................................||................................................."
	echo ".........................................Adapter_A$i Driver.........................................." >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1

$MCLI_LOCATION$MCLI_NAME adpallinfo a$i nolog | $grep -e "Product Name" | $grep " 82" >/dev/null
	if [ "$?" -eq "0" ] ; then
		if [ -f ./$fileName/script_workspace/megasr_ver.txt ] ; then
		for j in $( cat ./$fileName/script_workspace/megasr_ver.txt );do
		fgrep "$j"_DRVl ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
			if [ "$?" -ne "0" ] ; then
			echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
			cat ./$fileName/script_workspace/megasr_ver.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
			fi
		done
		fi
	else
		if [ -f ./$fileName/script_workspace/megaraid_sas_ver.txt ] ; then
		for j in $( cat ./$fileName/script_workspace/megaraid_sas_ver.txt );do
		fgrep "$j"_DRVl ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
			if [ "$?" -ne "0" ] ; then
			echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
			cat ./$fileName/script_workspace/megaraid_sas_ver.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
			fi
		done
		fi
	fi		

#OS Linux
fi

# Adapter Numbers
done
fi


if [ -e ./$fileName/MegaRAID/MSM/mrmonitord_version.txt ]; then 
#cho ".................................................||................................................."
echo "..........................................MSM MRMONITORD............................................" >> ./$fileName/MegaRAID/Versions_MR.txt
for j in $( cat ./$fileName/MegaRAID/MSM/mrmonitord_version.txt );do
fgrep "$j"_MSMmd ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/MegaRAID/MSM/mrmonitord_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
done
fi



if [ -e ./$fileName/script_workspace/mcli_Bundled_version.txt ]; then 
#cho ".................................................||................................................."
echo "..................................Latest/Included MegaCli version..................................." >> ./$fileName/MegaRAID/Versions_MR.txt
for j in $( cat ./$fileName/script_workspace/mcli_Bundled_version.txt );do

if [ "$OS_LSI" = "linux" ] ; then
fgrep "$j"_CLIl ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Bundled_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=Linux
fi
if [ "$OS_LSI" = "vmware" ] ; then
fgrep "$j"_CLIl ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Bundled_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=vmware
fi
if [ "$OS_LSI" = "freebsd" ] ; then
fgrep "$j"_CLIf ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Bundled_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=freebsd
fi
if [ "$OS_LSI" = "sco" ] ; then
fgrep "$j"_CLIsc ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Bundled_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=sco
fi
if [ "$OS_LSI" = "solaris" ] ; then
fgrep "$j"_CLIso ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Bundled_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=solaris
fi

done
fi

if [ -e ./$fileName/script_workspace/mcli_Existing_version.txt ]; then 
#cho ".................................................||................................................."
echo "....................................Pre-Existing MegaCli version...................................." >> ./$fileName/MegaRAID/Versions_MR.txt
for j in $( cat ./$fileName/script_workspace/mcli_Existing_version.txt );do

if [ "$OS_LSI" = "linux" ] ; then
fgrep "$j"_CLIl ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Existing_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=Linux
fi
if [ "$OS_LSI" = "vmware" ] ; then
fgrep "$j"_CLIl ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Existing_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=vmware
fi
if [ "$OS_LSI" = "freebsd" ] ; then
fgrep "$j"_CLIf ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Existing_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=freebsd
fi
if [ "$OS_LSI" = "sco" ] ; then
fgrep "$j"_CLIsc ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Existing_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=sco
fi
if [ "$OS_LSI" = "solaris" ] ; then
fgrep "$j"_CLIso ./$fileName/script_workspace/cversions_MR.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	if [ "$?" -ne "0" ] ; then
	echo "Version not listed in cversions_MR.txt" >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	cat ./$fileName/script_workspace/mcli_Existing_version.txt >> ./$fileName/MegaRAID/Versions_MR.txt 2>&1
	fi
# Return OS=solaris
fi

done
fi


#
#Stop MegaRAID CodeSet Check
#

# Return for no MacOS support for MegaRAID
fi

###########################################
# Return for G_* skip to the end
###########################################
fi # G_*
#

###########################################################################################################################
# Done with MegaCli! - Second iteration in case G_* option
###########################################################################################################################
LD_PRELOAD=
LD_LIBRARY_PATH=


###########################################################################################################################
###########################################################################################################################
# Monitor Mode - 
###########################################################################################################################
###########################################################################################################################
if [ "$tw_cli_Functional" != "NO" ]; then
if [ "$TWGETMONITORMODE" = "MONITOR" ]; then

if [ ! -d ./$fileName/MONITOR ]; then 
	mkdir ./$fileName/MONITOR 
	mkdir ./$fileName/MONITOR/work_space
fi

# No Carriage Return embedded on end of line!
echo  ------------------------------------------------------------------------------ > ./$fileName/MONITOR/work_space/no_alarms_check.txt
###########################################################################################################################
# Monitor Mode - Blank added to EOL in monitor_point_C$i.txt
# Getting latest AEN "monitor_point" to compare new AEN's against
# Verify monitor_point_C$i.txt is valid
###########################################################################################################################


for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
$CLI_LOCATION$CLI_NAME /c$i show alarms | sed '/^$/d' | tail -n 1  > ./$fileName/MONITOR/work_space/monitor_point_C$i.txt

	cat ./$fileName/MONITOR/work_space/monitor_point_C$i.txt | while read j ; do
	cat ./$fileName/MONITOR/work_space/no_alarms_check.txt | while read k ; do
	if [ "$j" = "$k" ] ; then echo "There were no alarms" > ./$fileName/MONITOR/work_space/monitor_point_C$i.txt ; fi
	done
	done
done

# NOT_FIRST_RUN
while [ "$GOTO_STOP_MONITOR" != "YES" ] ;  do

# Default 60 Second wait for checking Alarms/AENs with "show diag"
sleep 60
echo .
echo "lsigetlin.sh Monitor Mode - Command line \"$TWCMDLINE\"   `date '+%H:%M:%S.%N'`"
echo ""
echo "Saves Internal Controller Log daily and on specific errors."
echo "Exits after Controller Reset/Degraded Array/Rebuild Started AENs"
echo ""
echo "To terminate hit CTRL-C"
echo ""
echo 'If manually terminated and you still need to send the output to Support/your FAE, run;'
echo ""
echo "tar cf $fileName.tar ./$fileName"
echo "gzip -9 $fileName.tar"
echo ""
echo "Then send just the file $fileName.tar.gz to Support/your FAE."
echo ""
echo "If Monitor Mode completes, run a standard capture and include that as well."
echo .
echo .
echo .

###########################################################################################################################
# Monitor Mode - Blank added to EOL in alarms_C$i.txt
# Getting latest AENs to compare "monitor_point" against, changed order to get latest AENs on top
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
$CLI_LOCATION$CLI_NAME /c$i show alarms reverse > ./$fileName/MONITOR/work_space/alarms_C$i.txt
done
###########################################################################################################################
# Monitor Mode - Blank match j & k
# Comparing "monitor_point" and AENs, printing new AENs to new_alarms_C$i.txt 2>&1 
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ -e ./$fileName/MONITOR/work_space/new_alarms_C$i.txt ] ; then rm ./$fileName/MONITOR/work_space/new_alarms_C$i.txt ; fi

	cat ./$fileName/MONITOR/work_space/monitor_point_C$i.txt | while read j ; do
	cat ./$fileName/MONITOR/work_space/alarms_C$i.txt | while read k ; do
	if [ "$j" = "$k" ] ; then break ; else echo "$k" >> ./$fileName/MONITOR/work_space/new_alarms_C$i.txt ;	fi
	done
	done
done
###########################################################################################################################
# Monitor Mode - Blank match j & k
# Comparing "monitor_point" and AENs, printing new AENs to AnyError_new_alarms_C$i.txt 2>&1 
# "Couldn't strip blank spaces on the end of the AEN strings to use one set of AEN files."
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ -e ./$fileName/MONITOR/work_space/AnyError_new_alarms_C$i.txt ] ; then rm ./$fileName/MONITOR/work_space/AnyError_new_alarms_C$i.txt ; fi
done

for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ -e ./$fileName/MONITOR/work_space/AnyError_monitor_point_C$i.txt ] ; then 

	cat ./$fileName/MONITOR/work_space/AnyError_monitor_point_C$i.txt | while read j ; do
	cat ./$fileName/MONITOR/work_space/alarms_C$i.txt | while read k ; do
	if [ "$j" = "$k" ] ; then break ; else echo "$k" >> ./$fileName/MONITOR/work_space/AnyError_new_alarms_C$i.txt ; fi
	done
	done
fi
done


###########################################################################################################################
# Monitor Mode - 
# Searching for 3 specific AENs to stop test also just do a "show diag" on any "ERROR" and continue.
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
grep "Controller reset occurred: resets=" ./$fileName/MONITOR/work_space/new_alarms_C$i.txt > /dev/null 2>&1 
if [ "$?" -eq "0" ] ; then
	echo "Controller reset occurred: resets=" > ./$fileName/MONITOR/work_space/ResetDegradeRebuild_C$i.txt
	GOTO_STOP_MONITOR=YES
fi

if [ "$GOTO_STOP_MONITOR" != "YES" ] ; then
	grep "Degraded unit: unit=" ./$fileName/MONITOR/work_space/new_alarms_C$i.txt > /dev/null 2>&1
	if [ "$?" -eq "0" ] ; then
		echo "Degraded unit: unit=" > ./$fileName/MONITOR/work_space/ResetDegradeRebuild_C$i.txt
		GOTO_STOP_MONITOR=YES
	fi
fi

if [ "$GOTO_STOP_MONITOR" != "YES" ] ; then
	grep "Rebuild started:" ./$fileName/MONITOR/work_space/new_alarms_C$i.txt > /dev/null 2>&1
	if [ "$?" -eq "0" ] ; then
		echo "Rebuild started:" > ./$fileName/MONITOR/work_space/ResetDegradeRebuild_C$i.txt
		GOTO_STOP_MONITOR=YES
	fi
fi
# return for controller #
done

if [ "$GOTO_STOP_MONITOR" != "YES" ] ; then


for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ -e ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ] ; then rm ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ; fi
if [ -e ./$fileName/MONITOR/work_space/AnyError_new_alarms_C$i.txt ] ; then
	grep "]  ERROR" ./$fileName/MONITOR/work_space/AnyError_new_alarms_C$i.txt > /dev/null 2>&1
	if [ "$?" -eq "0" ] ; then echo "Dummy File - AnyError_new_alarms" > ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ; fi
fi

if [ ! -e ./$fileName/MONITOR/work_space/AnyError_new_alarms_C$i.txt ] ; then
	grep "]  ERROR" ./$fileName/MONITOR/work_space/new_alarms_C$i.txt > /dev/null 2>&1
	if [ "$?" -eq "0" ] ; then echo "Dummy File - new_alarms" > ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ; fi
fi
# return for controller #
done

###########################################################################################################################
# Monitor Mode - Blank added to EOL in monitor_point_C$i.txt
# Getting latest AEN "AnyError_monitor_point" to compare new AEN's against
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ ! -e ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ] ; then
$CLI_LOCATION$CLI_NAME /c$i show alarms | sed '/^$/d' | tail -n 1  > ./$fileName/MONITOR/work_space/AnyError_monitor_point_C$i.txt
fi
done
###########################################################################################################################
# Verify AnyError_monitor_point_C$i.txt is valid
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ ! -e ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ] ; then

	cat ./$fileName/MONITOR/work_space/AnyError_monitor_point_C$i.txt | while read j ; do
	cat ./$fileName/MONITOR/work_space/no_alarms_check.txt | while read k ; do
	if [ "$j" = "$k" ] ; then echo "There were no alarms" > ./$fileName/MONITOR/work_space/AnyError_monitor_point_C$i.txt ; fi
	done
	done
fi
done
###########################################################################################################################
# Monitor Mode - 
# log time/date stamps
###########################################################################################################################
mtodayDate=`date '+DATE:%m%d%y' | cut -d: -f2`
mcurrentTime=`date '+TIME:%H%M%S' | cut -d: -f2`
###########################################################################################################################
# Monitor Mode - 
# Default 60 Second Alarm Check wait * 60 Iterations = approx. 1 hour * 24 = approx. 1 day standard "show diag"
# 60 * 24 = 1440 lines 
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
echo 1 >> ./$fileName/MONITOR/work_space/Count_C$i.txt
grep -n "1" ./$fileName/MONITOR/work_space/Count_C$i.txt | $grep "1440:" > /dev/null 2>&1
if [ "$?" -eq "0" ] ; then 
	$CLI_LOCATION$CLI_NAME /c$i show diag > ./"$fileName"/MONITOR/daily_"$mtodayDate"_"$mcurrentTime"_diag_C"$i".txt 
rm ./$fileName/MONITOR/work_space/Count_C$i.txt
fi
done

###########################################################################################################################
# Monitor Mode - 
# The "show diag" on any error, not including the main three.
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ -e ./$fileName/MONITOR/work_space/CREATEAnyErrorMONITORPOINT_C$i.txt ] ; then
	$CLI_LOCATION$CLI_NAME /c$i show diag > ./"$fileName"/MONITOR/AnyError_"$mtodayDate"_"$mcurrentTime"_diag_C"$i".txt 
	rm ./$fileName/MONITOR/work_space/new_alarms_C$i.txt
fi
done

# Return for "if [ "$GOTO_STOP_MONITOR" != "YES" ] ; then"
fi
# Return for "while "$GOTO_STOP_MONITOR" != "YES" ;  do"
done

###########################################################################################################################
# Monitor Mode - 
# The "show diag" on the main three AENs.
###########################################################################################################################
for i in `cat ./$fileName/script_workspace/controller_numbers.txt` ; do #Support for Controller IDs 0-99
if [ -e ./$fileName/MONITOR/work_space/ResetDegradeRebuild_C$i.txt ] ; then
	$CLI_LOCATION$CLI_NAME /c$i show diag > ./"$fileName"/MONITOR/ResetDegradeRebuild_"$mtodayDate"_"$mcurrentTime"_diag_C"$i".txt
	sleep 300
	$CLI_LOCATION$CLI_NAME /c$i show diag > ./"$fileName"/MONITOR/ResetDegradeRebuild_5min_"$mtodayDate"_"$mcurrentTime"_diag_C"$i".txt
fi
done

# Return from "if [ "$TWGETMONITORMODE" = "MONITOR" ]; then"
fi
fi

###########################################################################################################################
# Script Start/Stop times
###########################################################################################################################
TWGETLUNIXSTOPutc=`date -u`
TWGETLUNIXSTOP=`date`
echo "START Universal Time" > ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo $TWGETLUNIXSTARTutc >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo "START Local Time" >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo $TWGETLUNIXSTART >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo "STOP Universal Time" >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo $TWGETLUNIXSTOPutc >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo "STOP Local Time" >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt
echo $TWGETLUNIXSTOP >> ./$fileName/script_workspace/Script_Start_Stop_Time.txt

###########################################################################################################################
# Capture created logs in the working directory
###########################################################################################################################

if [ -e ./CtDbg.log ] ; then
mv ./CtDbg.log ./$fileName/MegaRAID/
fi
if [ -e ./MegaSAS.log ] ; then
mv ./MegaSAS.log ./$fileName/MegaRAID/
fi
if [ -e ./CmdTool.log ] ; then
mv ./CmdTool.log ./$fileName/MegaRAID/
fi

###########################################################################################################################
# Clean up
###########################################################################################################################

if [ -d ./3rdpartylibs ] ; then
rm -rf ./3rdpartylibs
fi

for i in LGPLLicenseV2.txt libsysfs.so.2.0.1 ApacheLicenseV2.txt cliVmWare.conf libcrypto.so.0.9.7 libpegclient.so.1 libpegcommon.so.1 libpegconfig.so.1 libpegexportserver.so.1 libpeglistener.so.1 libpegprovider.so.1 libpegslp_client.so.1 libssl.so.0.9.7 libxerces-c.so.28.0 NOTICE OpenPegasusLicense.txt OpenPegasusNOTICE.txt OpenSSLLicense.txt server.cert server.key ssl.rnd CtDbg.log MegaSAS.log CmdTool.log lsut Sense-Key_ASC-ASCQ_Opcodes_SBC4R16.txt cversions_3w.txt cversions_MR.txt cversions_HBA.txt create freebsd_MegaCli freebsd_tw_cli.32 freebsd_tw_cli.64 linux_lsut.32 linux_lsut.64 linux_MegaCli linux_MegaCli64 linux_tw_cli.32 linux_tw_cli.64 macos_tw_cli.32 sco_MegaCli solaris_lsut.i386 solaris_lsut.sparc solaris_MegaCli solaris_tw_cli.32 vmware_MegaCli vmware_tw_cli.esx35 vmware_tw_cli.esx40 vmware_tw_cli.esxi40 ; do
if [ -e ./$i ] ; then
rm -f ./$i
fi
done

if [ "$OS_LSI" != "linux" ] ; then
rm -f ./Lib_Utils-1.00-07.noarch.rpm
rm -f ./Lib_Utils2-1.00-01.noarch.rpm
fi


###########################################################################################################################
# Compressing the file output 
###########################################################################################################################


tar cf $fileName.tar ./$fileName 
gzip -9 $fileName.tar

 
#Keep subdir unless variable set
if [ "$TWGETDIRECTORYKEEP" != "YES" ] ; then rm -rf $fileName > /dev/null 2>&1 ; fi 


#cho ".................................................||................................................."
echo ""
echo "Script done. The file name is;"
echo ""
echo "$fileName.tar.gz"
echo ""
echo "Send just this file as is to your support rep."
echo ""
echo '"./lsigetlunix -H" provides a help screen.'
echo ""
if [ "$TWGETDIRECTORYKEEP" != "YES" ] ; then date '+%H:%M:%S.%N' ; fi
if [ "$TWGETDIRECTORYKEEP" = "YES" ] ; then 
echo "The following subdir was left for your use;"
echo ""
echo "$fileName"
echo ""
date '+%H:%M:%S.%N'
fi


if [ "$TWGETBATCHMODE" != "BATCH" ] ; then 
if [ "$TWGETBATCHMODE" != "QUIET" ] ; then 


# no read -r in sh
GetKeystroke () { 
trap "" 2 3 
oldSttySettings=`stty -g` 
stty -echo raw 
echo "`dd count=1 2> /dev/null`" 
stty $oldSttySettings 
trap 2 3 
} 
 
keyStroke="" 
while [ "$keyStroke" != "C" ] 
do 

if [ "$keyStroke" = "Q" ] ; then
date '+%H:%M:%S.%N'
exit
fi

echo "Type Q to Quit." 
echo "...................................................................................................."
keyStroke=`GetKeystroke` 
done
# no read -r in sh
fi
fi


